Class: Google::Apis::NetworkmanagementV1::CloudRunRevisionInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::CloudRunRevisionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Cloud Run revision.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Cloud Run revision.
-
#location ⇒ String
Location in which this revision is deployed.
-
#service_uri ⇒ String
URI of Cloud Run service this revision belongs to.
-
#uri ⇒ String
URI of the Cloud Run revision.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudRunRevisionInfo
constructor
A new instance of CloudRunRevisionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudRunRevisionInfo
Returns a new instance of CloudRunRevisionInfo.
452 453 454 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Cloud Run revision.
Corresponds to the JSON property displayName
433 434 435 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 433 def display_name @display_name end |
#location ⇒ String
Location in which this revision is deployed.
Corresponds to the JSON property location
438 439 440 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 438 def location @location end |
#service_uri ⇒ String
URI of Cloud Run service this revision belongs to. Format: projects/
project_id/locations/location/services/service_id`
Corresponds to the JSON propertyserviceUri`
444 445 446 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 444 def service_uri @service_uri end |
#uri ⇒ String
URI of the Cloud Run revision. Format: projects/project_id/locations/
location/revisions/revision_id`
Corresponds to the JSON propertyuri`
450 451 452 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 450 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
457 458 459 460 461 462 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 457 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @location = args[:location] if args.key?(:location) @service_uri = args[:service_uri] if args.key?(:service_uri) @uri = args[:uri] if args.key?(:uri) end |