Class: Google::Apis::NetworkmanagementV1::CloudSqlInstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::CloudSqlInstanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Cloud SQL instance.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Cloud SQL instance.
-
#external_ip ⇒ String
External IP address of a Cloud SQL instance.
-
#internal_ip ⇒ String
Internal IP address of a Cloud SQL instance.
-
#network_uri ⇒ String
URI of a Cloud SQL instance network or empty string if the instance does not have one.
-
#region ⇒ String
Region in which the Cloud SQL instance is running.
-
#uri ⇒ String
URI of a Cloud SQL instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudSqlInstanceInfo
constructor
A new instance of CloudSqlInstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudSqlInstanceInfo
Returns a new instance of CloudSqlInstanceInfo.
493 494 495 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Cloud SQL instance.
Corresponds to the JSON property displayName
465 466 467 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 465 def display_name @display_name end |
#external_ip ⇒ String
External IP address of a Cloud SQL instance.
Corresponds to the JSON property externalIp
470 471 472 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 470 def external_ip @external_ip end |
#internal_ip ⇒ String
Internal IP address of a Cloud SQL instance.
Corresponds to the JSON property internalIp
475 476 477 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 475 def internal_ip @internal_ip end |
#network_uri ⇒ String
URI of a Cloud SQL instance network or empty string if the instance does not
have one.
Corresponds to the JSON property networkUri
481 482 483 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 481 def network_uri @network_uri end |
#region ⇒ String
Region in which the Cloud SQL instance is running.
Corresponds to the JSON property region
486 487 488 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 486 def region @region end |
#uri ⇒ String
URI of a Cloud SQL instance.
Corresponds to the JSON property uri
491 492 493 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 491 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
498 499 500 501 502 503 504 505 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 498 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @external_ip = args[:external_ip] if args.key?(:external_ip) @internal_ip = args[:internal_ip] if args.key?(:internal_ip) @network_uri = args[:network_uri] if args.key?(:network_uri) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |