Class: Google::Apis::NetworkmanagementV1::DeliverInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

Details of the final state "deliver" and associated resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeliverInfo

Returns a new instance of DeliverInfo.



660
661
662
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 660

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_service_typeString

Recognized type of a Google Service the packet is delivered to (if applicable). Corresponds to the JSON property googleServiceType

Returns:

  • (String)


631
632
633
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 631

def google_service_type
  @google_service_type
end

#ip_addressString

IP address of the target (if applicable). Corresponds to the JSON property ipAddress

Returns:

  • (String)


636
637
638
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 636

def ip_address
  @ip_address
end

#psc_google_api_targetString

PSC Google API target the packet is delivered to (if applicable). Corresponds to the JSON property pscGoogleApiTarget

Returns:

  • (String)


641
642
643
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 641

def psc_google_api_target
  @psc_google_api_target
end

#resource_uriString

URI of the resource that the packet is delivered to. For example: * "projects/ project/zones/zone/instances/instance" * "projects/project/regions/ region/networkEndpointGroups/network_endpoint_group" Corresponds to the JSON property resourceUri

Returns:

  • (String)


648
649
650
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 648

def resource_uri
  @resource_uri
end

#storage_bucketString

Name of the Cloud Storage Bucket the packet is delivered to (if applicable). Corresponds to the JSON property storageBucket

Returns:

  • (String)


653
654
655
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 653

def storage_bucket
  @storage_bucket
end

#targetString

Target type where the packet is delivered to. Corresponds to the JSON property target

Returns:

  • (String)


658
659
660
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 658

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



665
666
667
668
669
670
671
672
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 665

def update!(**args)
  @google_service_type = args[:google_service_type] if args.key?(:google_service_type)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @storage_bucket = args[:storage_bucket] if args.key?(:storage_bucket)
  @target = args[:target] if args.key?(:target)
end