Class: Google::Apis::NetworkmanagementV1::ForwardInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ForwardInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Details of the final state "forward" and associated resource.
Instance Attribute Summary collapse
-
#ip_address ⇒ String
IP address of the target (if applicable).
-
#resource_uri ⇒ String
URI of the resource that the packet is forwarded to.
-
#target ⇒ String
Target type where this packet is forwarded to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardInfo
constructor
A new instance of ForwardInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardInfo
Returns a new instance of ForwardInfo.
1300 1301 1302 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
IP address of the target (if applicable).
Corresponds to the JSON property ipAddress
1288 1289 1290 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1288 def ip_address @ip_address end |
#resource_uri ⇒ String
URI of the resource that the packet is forwarded to.
Corresponds to the JSON property resourceUri
1293 1294 1295 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1293 def resource_uri @resource_uri end |
#target ⇒ String
Target type where this packet is forwarded to.
Corresponds to the JSON property target
1298 1299 1300 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1298 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1305 1306 1307 1308 1309 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1305 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @target = args[:target] if args.key?(:target) end |