Class: Google::Apis::NetworkmanagementV1::GenerateMonitoringPointConfigResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::GenerateMonitoringPointConfigResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Message for response for getting Monitoring Point configuration of a NetworkMonitoringProvider resource.
Instance Attribute Summary collapse
-
#config ⇒ Hash<String,Object>
The Monitoring Point configuration of the provider in JSON format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateMonitoringPointConfigResponse
constructor
A new instance of GenerateMonitoringPointConfigResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateMonitoringPointConfigResponse
Returns a new instance of GenerateMonitoringPointConfigResponse.
1494 1495 1496 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Hash<String,Object>
The Monitoring Point configuration of the provider in JSON format.
Corresponds to the JSON property config
1492 1493 1494 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1492 def config @config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1499 1500 1501 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1499 def update!(**args) @config = args[:config] if args.key?(:config) end |