Class: Google::Apis::NetworkmanagementV1::GoogleServiceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Details of a Google Service sending packets to a VPC network. Although the source IP might be a publicly routable address, some Google Services use special routes within Google production infrastructure to reach Compute Engine Instances. https://cloud.google.com/vpc/docs/routes# special_return_paths

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleServiceInfo

Returns a new instance of GoogleServiceInfo.



1654
1655
1656
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_service_typeString

Recognized type of a Google Service. Corresponds to the JSON property googleServiceType

Returns:

  • (String)


1647
1648
1649
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1647

def google_service_type
  @google_service_type
end

#source_ipString

Source IP address. Corresponds to the JSON property sourceIp

Returns:

  • (String)


1652
1653
1654
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1652

def source_ip
  @source_ip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1659
1660
1661
1662
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1659

def update!(**args)
  @google_service_type = args[:google_service_type] if args.key?(:google_service_type)
  @source_ip = args[:source_ip] if args.key?(:source_ip)
end