Class: Google::Apis::NetworkmanagementV1::HttpBody

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

Message that represents an arbitrary HTTP body. It should only be used for payload formats that can't be represented as JSON, such as raw binary or an HTML page. This message can be used both in streaming and non-streaming API methods in the request as well as the response. It can be used as a top-level request field, which is convenient if one wants to extract parameters from either the URL or HTTP template into the request fields and also want access to the raw HTTP body. Example: message GetResourceRequest // A unique request id. string request_id = 1; // The raw HTTP body is bound to this field. google.api.HttpBody http_body = 2; service ResourceService rpc GetResource(GetResourceRequest) returns (google.api.HttpBody); rpc UpdateResource(google.api.HttpBody) returns (google.protobuf.Empty); Example with streaming methods: service CaldavService rpc GetCalendar(stream google. api.HttpBody) returns (stream google.api.HttpBody); rpc UpdateCalendar(stream google.api.HttpBody) returns (stream google.api.HttpBody); Use of this type only changes how the request and response bodies are handled, all other features will continue to work unchanged.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpBody

Returns a new instance of HttpBody.



1717
1718
1719
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1717

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_typeString

The HTTP Content-Type header value specifying the content type of the body. Corresponds to the JSON property contentType

Returns:

  • (String)


1703
1704
1705
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1703

def content_type
  @content_type
end

#dataString

The HTTP request/response body as raw binary. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1709
1710
1711
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1709

def data
  @data
end

#extensionsArray<Hash<String,Object>>

Application specific response metadata. Must be set in the first response for streaming APIs. Corresponds to the JSON property extensions

Returns:

  • (Array<Hash<String,Object>>)


1715
1716
1717
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1715

def extensions
  @extensions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1722
1723
1724
1725
1726
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1722

def update!(**args)
  @content_type = args[:content_type] if args.key?(:content_type)
  @data = args[:data] if args.key?(:data)
  @extensions = args[:extensions] if args.key?(:extensions)
end