Class: Google::Apis::NetworkmanagementV1::HybridSubnetInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::HybridSubnetInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a hybrid subnet.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a hybrid subnet.
-
#region ⇒ String
Name of a Google Cloud region where the hybrid subnet is configured.
-
#uri ⇒ String
URI of a hybrid subnet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HybridSubnetInfo
constructor
A new instance of HybridSubnetInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HybridSubnetInfo
Returns a new instance of HybridSubnetInfo.
1748 1749 1750 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a hybrid subnet.
Corresponds to the JSON property displayName
1736 1737 1738 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1736 def display_name @display_name end |
#region ⇒ String
Name of a Google Cloud region where the hybrid subnet is configured.
Corresponds to the JSON property region
1741 1742 1743 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1741 def region @region end |
#uri ⇒ String
URI of a hybrid subnet.
Corresponds to the JSON property uri
1746 1747 1748 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1746 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1753 1754 1755 1756 1757 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1753 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |