Class: Google::Apis::NetworkmanagementV1::InstanceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceInfo

Returns a new instance of InstanceInfo.



1875
1876
1877
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1875

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a Compute Engine instance. Corresponds to the JSON property displayName

Returns:

  • (String)


1817
1818
1819
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1817

def display_name
  @display_name
end

#external_ipString

External IP address of the network interface. Corresponds to the JSON property externalIp

Returns:

  • (String)


1822
1823
1824
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1822

def external_ip
  @external_ip
end

#interfaceString

Name of the network interface of a Compute Engine instance. Corresponds to the JSON property interface

Returns:

  • (String)


1827
1828
1829
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1827

def interface
  @interface
end

#internal_ipString

Internal IP address of the network interface. Corresponds to the JSON property internalIp

Returns:

  • (String)


1832
1833
1834
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1832

def internal_ip
  @internal_ip
end

#network_tagsArray<String>

Network tags configured on the instance. Corresponds to the JSON property networkTags

Returns:

  • (Array<String>)


1837
1838
1839
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1837

def network_tags
  @network_tags
end

#network_uriString

URI of a Compute Engine network in format "projects/project/global/networks/ network" Corresponds to the JSON property networkUri

Returns:

  • (String)


1843
1844
1845
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1843

def network_uri
  @network_uri
end

#psc_network_attachment_uriString

URI of the PSC network attachment the NIC is attached to (if relevant) in format "projects/project/regions/region/networkAttachments/ network_attachment" Corresponds to the JSON property pscNetworkAttachmentUri

Returns:

  • (String)


1850
1851
1852
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1850

def psc_network_attachment_uri
  @psc_network_attachment_uri
end

#runningBoolean Also known as: running?

Indicates whether the Compute Engine instance is running. Deprecated: use the status field instead. Corresponds to the JSON property running

Returns:

  • (Boolean)


1856
1857
1858
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1856

def running
  @running
end

#service_accountString

Service account authorized for the instance. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1862
1863
1864
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1862

def 
  @service_account
end

#statusString

The status of the instance. Corresponds to the JSON property status

Returns:

  • (String)


1867
1868
1869
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1867

def status
  @status
end

#uriString

URI of a Compute Engine instance in format "projects/project/zones/zone/ instances/instance" Corresponds to the JSON property uri

Returns:

  • (String)


1873
1874
1875
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1873

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1880

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @external_ip = args[:external_ip] if args.key?(:external_ip)
  @interface = args[:interface] if args.key?(:interface)
  @internal_ip = args[:internal_ip] if args.key?(:internal_ip)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @psc_network_attachment_uri = args[:psc_network_attachment_uri] if args.key?(:psc_network_attachment_uri)
  @running = args[:running] if args.key?(:running)
  @service_account = args[:service_account] if args.key?(:service_account)
  @status = args[:status] if args.key?(:status)
  @uri = args[:uri] if args.key?(:uri)
end