Class: Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Response for the ListConnectivityTests method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Page token to fetch the next set of Connectivity Tests.
-
#resources ⇒ Array<Google::Apis::NetworkmanagementV1::ConnectivityTest>
List of Connectivity Tests.
-
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with
-).
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListConnectivityTestsResponse
constructor
A new instance of ListConnectivityTestsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListConnectivityTestsResponse
Returns a new instance of ListConnectivityTestsResponse.
1979 1980 1981 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1979 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Page token to fetch the next set of Connectivity Tests.
Corresponds to the JSON property nextPageToken
1967 1968 1969 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1967 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::NetworkmanagementV1::ConnectivityTest>
List of Connectivity Tests.
Corresponds to the JSON property resources
1972 1973 1974 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1972 def resources @resources end |
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with -).
Corresponds to the JSON property unreachable
1977 1978 1979 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1977 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1984 1985 1986 1987 1988 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1984 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) @unreachable = args[:unreachable] if args.key?(:unreachable) end |