Class: Google::Apis::NetworkmanagementV1::ListLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ListLocationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
The response message for Locations.ListLocations.
Instance Attribute Summary collapse
-
#locations ⇒ Array<Google::Apis::NetworkmanagementV1::Location>
A list of locations that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLocationsResponse
constructor
A new instance of ListLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLocationsResponse
Returns a new instance of ListLocationsResponse.
1974 1975 1976 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1974 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Array<Google::Apis::NetworkmanagementV1::Location>
A list of locations that matches the specified filter in the request.
Corresponds to the JSON property locations
1967 1968 1969 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1967 def locations @locations end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
1972 1973 1974 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1972 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1979 1980 1981 1982 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1979 def update!(**args) @locations = args[:locations] if args.key?(:locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |