Class: Google::Apis::NetworkmanagementV1::ListMonitoringPointsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ListMonitoringPointsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Message for response to listing MonitoringPoints
Instance Attribute Summary collapse
-
#monitoring_points ⇒ Array<Google::Apis::NetworkmanagementV1::MonitoringPoint>
The list of MonitoringPoints.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMonitoringPointsResponse
constructor
A new instance of ListMonitoringPointsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMonitoringPointsResponse
Returns a new instance of ListMonitoringPointsResponse.
1999 2000 2001 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1999 def initialize(**args) update!(**args) end |
Instance Attribute Details
#monitoring_points ⇒ Array<Google::Apis::NetworkmanagementV1::MonitoringPoint>
The list of MonitoringPoints.
Corresponds to the JSON property monitoringPoints
1992 1993 1994 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1992 def monitoring_points @monitoring_points end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
1997 1998 1999 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1997 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2004 2005 2006 2007 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2004 def update!(**args) @monitoring_points = args[:monitoring_points] if args.key?(:monitoring_points) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |