Class: Google::Apis::NetworkmanagementV1::ListNetworkPathsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ListNetworkPathsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Message for response to listing NetworkPaths
Instance Attribute Summary collapse
-
#network_paths ⇒ Array<Google::Apis::NetworkmanagementV1::NetworkPath>
The list of NetworkPath Corresponds to the JSON property
networkPaths. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListNetworkPathsResponse
constructor
A new instance of ListNetworkPathsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListNetworkPathsResponse
Returns a new instance of ListNetworkPathsResponse.
2049 2050 2051 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#network_paths ⇒ Array<Google::Apis::NetworkmanagementV1::NetworkPath>
The list of NetworkPath
Corresponds to the JSON property networkPaths
2042 2043 2044 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2042 def network_paths @network_paths end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2047 2048 2049 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2047 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2054 2055 2056 2057 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2054 def update!(**args) @network_paths = args[:network_paths] if args.key?(:network_paths) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |