Class: Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Response for the ListVpcFlowLogsConfigs method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Page token to fetch the next set of configurations.
-
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with
-). -
#vpc_flow_logs_configs ⇒ Array<Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig>
List of VPC Flow Log configurations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVpcFlowLogsConfigsResponse
constructor
A new instance of ListVpcFlowLogsConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVpcFlowLogsConfigsResponse
Returns a new instance of ListVpcFlowLogsConfigsResponse.
2144 2145 2146 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Page token to fetch the next set of configurations.
Corresponds to the JSON property nextPageToken
2132 2133 2134 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2132 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with -).
Corresponds to the JSON property unreachable
2137 2138 2139 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2137 def unreachable @unreachable end |
#vpc_flow_logs_configs ⇒ Array<Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig>
List of VPC Flow Log configurations.
Corresponds to the JSON property vpcFlowLogsConfigs
2142 2143 2144 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2142 def vpc_flow_logs_configs @vpc_flow_logs_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2149 2150 2151 2152 2153 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2149 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @vpc_flow_logs_configs = args[:vpc_flow_logs_configs] if args.key?(:vpc_flow_logs_configs) end |