Class: Google::Apis::NetworkmanagementV1::ListWebPathsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ListWebPathsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Message for response to listing WebPaths
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#web_paths ⇒ Array<Google::Apis::NetworkmanagementV1::WebPath>
The list of WebPath.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListWebPathsResponse
constructor
A new instance of ListWebPathsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListWebPathsResponse
Returns a new instance of ListWebPathsResponse.
2236 2237 2238 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2229 2230 2231 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2229 def next_page_token @next_page_token end |
#web_paths ⇒ Array<Google::Apis::NetworkmanagementV1::WebPath>
The list of WebPath.
Corresponds to the JSON property webPaths
2234 2235 2236 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2234 def web_paths @web_paths end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2241 2242 2243 2244 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2241 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @web_paths = args[:web_paths] if args.key?(:web_paths) end |