Class: Google::Apis::NetworkmanagementV1::LoadBalancerBackend
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::LoadBalancerBackend
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a specific load balancer backend.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Compute Engine instance or network endpoint.
-
#health_check_allowing_firewall_rules ⇒ Array<String>
A list of firewall rule URIs allowing probes from health check IP ranges.
-
#health_check_blocking_firewall_rules ⇒ Array<String>
A list of firewall rule URIs blocking probes from health check IP ranges.
-
#health_check_firewall_state ⇒ String
State of the health check firewall configuration.
-
#uri ⇒ String
URI of the backend instance or network endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadBalancerBackend
constructor
A new instance of LoadBalancerBackend.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadBalancerBackend
Returns a new instance of LoadBalancerBackend.
2271 2272 2273 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Compute Engine instance or network endpoint.
Corresponds to the JSON property displayName
2244 2245 2246 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2244 def display_name @display_name end |
#health_check_allowing_firewall_rules ⇒ Array<String>
A list of firewall rule URIs allowing probes from health check IP ranges.
Corresponds to the JSON property healthCheckAllowingFirewallRules
2249 2250 2251 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2249 def health_check_allowing_firewall_rules @health_check_allowing_firewall_rules end |
#health_check_blocking_firewall_rules ⇒ Array<String>
A list of firewall rule URIs blocking probes from health check IP ranges.
Corresponds to the JSON property healthCheckBlockingFirewallRules
2254 2255 2256 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2254 def health_check_blocking_firewall_rules @health_check_blocking_firewall_rules end |
#health_check_firewall_state ⇒ String
State of the health check firewall configuration.
Corresponds to the JSON property healthCheckFirewallState
2259 2260 2261 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2259 def health_check_firewall_state @health_check_firewall_state end |
#uri ⇒ String
URI of the backend instance or network endpoint. Format: * projects/
project_id/zones/zone/instances/instance_id(instance) * `projects/`
project_id`/zones/`zone`/networkEndpointGroups/`neg_id (zonal NEG) *
projects/project_id/regions/region/networkEndpointGroups/neg_id(
regional NEG) * `projects/`project_id`/global/networkEndpointGroups/`neg_id (
global NEG)
Corresponds to the JSON property uri
2269 2270 2271 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2269 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2276 2277 2278 2279 2280 2281 2282 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2276 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @health_check_allowing_firewall_rules = args[:health_check_allowing_firewall_rules] if args.key?(:health_check_allowing_firewall_rules) @health_check_blocking_firewall_rules = args[:health_check_blocking_firewall_rules] if args.key?(:health_check_blocking_firewall_rules) @health_check_firewall_state = args[:health_check_firewall_state] if args.key?(:health_check_firewall_state) @uri = args[:uri] if args.key?(:uri) end |