Class: Google::Apis::NetworkmanagementV1::LoadBalancerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a load balancer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerInfo

Returns a new instance of LoadBalancerInfo.



2426
2427
2428
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_typeString

Type of load balancer's backend configuration. Corresponds to the JSON property backendType

Returns:

  • (String)


2398
2399
2400
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2398

def backend_type
  @backend_type
end

#backend_uriString

URI of the backend associated with the load balancer. Format: * projects/ project_id/regions/region/backendServices/backend_service_id* `projects/ `project_id`/global/backendServices/`backend_service_id * projects/ project_id/regions/region/targetPools/target_pool_id* `projects/` project_id`/zones/`zone`/targetInstances/`target_instance_id Corresponds to the JSON property backendUri

Returns:

  • (String)


2407
2408
2409
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2407

def backend_uri
  @backend_uri
end

#backendsArray<Google::Apis::NetworkmanagementV1::LoadBalancerBackend>

Information for the loadbalancer backends. Corresponds to the JSON property backends



2412
2413
2414
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2412

def backends
  @backends
end

#health_check_uriString

URI of the health check for the load balancer. Deprecated and no longer populated as different load balancer backends might have different health checks. Corresponds to the JSON property healthCheckUri

Returns:

  • (String)


2419
2420
2421
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2419

def health_check_uri
  @health_check_uri
end

#load_balancer_typeString

Type of the load balancer. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


2424
2425
2426
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2424

def load_balancer_type
  @load_balancer_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2431
2432
2433
2434
2435
2436
2437
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2431

def update!(**args)
  @backend_type = args[:backend_type] if args.key?(:backend_type)
  @backend_uri = args[:backend_uri] if args.key?(:backend_uri)
  @backends = args[:backends] if args.key?(:backends)
  @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
end