Class: Google::Apis::NetworkmanagementV1::Location
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::Location
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
A resource that represents a Google Cloud location.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The friendly name for this location, typically a nearby city name.
-
#labels ⇒ Hash<String,String>
Cross-service attributes for the location.
-
#location_id ⇒ String
The canonical id for this location.
-
#metadata ⇒ Hash<String,Object>
Service-specific metadata.
-
#name ⇒ String
Resource name for the location, which may vary between implementations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Location
constructor
A new instance of Location.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Location
Returns a new instance of Location.
2084 2085 2086 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The friendly name for this location, typically a nearby city name. For example,
"Tokyo".
Corresponds to the JSON property displayName
2059 2060 2061 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2059 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Cross-service attributes for the location. For example "cloud.googleapis.com/
region": "us-east1"
Corresponds to the JSON property labels
2065 2066 2067 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2065 def labels @labels end |
#location_id ⇒ String
The canonical id for this location. For example: "us-east1".
Corresponds to the JSON property locationId
2070 2071 2072 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2070 def location_id @location_id end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata. For example the available capacity at the given
location.
Corresponds to the JSON property metadata
2076 2077 2078 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2076 def @metadata end |
#name ⇒ String
Resource name for the location, which may vary between implementations. For
example: "projects/example-project/locations/us-east1"
Corresponds to the JSON property name
2082 2083 2084 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2082 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2089 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @location_id = args[:location_id] if args.key?(:location_id) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) end |