Class: Google::Apis::NetworkmanagementV1::NetworkManagementService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::NetworkmanagementV1::NetworkManagementService
- Defined in:
- lib/google/apis/networkmanagement_v1/service.rb
Overview
Network Management API
The Network Management API provides a collection of network performance monitoring and diagnostic capabilities.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://networkmanagement.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#cancel_organization_location_global_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_organization_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new
VpcFlowLogsConfig. -
#create_project_location_global_connectivity_test(parent, connectivity_test_object = nil, test_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new Connectivity Test.
-
#create_project_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new
VpcFlowLogsConfig. -
#delete_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Deletes a long-running operation.
-
#delete_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific
VpcFlowLogsConfig. -
#delete_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific
ConnectivityTest. -
#delete_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Deletes a long-running operation.
-
#delete_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific
VpcFlowLogsConfig. -
#get_organization_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Location
Gets information about a location.
-
#get_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Gets the latest state of a long-running operation.
-
#get_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig
Gets the details of a specific
VpcFlowLogsConfig. -
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Location
Gets information about a location.
-
#get_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ConnectivityTest
Gets the details of a specific Connectivity Test.
-
#get_project_location_global_connectivity_test_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Policy
Gets the access control policy for a resource.
-
#get_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig
Gets the details of a specific
VpcFlowLogsConfig. -
#initialize ⇒ NetworkManagementService
constructor
A new instance of NetworkManagementService.
-
#list_organization_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
Lists all
VpcFlowLogsConfigsin a given organization. -
#list_organization_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#list_project_location_global_connectivity_tests(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse
Lists all Connectivity Tests owned by a project.
-
#list_project_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
Lists all
VpcFlowLogsConfigsin a given project. -
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_organization_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates an existing
VpcFlowLogsConfig. -
#patch_project_location_global_connectivity_test(name, connectivity_test_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates the configuration of an existing
ConnectivityTest. -
#patch_project_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates an existing
VpcFlowLogsConfig. -
#query_project_location_vpc_flow_logs_config_org_vpc_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::QueryOrgVpcFlowLogsConfigsResponse
QueryOrgVpcFlowLogsConfigs returns a list of all organization-level VPC Flow Logs configurations applicable to the specified project.
-
#rerun_connectivity_test(name, rerun_connectivity_test_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Rerun an existing
ConnectivityTest. -
#set_connectivity_test_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Policy
Sets the access control policy on the specified resource.
-
#show_project_location_vpc_flow_logs_config_effective_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, resource: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ShowEffectiveFlowLogsConfigsResponse
ShowEffectiveFlowLogsConfigs returns a list of all VPC Flow Logs configurations applicable to a specified resource.
-
#test_connectivity_test_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ NetworkManagementService
Returns a new instance of NetworkManagementService.
48 49 50 51 52 53 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-networkmanagement_v1', client_version: Google::Apis::NetworkmanagementV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 988 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::NetworkmanagementV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::NetworkmanagementV1::Empty::Representation command.response_class = Google::Apis::NetworkmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_organization_location_global_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 169 def cancel_organization_location_global_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::NetworkmanagementV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::NetworkmanagementV1::Empty::Representation command.response_class = Google::Apis::NetworkmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new VpcFlowLogsConfig. If a configuration with the exact same
settings already exists (even if the ID is different), the creation fails.
Notes: 1. Creating a configuration with state=DISABLED will fail 2. The
following fields are not considered as settings for the purpose of the check
mentioned above, therefore - creating another configuration with the same
fields but different values for the following fields will fail as well: * name
- create_time * update_time * labels * description
326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 326 def create_organization_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/vpcFlowLogsConfigs', ) command.request_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.request_object = vpc_flow_logs_config_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['parent'] = parent unless parent.nil? command.query['vpcFlowLogsConfigId'] = vpc_flow_logs_config_id unless vpc_flow_logs_config_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_global_connectivity_test(parent, connectivity_test_object = nil, test_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new Connectivity Test. After you create a test, the reachability
analysis is performed as part of the long running operation, which completes
when the analysis completes. If the endpoint specifications in
ConnectivityTest are invalid (for example, containing non-existent resources
in the network, or you don't have read permissions to the network
configurations of listed projects), then the reachability result returns a
value of UNKNOWN. If the endpoint specifications in ConnectivityTest are
incomplete, the reachability result returns a value of AMBIGUOUS. For more
information, see the Connectivity Test documentation.
625 626 627 628 629 630 631 632 633 634 635 636 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 625 def create_project_location_global_connectivity_test(parent, connectivity_test_object = nil, test_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/connectivityTests', ) command.request_representation = Google::Apis::NetworkmanagementV1::ConnectivityTest::Representation command.request_object = connectivity_test_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['parent'] = parent unless parent.nil? command.query['testId'] = test_id unless test_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new VpcFlowLogsConfig. If a configuration with the exact same
settings already exists (even if the ID is different), the creation fails.
Notes: 1. Creating a configuration with state=DISABLED will fail 2. The
following fields are not considered as settings for the purpose of the check
mentioned above, therefore - creating another configuration with the same
fields but different values for the following fields will fail as well: * name
- create_time * update_time * labels * description
1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1145 def create_project_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/vpcFlowLogsConfigs', ) command.request_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.request_object = vpc_flow_logs_config_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['parent'] = parent unless parent.nil? command.query['vpcFlowLogsConfigId'] = vpc_flow_logs_config_id unless vpc_flow_logs_config_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
204 205 206 207 208 209 210 211 212 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 204 def delete_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Empty::Representation command.response_class = Google::Apis::NetworkmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific VpcFlowLogsConfig.
363 364 365 366 367 368 369 370 371 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 363 def delete_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific ConnectivityTest.
659 660 661 662 663 664 665 666 667 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 659 def delete_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1023 1024 1025 1026 1027 1028 1029 1030 1031 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1023 def delete_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Empty::Representation command.response_class = Google::Apis::NetworkmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific VpcFlowLogsConfig.
1182 1183 1184 1185 1186 1187 1188 1189 1190 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1182 def delete_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 75 def get_organization_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Location::Representation command.response_class = Google::Apis::NetworkmanagementV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
235 236 237 238 239 240 241 242 243 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 235 def get_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig
Gets the details of a specific VpcFlowLogsConfig.
397 398 399 400 401 402 403 404 405 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 397 def get_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.response_class = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Location
Gets information about a location.
524 525 526 527 528 529 530 531 532 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 524 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Location::Representation command.response_class = Google::Apis::NetworkmanagementV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ConnectivityTest
Gets the details of a specific Connectivity Test.
690 691 692 693 694 695 696 697 698 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 690 def get_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::ConnectivityTest::Representation command.response_class = Google::Apis::NetworkmanagementV1::ConnectivityTest command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_connectivity_test_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
734 735 736 737 738 739 740 741 742 743 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 734 def get_project_location_global_connectivity_test_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::NetworkmanagementV1::Policy::Representation command.response_class = Google::Apis::NetworkmanagementV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1054 def get_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig
Gets the details of a specific VpcFlowLogsConfig.
1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1216 def get_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.response_class = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 280 def list_organization_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListOperationsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
Lists all VpcFlowLogsConfigs in a given organization.
440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 440 def list_organization_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/vpcFlowLogsConfigs', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 127 def list_organization_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListLocationsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_global_connectivity_tests(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse
Lists all Connectivity Tests owned by a project.
782 783 784 785 786 787 788 789 790 791 792 793 794 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 782 def list_project_location_global_connectivity_tests(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/connectivityTests', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1099 def list_project_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListOperationsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
Lists all VpcFlowLogsConfigs in a given project.
1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1259 def list_project_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/vpcFlowLogsConfigs', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
576 577 578 579 580 581 582 583 584 585 586 587 588 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 576 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListLocationsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates an existing VpcFlowLogsConfig. If a configuration with the exact
same settings already exists (even if the ID is different), the creation fails.
Notes: 1. Updating a configuration with state=DISABLED will fail 2. The
following fields are not considered as settings for the purpose of the check
mentioned above, therefore - updating another configuration with the same
fields but different values for the following fields will fail as well: * name
- create_time * update_time * labels * description
491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 491 def patch_organization_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.request_object = vpc_flow_logs_config_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_global_connectivity_test(name, connectivity_test_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates the configuration of an existing ConnectivityTest. After you update
a test, the reachability analysis is performed as part of the long running
operation, which completes when the analysis completes. The Reachability state
in the test resource is updated with the new result. If the endpoint
specifications in ConnectivityTest are invalid (for example, they contain
non-existent resources in the network, or the user does not have read
permissions to the network configurations of listed projects), then the
reachability result returns a value of UNKNOWN. If the endpoint specifications
in ConnectivityTest are incomplete, the reachability result returns a value
of AMBIGUOUS. See the documentation in ConnectivityTest for more details.
830 831 832 833 834 835 836 837 838 839 840 841 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 830 def patch_project_location_global_connectivity_test(name, connectivity_test_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::NetworkmanagementV1::ConnectivityTest::Representation command.request_object = connectivity_test_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates an existing VpcFlowLogsConfig. If a configuration with the exact
same settings already exists (even if the ID is different), the creation fails.
Notes: 1. Updating a configuration with state=DISABLED will fail. 2. The
following fields are not considered as settings for the purpose of the check
mentioned above, therefore - updating another configuration with the same
fields but different values for the following fields will fail as well: * name
- create_time * update_time * labels * description
1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1310 def patch_project_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.request_object = vpc_flow_logs_config_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#query_project_location_vpc_flow_logs_config_org_vpc_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::QueryOrgVpcFlowLogsConfigsResponse
QueryOrgVpcFlowLogsConfigs returns a list of all organization-level VPC Flow Logs configurations applicable to the specified project.
1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1353 def query_project_location_vpc_flow_logs_config_org_vpc_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/vpcFlowLogsConfigs:queryOrgVpcFlowLogsConfigs', ) command.response_representation = Google::Apis::NetworkmanagementV1::QueryOrgVpcFlowLogsConfigsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::QueryOrgVpcFlowLogsConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#rerun_connectivity_test(name, rerun_connectivity_test_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Rerun an existing ConnectivityTest. After the user triggers the rerun, the
reachability analysis is performed as part of the long running operation,
which completes when the analysis completes. Even though the test
configuration remains the same, the reachability result may change due to
underlying network configuration changes. If the endpoint specifications in
ConnectivityTest become invalid (for example, specified resources are deleted
in the network, or you lost read permissions to the network configurations of
listed projects), then the reachability result returns a value of UNKNOWN.
872 873 874 875 876 877 878 879 880 881 882 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 872 def rerun_connectivity_test(name, rerun_connectivity_test_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:rerun', ) command.request_representation = Google::Apis::NetworkmanagementV1::RerunConnectivityTestRequest::Representation command.request_object = rerun_connectivity_test_request_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_connectivity_test_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
909 910 911 912 913 914 915 916 917 918 919 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 909 def set_connectivity_test_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::NetworkmanagementV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::NetworkmanagementV1::Policy::Representation command.response_class = Google::Apis::NetworkmanagementV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#show_project_location_vpc_flow_logs_config_effective_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, resource: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ShowEffectiveFlowLogsConfigsResponse
ShowEffectiveFlowLogsConfigs returns a list of all VPC Flow Logs configurations applicable to a specified resource.
1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1401 def show_project_location_vpc_flow_logs_config_effective_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, resource: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/vpcFlowLogsConfigs:showEffectiveFlowLogsConfigs', ) command.response_representation = Google::Apis::NetworkmanagementV1::ShowEffectiveFlowLogsConfigsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ShowEffectiveFlowLogsConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_connectivity_test_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
948 949 950 951 952 953 954 955 956 957 958 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 948 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::NetworkmanagementV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::NetworkmanagementV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |