Class: Google::Apis::NetworkmanagementV1::NetworkPath

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

Message describing NetworkPath resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPath

Returns a new instance of NetworkPath.



2976
2977
2978
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2976

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the NetworkPath was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2890
2891
2892
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2890

def create_time
  @create_time
end

#destinationString

Output only. IP address or hostname of the network path destination. Corresponds to the JSON property destination

Returns:

  • (String)


2895
2896
2897
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2895

def destination
  @destination
end

#destination_geo_locationGoogle::Apis::NetworkmanagementV1::GeoLocation

The geographical location of the MonitoringPoint. Corresponds to the JSON property destinationGeoLocation



2900
2901
2902
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2900

def destination_geo_location
  @destination_geo_location
end

#destination_monitoring_point_idString

Output only. Provider's UUID of the destination MonitoringPoint. This id may not point to a resource in the Google Cloud. Corresponds to the JSON property destinationMonitoringPointId

Returns:

  • (String)


2906
2907
2908
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2906

def destination_monitoring_point_id
  @destination_monitoring_point_id
end

#display_nameString

Output only. The display name of the network path. Corresponds to the JSON property displayName

Returns:

  • (String)


2911
2912
2913
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2911

def display_name
  @display_name
end

#dual_endedBoolean Also known as: dual_ended?

Output only. Indicates if the network path is dual ended. When true, the network path is measured both: from both source to destination, and from destination to source. When false, the network path is measured from the source through the destination back to the source (round trip measurement). Corresponds to the JSON property dualEnded

Returns:

  • (Boolean)


2919
2920
2921
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2919

def dual_ended
  @dual_ended
end

#monitoring_enabledBoolean Also known as: monitoring_enabled?

Output only. Is monitoring enabled for the network path. Corresponds to the JSON property monitoringEnabled

Returns:

  • (Boolean)


2925
2926
2927
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2925

def monitoring_enabled
  @monitoring_enabled
end

#monitoring_policy_display_nameString

Output only. Display name of the monitoring policy. Corresponds to the JSON property monitoringPolicyDisplayName

Returns:

  • (String)


2931
2932
2933
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2931

def monitoring_policy_display_name
  @monitoring_policy_display_name
end

#monitoring_policy_idString

Output only. ID of monitoring policy. Corresponds to the JSON property monitoringPolicyId

Returns:

  • (String)


2936
2937
2938
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2936

def monitoring_policy_id
  @monitoring_policy_id
end

#monitoring_statusString

Output only. The monitoring status of the network path. Corresponds to the JSON property monitoringStatus

Returns:

  • (String)


2941
2942
2943
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2941

def monitoring_status
  @monitoring_status
end

#nameString

Identifier. Name of the resource. Format: projects/project/locations/ location/networkMonitoringProviders/network_monitoring_provider/ networkPaths/network_path` Corresponds to the JSON propertyname`

Returns:

  • (String)


2948
2949
2950
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2948

def name
  @name
end

#network_protocolString

Output only. The network protocol of the network path. Corresponds to the JSON property networkProtocol

Returns:

  • (String)


2953
2954
2955
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2953

def network_protocol
  @network_protocol
end

#provider_tagsArray<Google::Apis::NetworkmanagementV1::ProviderTag>

Output only. The provider tags of the network path. Corresponds to the JSON property providerTags



2958
2959
2960
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2958

def provider_tags
  @provider_tags
end

#provider_ui_uriString

Output only. Link to provider's UI; link shows the NetworkPath. Corresponds to the JSON property providerUiUri

Returns:

  • (String)


2963
2964
2965
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2963

def provider_ui_uri
  @provider_ui_uri
end

#source_monitoring_point_idString

Output only. Provider's UUID of the source MonitoringPoint. This id may not point to a resource in the Google Cloud. Corresponds to the JSON property sourceMonitoringPointId

Returns:

  • (String)


2969
2970
2971
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2969

def source_monitoring_point_id
  @source_monitoring_point_id
end

#update_timeString

Output only. The time the NetworkPath was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2974
2975
2976
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2974

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
2998
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2981

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destination = args[:destination] if args.key?(:destination)
  @destination_geo_location = args[:destination_geo_location] if args.key?(:destination_geo_location)
  @destination_monitoring_point_id = args[:destination_monitoring_point_id] if args.key?(:destination_monitoring_point_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @dual_ended = args[:dual_ended] if args.key?(:dual_ended)
  @monitoring_enabled = args[:monitoring_enabled] if args.key?(:monitoring_enabled)
  @monitoring_policy_display_name = args[:monitoring_policy_display_name] if args.key?(:monitoring_policy_display_name)
  @monitoring_policy_id = args[:monitoring_policy_id] if args.key?(:monitoring_policy_id)
  @monitoring_status = args[:monitoring_status] if args.key?(:monitoring_status)
  @name = args[:name] if args.key?(:name)
  @network_protocol = args[:network_protocol] if args.key?(:network_protocol)
  @provider_tags = args[:provider_tags] if args.key?(:provider_tags)
  @provider_ui_uri = args[:provider_ui_uri] if args.key?(:provider_ui_uri)
  @source_monitoring_point_id = args[:source_monitoring_point_id] if args.key?(:source_monitoring_point_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end