Class: Google::Apis::NetworkmanagementV1::NgfwPacketInspectionInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::NgfwPacketInspectionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a layer 7 packet inspection by the firewall.
Instance Attribute Summary collapse
-
#security_profile_group_uri ⇒ String
URI of the security profile group associated with this firewall packet inspection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NgfwPacketInspectionInfo
constructor
A new instance of NgfwPacketInspectionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NgfwPacketInspectionInfo
Returns a new instance of NgfwPacketInspectionInfo.
2881 2882 2883 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2881 def initialize(**args) update!(**args) end |
Instance Attribute Details
#security_profile_group_uri ⇒ String
URI of the security profile group associated with this firewall packet
inspection.
Corresponds to the JSON property securityProfileGroupUri
2879 2880 2881 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2879 def security_profile_group_uri @security_profile_group_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2886 2887 2888 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2886 def update!(**args) @security_profile_group_uri = args[:security_profile_group_uri] if args.key?(:security_profile_group_uri) end |