Class: Google::Apis::NetworkmanagementV1::ProbingDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

Results of active probing from the last run of the test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProbingDetails

Returns a new instance of ProbingDetails.



3325
3326
3327
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abort_causeString

The reason probing was aborted. Corresponds to the JSON property abortCause

Returns:

  • (String)


3264
3265
3266
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3264

def abort_cause
  @abort_cause
end

#destination_egress_locationGoogle::Apis::NetworkmanagementV1::EdgeLocation

Representation of a network edge location as per https://cloud.google.com/vpc/ docs/edge-locations. Corresponds to the JSON property destinationEgressLocation



3270
3271
3272
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3270

def destination_egress_location
  @destination_egress_location
end

#edge_responsesArray<Google::Apis::NetworkmanagementV1::SingleEdgeResponse>

Probing results for all edge devices. Corresponds to the JSON property edgeResponses



3275
3276
3277
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3275

def edge_responses
  @edge_responses
end

#endpoint_infoGoogle::Apis::NetworkmanagementV1::EndpointInfo

For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model. Corresponds to the JSON property endpointInfo



3282
3283
3284
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3282

def endpoint_info
  @endpoint_info
end

#errorGoogle::Apis::NetworkmanagementV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3292
3293
3294
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3292

def error
  @error
end

#probed_all_devicesBoolean Also known as: probed_all_devices?

Whether all relevant edge devices were probed. Corresponds to the JSON property probedAllDevices

Returns:

  • (Boolean)


3297
3298
3299
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3297

def probed_all_devices
  @probed_all_devices
end

#probing_latencyGoogle::Apis::NetworkmanagementV1::LatencyDistribution

Describes measured latency distribution. Corresponds to the JSON property probingLatency



3303
3304
3305
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3303

def probing_latency
  @probing_latency
end

#resultString

The overall result of active probing. Corresponds to the JSON property result

Returns:

  • (String)


3308
3309
3310
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3308

def result
  @result
end

#sent_probe_countFixnum

Number of probes sent. Corresponds to the JSON property sentProbeCount

Returns:

  • (Fixnum)


3313
3314
3315
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3313

def sent_probe_count
  @sent_probe_count
end

#successful_probe_countFixnum

Number of probes that reached the destination. Corresponds to the JSON property successfulProbeCount

Returns:

  • (Fixnum)


3318
3319
3320
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3318

def successful_probe_count
  @successful_probe_count
end

#verify_timeString

The time that reachability was assessed through active probing. Corresponds to the JSON property verifyTime

Returns:

  • (String)


3323
3324
3325
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3323

def verify_time
  @verify_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3330

def update!(**args)
  @abort_cause = args[:abort_cause] if args.key?(:abort_cause)
  @destination_egress_location = args[:destination_egress_location] if args.key?(:destination_egress_location)
  @edge_responses = args[:edge_responses] if args.key?(:edge_responses)
  @endpoint_info = args[:endpoint_info] if args.key?(:endpoint_info)
  @error = args[:error] if args.key?(:error)
  @probed_all_devices = args[:probed_all_devices] if args.key?(:probed_all_devices)
  @probing_latency = args[:probing_latency] if args.key?(:probing_latency)
  @result = args[:result] if args.key?(:result)
  @sent_probe_count = args[:sent_probe_count] if args.key?(:sent_probe_count)
  @successful_probe_count = args[:successful_probe_count] if args.key?(:successful_probe_count)
  @verify_time = args[:verify_time] if args.key?(:verify_time)
end