Class: Google::Apis::NetworkmanagementV1::ReachabilityDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

Results of the configuration analysis from the last run of the test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReachabilityDetails

Returns a new instance of ReachabilityDetails.



3520
3521
3522
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::NetworkmanagementV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3501
3502
3503
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3501

def error
  @error
end

#resultString

The overall result of the test's configuration analysis. Corresponds to the JSON property result

Returns:

  • (String)


3506
3507
3508
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3506

def result
  @result
end

#tracesArray<Google::Apis::NetworkmanagementV1::Trace>

Result may contain a list of traces if a test has multiple possible paths in the network, such as when destination endpoint is a load balancer with multiple backends. Corresponds to the JSON property traces



3513
3514
3515
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3513

def traces
  @traces
end

#verify_timeString

The time of the configuration analysis. Corresponds to the JSON property verifyTime

Returns:

  • (String)


3518
3519
3520
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3518

def verify_time
  @verify_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3525
3526
3527
3528
3529
3530
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3525

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @result = args[:result] if args.key?(:result)
  @traces = args[:traces] if args.key?(:traces)
  @verify_time = args[:verify_time] if args.key?(:verify_time)
end