Class: Google::Apis::NetworkmanagementV1::RedisClusterInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Redis Cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RedisClusterInfo

Returns a new instance of RedisClusterInfo.



3570
3571
3572
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discovery_endpoint_ip_addressString

Discovery endpoint IP address of a Redis Cluster. Corresponds to the JSON property discoveryEndpointIpAddress

Returns:

  • (String)


3540
3541
3542
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3540

def discovery_endpoint_ip_address
  @discovery_endpoint_ip_address
end

#display_nameString

Name of a Redis Cluster. Corresponds to the JSON property displayName

Returns:

  • (String)


3545
3546
3547
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3545

def display_name
  @display_name
end

#locationString

Name of the region in which the Redis Cluster is defined. For example, "us- central1". Corresponds to the JSON property location

Returns:

  • (String)


3551
3552
3553
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3551

def location
  @location
end

#network_uriString

URI of the network containing the Redis Cluster endpoints in format "projects/ project_id/global/networks/network_id". Corresponds to the JSON property networkUri

Returns:

  • (String)


3557
3558
3559
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3557

def network_uri
  @network_uri
end

#secondary_endpoint_ip_addressString

Secondary endpoint IP address of a Redis Cluster. Corresponds to the JSON property secondaryEndpointIpAddress

Returns:

  • (String)


3562
3563
3564
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3562

def secondary_endpoint_ip_address
  @secondary_endpoint_ip_address
end

#uriString

URI of a Redis Cluster in format "projects/project_id/locations/location/ clusters/cluster_id" Corresponds to the JSON property uri

Returns:

  • (String)


3568
3569
3570
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3568

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3575
3576
3577
3578
3579
3580
3581
3582
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3575

def update!(**args)
  @discovery_endpoint_ip_address = args[:discovery_endpoint_ip_address] if args.key?(:discovery_endpoint_ip_address)
  @display_name = args[:display_name] if args.key?(:display_name)
  @location = args[:location] if args.key?(:location)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @secondary_endpoint_ip_address = args[:secondary_endpoint_ip_address] if args.key?(:secondary_endpoint_ip_address)
  @uri = args[:uri] if args.key?(:uri)
end