Class: Google::Apis::NetworkmanagementV1::RedisInstanceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Cloud Redis Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RedisInstanceInfo

Returns a new instance of RedisInstanceInfo.



3621
3622
3623
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a Cloud Redis Instance. Corresponds to the JSON property displayName

Returns:

  • (String)


3592
3593
3594
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3592

def display_name
  @display_name
end

#network_uriString

URI of a Cloud Redis Instance network in format "projects/project/global/ networks/network". Corresponds to the JSON property networkUri

Returns:

  • (String)


3598
3599
3600
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3598

def network_uri
  @network_uri
end

#primary_endpoint_ipString

Primary endpoint IP address of a Cloud Redis Instance. Corresponds to the JSON property primaryEndpointIp

Returns:

  • (String)


3603
3604
3605
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3603

def primary_endpoint_ip
  @primary_endpoint_ip
end

#read_endpoint_ipString

Read endpoint IP address of a Cloud Redis Instance (if applicable). Corresponds to the JSON property readEndpointIp

Returns:

  • (String)


3608
3609
3610
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3608

def read_endpoint_ip
  @read_endpoint_ip
end

#regionString

Region in which the Cloud Redis Instance is defined. Corresponds to the JSON property region

Returns:

  • (String)


3613
3614
3615
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3613

def region
  @region
end

#uriString

URI of a Cloud Redis Instance in format "projects/project/locations/ location/instances/instance" Corresponds to the JSON property uri

Returns:

  • (String)


3619
3620
3621
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3619

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3626
3627
3628
3629
3630
3631
3632
3633
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3626

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @primary_endpoint_ip = args[:primary_endpoint_ip] if args.key?(:primary_endpoint_ip)
  @read_endpoint_ip = args[:read_endpoint_ip] if args.key?(:read_endpoint_ip)
  @region = args[:region] if args.key?(:region)
  @uri = args[:uri] if args.key?(:uri)
end