Class: Google::Apis::NetworkmanagementV1::ShowEffectiveFlowLogsConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ShowEffectiveFlowLogsConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Response for the ShowEffectiveFlowLogsConfigs method.
Instance Attribute Summary collapse
-
#effective_flow_logs_configs ⇒ Array<Google::Apis::NetworkmanagementV1::EffectiveVpcFlowLogsConfig>
List of Effective Vpc Flow Logs configurations.
-
#next_page_token ⇒ String
Page token to fetch the next set of configurations.
-
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with
-).
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShowEffectiveFlowLogsConfigsResponse
constructor
A new instance of ShowEffectiveFlowLogsConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShowEffectiveFlowLogsConfigsResponse
Returns a new instance of ShowEffectiveFlowLogsConfigsResponse.
3054 3055 3056 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_flow_logs_configs ⇒ Array<Google::Apis::NetworkmanagementV1::EffectiveVpcFlowLogsConfig>
List of Effective Vpc Flow Logs configurations.
Corresponds to the JSON property effectiveFlowLogsConfigs
3042 3043 3044 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3042 def effective_flow_logs_configs @effective_flow_logs_configs end |
#next_page_token ⇒ String
Page token to fetch the next set of configurations.
Corresponds to the JSON property nextPageToken
3047 3048 3049 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3047 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with -).
Corresponds to the JSON property unreachable
3052 3053 3054 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3052 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3059 3060 3061 3062 3063 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3059 def update!(**args) @effective_flow_logs_configs = args[:effective_flow_logs_configs] if args.key?(:effective_flow_logs_configs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |