Class: Google::Apis::NetworkmanagementV1::SingleEdgeResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

Probing results for a single edge device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SingleEdgeResponse

Returns a new instance of SingleEdgeResponse.



3975
3976
3977
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_egress_locationGoogle::Apis::NetworkmanagementV1::EdgeLocation

Representation of a network edge location as per https://cloud.google.com/vpc/ docs/edge-locations. Corresponds to the JSON property destinationEgressLocation



3947
3948
3949
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3947

def destination_egress_location
  @destination_egress_location
end

#destination_routerString

Router name in the format 'router.metroshard'. For example: pf01.aaa01, pr02.aaa01. Corresponds to the JSON property destinationRouter

Returns:

  • (String)


3953
3954
3955
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3953

def destination_router
  @destination_router
end

#probing_latencyGoogle::Apis::NetworkmanagementV1::LatencyDistribution

Describes measured latency distribution. Corresponds to the JSON property probingLatency



3958
3959
3960
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3958

def probing_latency
  @probing_latency
end

#resultString

The overall result of active probing for this egress device. Corresponds to the JSON property result

Returns:

  • (String)


3963
3964
3965
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3963

def result
  @result
end

#sent_probe_countFixnum

Number of probes sent. Corresponds to the JSON property sentProbeCount

Returns:

  • (Fixnum)


3968
3969
3970
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3968

def sent_probe_count
  @sent_probe_count
end

#successful_probe_countFixnum

Number of probes that reached the destination. Corresponds to the JSON property successfulProbeCount

Returns:

  • (Fixnum)


3973
3974
3975
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3973

def successful_probe_count
  @successful_probe_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3980
3981
3982
3983
3984
3985
3986
3987
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3980

def update!(**args)
  @destination_egress_location = args[:destination_egress_location] if args.key?(:destination_egress_location)
  @destination_router = args[:destination_router] if args.key?(:destination_router)
  @probing_latency = args[:probing_latency] if args.key?(:probing_latency)
  @result = args[:result] if args.key?(:result)
  @sent_probe_count = args[:sent_probe_count] if args.key?(:sent_probe_count)
  @successful_probe_count = args[:successful_probe_count] if args.key?(:successful_probe_count)
end