Class: Google::Apis::NetworkmanagementV1::ViewerPermissionMissingInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a step that was redacted due to missing permissions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ViewerPermissionMissingInfo

Returns a new instance of ViewerPermissionMissingInfo.



4452
4453
4454
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_typesArray<String>

Types of the resources that the user does not have permission to view. Corresponds to the JSON property resourceTypes

Returns:

  • (Array<String>)


4450
4451
4452
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4450

def resource_types
  @resource_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4457
4458
4459
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4457

def update!(**args)
  @resource_types = args[:resource_types] if args.key?(:resource_types)
end