Class: Google::Apis::NetworkmanagementV1::VpnGatewayInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine VPN gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayInfo

Returns a new instance of VpnGatewayInfo.



4627
4628
4629
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4627

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a VPN gateway. Corresponds to the JSON property displayName

Returns:

  • (String)


4593
4594
4595
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4593

def display_name
  @display_name
end

#ip_addressString

IP address of the VPN gateway. Corresponds to the JSON property ipAddress

Returns:

  • (String)


4598
4599
4600
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4598

def ip_address
  @ip_address
end

#network_uriString

URI of the VPC network where the VPN gateway is configured. Format: projects/ project_id/global/networks/network_id` Corresponds to the JSON propertynetworkUri`

Returns:

  • (String)


4604
4605
4606
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4604

def network_uri
  @network_uri
end

#regionString

Name of a Google Cloud region where this VPN gateway is configured. Corresponds to the JSON property region

Returns:

  • (String)


4609
4610
4611
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4609

def region
  @region
end

#uriString

URI of the VPN gateway. Format: * projects/project_id/regions/region/ vpnGateways/vpn_gateway_id(HA VPN gateway) * `projects/`project_id`/ regions/`region`/targetVpnGateways/`target_vpn_gateway_id (Classic VPN gateway) Corresponds to the JSON property uri

Returns:

  • (String)


4617
4618
4619
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4617

def uri
  @uri
end

#vpn_tunnel_uriString

URI of the VPN tunnel associated with the VPN gateway. There may be multiple VPN tunnels configured on a VPN gateway, and only the one relevant to the test is displayed. Format: projects/project_id/regions/region/vpnTunnels/ vpn_tunnel_id` Corresponds to the JSON propertyvpnTunnelUri`

Returns:

  • (String)


4625
4626
4627
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4625

def vpn_tunnel_uri
  @vpn_tunnel_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4632
4633
4634
4635
4636
4637
4638
4639
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4632

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @region = args[:region] if args.key?(:region)
  @uri = args[:uri] if args.key?(:uri)
  @vpn_tunnel_uri = args[:vpn_tunnel_uri] if args.key?(:vpn_tunnel_uri)
end