Class: Google::Apis::NetworkmanagementV1::VpnTunnelInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::VpnTunnelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine VPN tunnel.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a VPN tunnel.
-
#network_uri ⇒ String
URI of the VPC network where the VPN tunnel is configured.
-
#region ⇒ String
Name of a Google Cloud region where this VPN tunnel is configured.
-
#remote_gateway ⇒ String
URI of a VPN gateway at remote end of the tunnel.
-
#remote_gateway_ip ⇒ String
Remote VPN gateway's IP address.
-
#routing_type ⇒ String
Type of the routing policy.
-
#source_gateway ⇒ String
URI of the VPN gateway at local end of the tunnel.
-
#source_gateway_ip ⇒ String
Local VPN gateway's IP address.
-
#uri ⇒ String
URI of the VPN tunnel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnelInfo
constructor
A new instance of VpnTunnelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnelInfo
Returns a new instance of VpnTunnelInfo.
4699 4700 4701 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4699 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a VPN tunnel.
Corresponds to the JSON property displayName
4649 4650 4651 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4649 def display_name @display_name end |
#network_uri ⇒ String
URI of the VPC network where the VPN tunnel is configured. Format: projects/
project_id/global/networks/network_id`
Corresponds to the JSON propertynetworkUri`
4655 4656 4657 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4655 def network_uri @network_uri end |
#region ⇒ String
Name of a Google Cloud region where this VPN tunnel is configured.
Corresponds to the JSON property region
4660 4661 4662 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4660 def region @region end |
#remote_gateway ⇒ String
URI of a VPN gateway at remote end of the tunnel. Format: * projects/
project_id/regions/region/vpnGateways/vpn_gateway_id`` (GCP HA VPN gateway)
projects/project_id/global/peerVpnGateways/peer_vpn_gateway_id`(GCP peer VPN gateway) Corresponds to the JSON propertyremoteGateway`
4668 4669 4670 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4668 def remote_gateway @remote_gateway end |
#remote_gateway_ip ⇒ String
Remote VPN gateway's IP address.
Corresponds to the JSON property remoteGatewayIp
4673 4674 4675 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4673 def remote_gateway_ip @remote_gateway_ip end |
#routing_type ⇒ String
Type of the routing policy.
Corresponds to the JSON property routingType
4678 4679 4680 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4678 def routing_type @routing_type end |
#source_gateway ⇒ String
URI of the VPN gateway at local end of the tunnel. Format: * projects/
project_id/regions/region/vpnGateways/vpn_gateway_id(HA VPN gateway) * `
projects/`project_id`/regions/`region`/targetVpnGateways/`
target_vpn_gateway_id (Classic VPN gateway)
Corresponds to the JSON property sourceGateway
4686 4687 4688 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4686 def source_gateway @source_gateway end |
#source_gateway_ip ⇒ String
Local VPN gateway's IP address.
Corresponds to the JSON property sourceGatewayIp
4691 4692 4693 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4691 def source_gateway_ip @source_gateway_ip end |
#uri ⇒ String
URI of the VPN tunnel. Format: projects/project_id/regions/region/
vpnTunnels/vpn_tunnel_id`
Corresponds to the JSON propertyuri`
4697 4698 4699 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4697 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4704 4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4704 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @network_uri = args[:network_uri] if args.key?(:network_uri) @region = args[:region] if args.key?(:region) @remote_gateway = args[:remote_gateway] if args.key?(:remote_gateway) @remote_gateway_ip = args[:remote_gateway_ip] if args.key?(:remote_gateway_ip) @routing_type = args[:routing_type] if args.key?(:routing_type) @source_gateway = args[:source_gateway] if args.key?(:source_gateway) @source_gateway_ip = args[:source_gateway_ip] if args.key?(:source_gateway_ip) @uri = args[:uri] if args.key?(:uri) end |