Class: Google::Apis::NetworkmanagementV1::ConnectivityTest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

A Connectivity Test for a network reachability analysis.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectivityTest

Returns a new instance of ConnectivityTest.



593
594
595
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bypass_firewall_checksBoolean Also known as: bypass_firewall_checks?

Whether the analysis should skip firewall checking. Default value is false. Corresponds to the JSON property bypassFirewallChecks

Returns:

  • (Boolean)


515
516
517
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 515

def bypass_firewall_checks
  @bypass_firewall_checks
end

#create_timeString

Output only. The time the test was created. Corresponds to the JSON property createTime

Returns:

  • (String)


521
522
523
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 521

def create_time
  @create_time
end

#descriptionString

The user-supplied description of the Connectivity Test. Maximum of 512 characters. Corresponds to the JSON property description

Returns:

  • (String)


527
528
529
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 527

def description
  @description
end

#destinationGoogle::Apis::NetworkmanagementV1::Endpoint

Source or destination of the Connectivity Test. Corresponds to the JSON property destination



532
533
534
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 532

def destination
  @destination
end

#display_nameString

Output only. The display name of a Connectivity Test. Corresponds to the JSON property displayName

Returns:

  • (String)


537
538
539
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 537

def display_name
  @display_name
end

#labelsHash<String,String>

Resource labels to represent user-provided metadata. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


542
543
544
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 542

def labels
  @labels
end

#nameString

Identifier. Unique name of the resource using the form: projects/project_id/ locations/global/connectivityTests/test_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


548
549
550
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 548

def name
  @name
end

#probing_detailsGoogle::Apis::NetworkmanagementV1::ProbingDetails

Results of active probing from the last run of the test. Corresponds to the JSON property probingDetails



553
554
555
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 553

def probing_details
  @probing_details
end

#protocolString

IP Protocol of the test. When not provided, "TCP" is assumed. Corresponds to the JSON property protocol

Returns:

  • (String)


558
559
560
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 558

def protocol
  @protocol
end

#reachability_detailsGoogle::Apis::NetworkmanagementV1::ReachabilityDetails

Results of the configuration analysis from the last run of the test. Corresponds to the JSON property reachabilityDetails



563
564
565
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 563

def reachability_details
  @reachability_details
end

Other projects that may be relevant for reachability analysis. This is applicable to scenarios where a test can cross project boundaries. Corresponds to the JSON property relatedProjects

Returns:

  • (Array<String>)


569
570
571
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 569

def related_projects
  @related_projects
end

#return_reachability_detailsGoogle::Apis::NetworkmanagementV1::ReachabilityDetails

Results of the configuration analysis from the last run of the test. Corresponds to the JSON property returnReachabilityDetails



574
575
576
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 574

def return_reachability_details
  @return_reachability_details
end

#round_tripBoolean Also known as: round_trip?

Whether run analysis for the return path from destination to source. Default value is false. Corresponds to the JSON property roundTrip

Returns:

  • (Boolean)


580
581
582
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 580

def round_trip
  @round_trip
end

#sourceGoogle::Apis::NetworkmanagementV1::Endpoint

Source or destination of the Connectivity Test. Corresponds to the JSON property source



586
587
588
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 586

def source
  @source
end

#update_timeString

Output only. The time the test's configuration was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


591
592
593
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 591

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 598

def update!(**args)
  @bypass_firewall_checks = args[:bypass_firewall_checks] if args.key?(:bypass_firewall_checks)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @destination = args[:destination] if args.key?(:destination)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @probing_details = args[:probing_details] if args.key?(:probing_details)
  @protocol = args[:protocol] if args.key?(:protocol)
  @reachability_details = args[:reachability_details] if args.key?(:reachability_details)
  @related_projects = args[:related_projects] if args.key?(:related_projects)
  @return_reachability_details = args[:return_reachability_details] if args.key?(:return_reachability_details)
  @round_trip = args[:round_trip] if args.key?(:round_trip)
  @source = args[:source] if args.key?(:source)
  @update_time = args[:update_time] if args.key?(:update_time)
end