Class: Google::Apis::NetworkmanagementV1::DeliverInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::DeliverInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Details of the final state "deliver" and associated resource.
Instance Attribute Summary collapse
-
#google_service_type ⇒ String
Recognized type of a Google Service the packet is delivered to (if applicable).
-
#ip_address ⇒ String
IP address of the target (if applicable).
-
#psc_google_api_target ⇒ String
PSC Google API target the packet is delivered to (if applicable).
-
#resource_uri ⇒ String
URI of the resource that the packet is delivered to.
-
#storage_bucket ⇒ String
Name of the Cloud Storage Bucket the packet is delivered to (if applicable).
-
#target ⇒ String
Target type where the packet is delivered to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeliverInfo
constructor
A new instance of DeliverInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeliverInfo
Returns a new instance of DeliverInfo.
651 652 653 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_service_type ⇒ String
Recognized type of a Google Service the packet is delivered to (if applicable).
Corresponds to the JSON property googleServiceType
624 625 626 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 624 def google_service_type @google_service_type end |
#ip_address ⇒ String
IP address of the target (if applicable).
Corresponds to the JSON property ipAddress
629 630 631 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 629 def ip_address @ip_address end |
#psc_google_api_target ⇒ String
PSC Google API target the packet is delivered to (if applicable).
Corresponds to the JSON property pscGoogleApiTarget
634 635 636 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 634 def psc_google_api_target @psc_google_api_target end |
#resource_uri ⇒ String
URI of the resource that the packet is delivered to.
Corresponds to the JSON property resourceUri
639 640 641 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 639 def resource_uri @resource_uri end |
#storage_bucket ⇒ String
Name of the Cloud Storage Bucket the packet is delivered to (if applicable).
Corresponds to the JSON property storageBucket
644 645 646 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 644 def storage_bucket @storage_bucket end |
#target ⇒ String
Target type where the packet is delivered to.
Corresponds to the JSON property target
649 650 651 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 649 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
656 657 658 659 660 661 662 663 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 656 def update!(**args) @google_service_type = args[:google_service_type] if args.key?(:google_service_type) @ip_address = args[:ip_address] if args.key?(:ip_address) @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target) @resource_uri = args[:resource_uri] if args.key?(:resource_uri) @storage_bucket = args[:storage_bucket] if args.key?(:storage_bucket) @target = args[:target] if args.key?(:target) end |