Class: Google::Apis::NetworkmanagementV1::Endpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

Source or destination of the Connectivity Test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Endpoint

Returns a new instance of Endpoint.



1028
1029
1030
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_engine_versionGoogle::Apis::NetworkmanagementV1::AppEngineVersionEndpoint

Wrapper for the App Engine service version attributes. Corresponds to the JSON property appEngineVersion



919
920
921
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 919

def app_engine_version
  @app_engine_version
end

#cloud_functionGoogle::Apis::NetworkmanagementV1::CloudFunctionEndpoint

Wrapper for Cloud Function attributes. Corresponds to the JSON property cloudFunction



924
925
926
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 924

def cloud_function
  @cloud_function
end

#cloud_run_revisionGoogle::Apis::NetworkmanagementV1::CloudRunRevisionEndpoint

Wrapper for Cloud Run revision attributes. Corresponds to the JSON property cloudRunRevision



929
930
931
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 929

def cloud_run_revision
  @cloud_run_revision
end

#cloud_sql_instanceString

A Cloud SQL instance URI. Corresponds to the JSON property cloudSqlInstance

Returns:

  • (String)


934
935
936
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 934

def cloud_sql_instance
  @cloud_sql_instance
end

#forwarding_ruleString

A forwarding rule and its corresponding IP address represent the frontend configuration of a Google Cloud load balancer. Forwarding rules are also used for protocol forwarding, Private Service Connect and other network services to provide forwarding information in the control plane. Applicable only to destination endpoint. Format: projects/project/global/forwardingRules/id or `projects/`project`/regions/`region`/forwardingRules/`id Corresponds to the JSON property forwardingRule

Returns:

  • (String)


944
945
946
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 944

def forwarding_rule
  @forwarding_rule
end

#forwarding_rule_targetString

Output only. Specifies the type of the target of the forwarding rule. Corresponds to the JSON property forwardingRuleTarget

Returns:

  • (String)


949
950
951
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 949

def forwarding_rule_target
  @forwarding_rule_target
end

#fqdnString

DNS endpoint of Google Kubernetes Engine cluster control plane. Requires gke_master_cluster to be set, can't be used simultaneoulsly with ip_address or network. Applicable only to destination endpoint. Corresponds to the JSON property fqdn

Returns:

  • (String)


957
958
959
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 957

def fqdn
  @fqdn
end

#gke_master_clusterString

A cluster URI for Google Kubernetes Engine cluster control plane. Corresponds to the JSON property gkeMasterCluster

Returns:

  • (String)


963
964
965
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 963

def gke_master_cluster
  @gke_master_cluster
end

#gke_podString

A GKE Pod URI. Corresponds to the JSON property gkePod

Returns:

  • (String)


968
969
970
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 968

def gke_pod
  @gke_pod
end

#instanceString

A Compute Engine instance URI. Corresponds to the JSON property instance

Returns:

  • (String)


973
974
975
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 973

def instance
  @instance
end

#ip_addressString

The IP address of the endpoint, which can be an external or internal IP. Corresponds to the JSON property ipAddress

Returns:

  • (String)


978
979
980
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 978

def ip_address
  @ip_address
end

#load_balancer_idString

Output only. ID of the load balancer the forwarding rule points to. Empty for forwarding rules not related to load balancers. Corresponds to the JSON property loadBalancerId

Returns:

  • (String)


984
985
986
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 984

def load_balancer_id
  @load_balancer_id
end

#load_balancer_typeString

Output only. Type of the load balancer the forwarding rule points to. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


989
990
991
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 989

def load_balancer_type
  @load_balancer_type
end

#networkString

A VPC network URI. For source endpoints, used according to the network_type. For destination endpoints, used only when the source is an external IP address endpoint, and the destination is an internal IP address endpoint. Corresponds to the JSON property network

Returns:

  • (String)


996
997
998
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 996

def network
  @network
end

#network_typeString

For source endpoints, type of the network where the endpoint is located. Not relevant for destination endpoints. Corresponds to the JSON property networkType

Returns:

  • (String)


1002
1003
1004
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1002

def network_type
  @network_type
end

#portFixnum

The IP protocol port of the endpoint. Only applicable when protocol is TCP or UDP. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1008
1009
1010
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1008

def port
  @port
end

#project_idString

For source endpoints, endpoint project ID. Used according to the network_type . Not relevant for destination endpoints. Corresponds to the JSON property projectId

Returns:

  • (String)


1014
1015
1016
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1014

def project_id
  @project_id
end

#redis_clusterString

A Redis Cluster URI. Applicable only to destination endpoint. Corresponds to the JSON property redisCluster

Returns:

  • (String)


1020
1021
1022
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1020

def redis_cluster
  @redis_cluster
end

#redis_instanceString

A Redis Instance URI. Applicable only to destination endpoint. Corresponds to the JSON property redisInstance

Returns:

  • (String)


1026
1027
1028
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1026

def redis_instance
  @redis_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1033

def update!(**args)
  @app_engine_version = args[:app_engine_version] if args.key?(:app_engine_version)
  @cloud_function = args[:cloud_function] if args.key?(:cloud_function)
  @cloud_run_revision = args[:cloud_run_revision] if args.key?(:cloud_run_revision)
  @cloud_sql_instance = args[:cloud_sql_instance] if args.key?(:cloud_sql_instance)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @forwarding_rule_target = args[:forwarding_rule_target] if args.key?(:forwarding_rule_target)
  @fqdn = args[:fqdn] if args.key?(:fqdn)
  @gke_master_cluster = args[:gke_master_cluster] if args.key?(:gke_master_cluster)
  @gke_pod = args[:gke_pod] if args.key?(:gke_pod)
  @instance = args[:instance] if args.key?(:instance)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @load_balancer_id = args[:load_balancer_id] if args.key?(:load_balancer_id)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
  @network = args[:network] if args.key?(:network)
  @network_type = args[:network_type] if args.key?(:network_type)
  @port = args[:port] if args.key?(:port)
  @project_id = args[:project_id] if args.key?(:project_id)
  @redis_cluster = args[:redis_cluster] if args.key?(:redis_cluster)
  @redis_instance = args[:redis_instance] if args.key?(:redis_instance)
end