Class: Google::Apis::NetworkmanagementV1::Endpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

Source or destination of the Connectivity Test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Endpoint

Returns a new instance of Endpoint.



997
998
999
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_engine_versionGoogle::Apis::NetworkmanagementV1::AppEngineVersionEndpoint

Wrapper for the App Engine service version attributes. Corresponds to the JSON property appEngineVersion



888
889
890
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 888

def app_engine_version
  @app_engine_version
end

#cloud_functionGoogle::Apis::NetworkmanagementV1::CloudFunctionEndpoint

Wrapper for Cloud Function attributes. Corresponds to the JSON property cloudFunction



893
894
895
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 893

def cloud_function
  @cloud_function
end

#cloud_run_revisionGoogle::Apis::NetworkmanagementV1::CloudRunRevisionEndpoint

Wrapper for Cloud Run revision attributes. Corresponds to the JSON property cloudRunRevision



898
899
900
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 898

def cloud_run_revision
  @cloud_run_revision
end

#cloud_sql_instanceString

A Cloud SQL instance URI. Corresponds to the JSON property cloudSqlInstance

Returns:

  • (String)


903
904
905
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 903

def cloud_sql_instance
  @cloud_sql_instance
end

#forwarding_ruleString

A forwarding rule and its corresponding IP address represent the frontend configuration of a Google Cloud load balancer. Forwarding rules are also used for protocol forwarding, Private Service Connect and other network services to provide forwarding information in the control plane. Applicable only to destination endpoint. Format: projects/project/global/forwardingRules/id or `projects/`project`/regions/`region`/forwardingRules/`id Corresponds to the JSON property forwardingRule

Returns:

  • (String)


913
914
915
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 913

def forwarding_rule
  @forwarding_rule
end

#forwarding_rule_targetString

Output only. Specifies the type of the target of the forwarding rule. Corresponds to the JSON property forwardingRuleTarget

Returns:

  • (String)


918
919
920
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 918

def forwarding_rule_target
  @forwarding_rule_target
end

#fqdnString

DNS endpoint of Google Kubernetes Engine cluster control plane. Requires gke_master_cluster to be set, can't be used simultaneoulsly with ip_address or network. Applicable only to destination endpoint. Corresponds to the JSON property fqdn

Returns:

  • (String)


926
927
928
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 926

def fqdn
  @fqdn
end

#gke_master_clusterString

A cluster URI for Google Kubernetes Engine cluster control plane. Corresponds to the JSON property gkeMasterCluster

Returns:

  • (String)


932
933
934
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 932

def gke_master_cluster
  @gke_master_cluster
end

#gke_podString

A GKE Pod URI. Corresponds to the JSON property gkePod

Returns:

  • (String)


937
938
939
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 937

def gke_pod
  @gke_pod
end

#instanceString

A Compute Engine instance URI. Corresponds to the JSON property instance

Returns:

  • (String)


942
943
944
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 942

def instance
  @instance
end

#ip_addressString

The IP address of the endpoint, which can be an external or internal IP. Corresponds to the JSON property ipAddress

Returns:

  • (String)


947
948
949
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 947

def ip_address
  @ip_address
end

#load_balancer_idString

Output only. ID of the load balancer the forwarding rule points to. Empty for forwarding rules not related to load balancers. Corresponds to the JSON property loadBalancerId

Returns:

  • (String)


953
954
955
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 953

def load_balancer_id
  @load_balancer_id
end

#load_balancer_typeString

Output only. Type of the load balancer the forwarding rule points to. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


958
959
960
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 958

def load_balancer_type
  @load_balancer_type
end

#networkString

A VPC network URI. For source endpoints, used according to the network_type. For destination endpoints, used only when the source is an external IP address endpoint, and the destination is an internal IP address endpoint. Corresponds to the JSON property network

Returns:

  • (String)


965
966
967
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 965

def network
  @network
end

#network_typeString

For source endpoints, type of the network where the endpoint is located. Not relevant for destination endpoints. Corresponds to the JSON property networkType

Returns:

  • (String)


971
972
973
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 971

def network_type
  @network_type
end

#portFixnum

The IP protocol port of the endpoint. Only applicable when protocol is TCP or UDP. Corresponds to the JSON property port

Returns:

  • (Fixnum)


977
978
979
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 977

def port
  @port
end

#project_idString

For source endpoints, endpoint project ID. Used according to the network_type . Not relevant for destination endpoints. Corresponds to the JSON property projectId

Returns:

  • (String)


983
984
985
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 983

def project_id
  @project_id
end

#redis_clusterString

A Redis Cluster URI. Applicable only to destination endpoint. Corresponds to the JSON property redisCluster

Returns:

  • (String)


989
990
991
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 989

def redis_cluster
  @redis_cluster
end

#redis_instanceString

A Redis Instance URI. Applicable only to destination endpoint. Corresponds to the JSON property redisInstance

Returns:

  • (String)


995
996
997
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 995

def redis_instance
  @redis_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1002

def update!(**args)
  @app_engine_version = args[:app_engine_version] if args.key?(:app_engine_version)
  @cloud_function = args[:cloud_function] if args.key?(:cloud_function)
  @cloud_run_revision = args[:cloud_run_revision] if args.key?(:cloud_run_revision)
  @cloud_sql_instance = args[:cloud_sql_instance] if args.key?(:cloud_sql_instance)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @forwarding_rule_target = args[:forwarding_rule_target] if args.key?(:forwarding_rule_target)
  @fqdn = args[:fqdn] if args.key?(:fqdn)
  @gke_master_cluster = args[:gke_master_cluster] if args.key?(:gke_master_cluster)
  @gke_pod = args[:gke_pod] if args.key?(:gke_pod)
  @instance = args[:instance] if args.key?(:instance)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @load_balancer_id = args[:load_balancer_id] if args.key?(:load_balancer_id)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
  @network = args[:network] if args.key?(:network)
  @network_type = args[:network_type] if args.key?(:network_type)
  @port = args[:port] if args.key?(:port)
  @project_id = args[:project_id] if args.key?(:project_id)
  @redis_cluster = args[:redis_cluster] if args.key?(:redis_cluster)
  @redis_instance = args[:redis_instance] if args.key?(:redis_instance)
end