Class: Google::Apis::NetworkmanagementV1::EndpointInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::EndpointInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model.
Instance Attribute Summary collapse
-
#destination_ip ⇒ String
Destination IP address.
-
#destination_network_uri ⇒ String
URI of the network where this packet is sent to.
-
#destination_port ⇒ Fixnum
Destination port.
-
#protocol ⇒ String
IP protocol in string format, for example: "TCP", "UDP", "ICMP".
-
#source_agent_uri ⇒ String
URI of the source telemetry agent this packet originates from.
-
#source_ip ⇒ String
Source IP address.
-
#source_network_uri ⇒ String
URI of the network where this packet originates from.
-
#source_port ⇒ Fixnum
Source port.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EndpointInfo
constructor
A new instance of EndpointInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EndpointInfo
Returns a new instance of EndpointInfo.
1134 1135 1136 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1134 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_ip ⇒ String
Destination IP address.
Corresponds to the JSON property destinationIp
1095 1096 1097 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1095 def destination_ip @destination_ip end |
#destination_network_uri ⇒ String
URI of the network where this packet is sent to. Format: projects/project_id
/global/networks/network_id`
Corresponds to the JSON propertydestinationNetworkUri`
1101 1102 1103 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1101 def destination_network_uri @destination_network_uri end |
#destination_port ⇒ Fixnum
Destination port. Only valid when protocol is TCP or UDP.
Corresponds to the JSON property destinationPort
1106 1107 1108 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1106 def destination_port @destination_port end |
#protocol ⇒ String
IP protocol in string format, for example: "TCP", "UDP", "ICMP".
Corresponds to the JSON property protocol
1111 1112 1113 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1111 def protocol @protocol end |
#source_agent_uri ⇒ String
URI of the source telemetry agent this packet originates from.
Corresponds to the JSON property sourceAgentUri
1116 1117 1118 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1116 def source_agent_uri @source_agent_uri end |
#source_ip ⇒ String
Source IP address.
Corresponds to the JSON property sourceIp
1121 1122 1123 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1121 def source_ip @source_ip end |
#source_network_uri ⇒ String
URI of the network where this packet originates from. Format: projects/
project_id/global/networks/network_id`
Corresponds to the JSON propertysourceNetworkUri`
1127 1128 1129 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1127 def source_network_uri @source_network_uri end |
#source_port ⇒ Fixnum
Source port. Only valid when protocol is TCP or UDP.
Corresponds to the JSON property sourcePort
1132 1133 1134 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1132 def source_port @source_port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1139 def update!(**args) @destination_ip = args[:destination_ip] if args.key?(:destination_ip) @destination_network_uri = args[:destination_network_uri] if args.key?(:destination_network_uri) @destination_port = args[:destination_port] if args.key?(:destination_port) @protocol = args[:protocol] if args.key?(:protocol) @source_agent_uri = args[:source_agent_uri] if args.key?(:source_agent_uri) @source_ip = args[:source_ip] if args.key?(:source_ip) @source_network_uri = args[:source_network_uri] if args.key?(:source_network_uri) @source_port = args[:source_port] if args.key?(:source_port) end |