Class: Google::Apis::NetworkmanagementV1::EndpointInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. The specification of the endpoints for the test. EndpointInfo is derived from source and destination Endpoint and validated by the backend data plane model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndpointInfo

Returns a new instance of EndpointInfo.



1071
1072
1073
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_ipString

Destination IP address. Corresponds to the JSON property destinationIp

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1034

def destination_ip
  @destination_ip
end

#destination_network_uriString

URI of the network where this packet is sent to. Corresponds to the JSON property destinationNetworkUri

Returns:

  • (String)


1039
1040
1041
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1039

def destination_network_uri
  @destination_network_uri
end

#destination_portFixnum

Destination port. Only valid when protocol is TCP or UDP. Corresponds to the JSON property destinationPort

Returns:

  • (Fixnum)


1044
1045
1046
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1044

def destination_port
  @destination_port
end

#protocolString

IP protocol in string format, for example: "TCP", "UDP", "ICMP". Corresponds to the JSON property protocol

Returns:

  • (String)


1049
1050
1051
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1049

def protocol
  @protocol
end

#source_agent_uriString

URI of the source telemetry agent this packet originates from. Corresponds to the JSON property sourceAgentUri

Returns:

  • (String)


1054
1055
1056
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1054

def source_agent_uri
  @source_agent_uri
end

#source_ipString

Source IP address. Corresponds to the JSON property sourceIp

Returns:

  • (String)


1059
1060
1061
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1059

def source_ip
  @source_ip
end

#source_network_uriString

URI of the network where this packet originates from. Corresponds to the JSON property sourceNetworkUri

Returns:

  • (String)


1064
1065
1066
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1064

def source_network_uri
  @source_network_uri
end

#source_portFixnum

Source port. Only valid when protocol is TCP or UDP. Corresponds to the JSON property sourcePort

Returns:

  • (Fixnum)


1069
1070
1071
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1069

def source_port
  @source_port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1076

def update!(**args)
  @destination_ip = args[:destination_ip] if args.key?(:destination_ip)
  @destination_network_uri = args[:destination_network_uri] if args.key?(:destination_network_uri)
  @destination_port = args[:destination_port] if args.key?(:destination_port)
  @protocol = args[:protocol] if args.key?(:protocol)
  @source_agent_uri = args[:source_agent_uri] if args.key?(:source_agent_uri)
  @source_ip = args[:source_ip] if args.key?(:source_ip)
  @source_network_uri = args[:source_network_uri] if args.key?(:source_network_uri)
  @source_port = args[:source_port] if args.key?(:source_port)
end