Class: Google::Apis::NetworkmanagementV1::FirewallInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::FirewallInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a VPC firewall rule, an implied VPC firewall rule, or a firewall policy rule.
Instance Attribute Summary collapse
-
#action ⇒ String
Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP Corresponds to the JSON property
action. -
#direction ⇒ String
Possible values: INGRESS, EGRESS Corresponds to the JSON property
direction. -
#display_name ⇒ String
The display name of the firewall rule.
-
#firewall_rule_type ⇒ String
The firewall rule's type.
-
#network_uri ⇒ String
The URI of the VPC network that the firewall rule is associated with.
-
#policy ⇒ String
The name of the firewall policy that this rule is associated with.
-
#policy_priority ⇒ Fixnum
The priority of the firewall policy that this rule is associated with.
-
#policy_uri ⇒ String
The URI of the firewall policy that this rule is associated with.
-
#priority ⇒ Fixnum
The priority of the firewall rule.
-
#target_service_accounts ⇒ Array<String>
The target service accounts specified by the firewall rule.
-
#target_tags ⇒ Array<String>
The target tags defined by the VPC firewall rule.
-
#target_type ⇒ String
Target type of the firewall rule.
-
#uri ⇒ String
The URI of the firewall rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallInfo
constructor
A new instance of FirewallInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallInfo
Returns a new instance of FirewallInfo.
1259 1260 1261 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1259 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP
Corresponds to the JSON property action
1190 1191 1192 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1190 def action @action end |
#direction ⇒ String
Possible values: INGRESS, EGRESS
Corresponds to the JSON property direction
1195 1196 1197 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1195 def direction @direction end |
#display_name ⇒ String
The display name of the firewall rule. This field might be empty for firewall
policy rules.
Corresponds to the JSON property displayName
1201 1202 1203 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1201 def display_name @display_name end |
#firewall_rule_type ⇒ String
The firewall rule's type.
Corresponds to the JSON property firewallRuleType
1206 1207 1208 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1206 def firewall_rule_type @firewall_rule_type end |
#network_uri ⇒ String
The URI of the VPC network that the firewall rule is associated with. This
field is not applicable to hierarchical firewall policy rules.
Corresponds to the JSON property networkUri
1212 1213 1214 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1212 def network_uri @network_uri end |
#policy ⇒ String
The name of the firewall policy that this rule is associated with. This field
is not applicable to VPC firewall rules and implied VPC firewall rules.
Corresponds to the JSON property policy
1218 1219 1220 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1218 def policy @policy end |
#policy_priority ⇒ Fixnum
The priority of the firewall policy that this rule is associated with. This
field is not applicable to VPC firewall rules and implied VPC firewall rules.
Corresponds to the JSON property policyPriority
1224 1225 1226 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1224 def policy_priority @policy_priority end |
#policy_uri ⇒ String
The URI of the firewall policy that this rule is associated with. This field
is not applicable to VPC firewall rules and implied VPC firewall rules.
Corresponds to the JSON property policyUri
1230 1231 1232 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1230 def policy_uri @policy_uri end |
#priority ⇒ Fixnum
The priority of the firewall rule.
Corresponds to the JSON property priority
1235 1236 1237 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1235 def priority @priority end |
#target_service_accounts ⇒ Array<String>
The target service accounts specified by the firewall rule.
Corresponds to the JSON property targetServiceAccounts
1240 1241 1242 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1240 def target_service_accounts @target_service_accounts end |
#target_tags ⇒ Array<String>
The target tags defined by the VPC firewall rule. This field is not applicable
to firewall policy rules.
Corresponds to the JSON property targetTags
1246 1247 1248 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1246 def @target_tags end |
#target_type ⇒ String
Target type of the firewall rule.
Corresponds to the JSON property targetType
1251 1252 1253 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1251 def target_type @target_type end |
#uri ⇒ String
The URI of the firewall rule. This field is not applicable to implied VPC
firewall rules.
Corresponds to the JSON property uri
1257 1258 1259 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1257 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1264 def update!(**args) @action = args[:action] if args.key?(:action) @direction = args[:direction] if args.key?(:direction) @display_name = args[:display_name] if args.key?(:display_name) @firewall_rule_type = args[:firewall_rule_type] if args.key?(:firewall_rule_type) @network_uri = args[:network_uri] if args.key?(:network_uri) @policy = args[:policy] if args.key?(:policy) @policy_priority = args[:policy_priority] if args.key?(:policy_priority) @policy_uri = args[:policy_uri] if args.key?(:policy_uri) @priority = args[:priority] if args.key?(:priority) @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts) @target_tags = args[:target_tags] if args.key?(:target_tags) @target_type = args[:target_type] if args.key?(:target_type) @uri = args[:uri] if args.key?(:uri) end |