Class: Google::Apis::NetworkmanagementV1::FirewallInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a VPC firewall rule, an implied VPC firewall rule, or a firewall policy rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallInfo

Returns a new instance of FirewallInfo.



1250
1251
1252
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP Corresponds to the JSON property action

Returns:

  • (String)


1181
1182
1183
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1181

def action
  @action
end

#directionString

Possible values: INGRESS, EGRESS Corresponds to the JSON property direction

Returns:

  • (String)


1186
1187
1188
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1186

def direction
  @direction
end

#display_nameString

The display name of the firewall rule. This field might be empty for firewall policy rules. Corresponds to the JSON property displayName

Returns:

  • (String)


1192
1193
1194
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1192

def display_name
  @display_name
end

#firewall_rule_typeString

The firewall rule's type. Corresponds to the JSON property firewallRuleType

Returns:

  • (String)


1197
1198
1199
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1197

def firewall_rule_type
  @firewall_rule_type
end

#network_uriString

The URI of the VPC network that the firewall rule is associated with. This field is not applicable to hierarchical firewall policy rules. Corresponds to the JSON property networkUri

Returns:

  • (String)


1203
1204
1205
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1203

def network_uri
  @network_uri
end

#policyString

The name of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules. Corresponds to the JSON property policy

Returns:

  • (String)


1209
1210
1211
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1209

def policy
  @policy
end

#policy_priorityFixnum

The priority of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules. Corresponds to the JSON property policyPriority

Returns:

  • (Fixnum)


1215
1216
1217
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1215

def policy_priority
  @policy_priority
end

#policy_uriString

The URI of the firewall policy that this rule is associated with. This field is not applicable to VPC firewall rules and implied VPC firewall rules. Corresponds to the JSON property policyUri

Returns:

  • (String)


1221
1222
1223
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1221

def policy_uri
  @policy_uri
end

#priorityFixnum

The priority of the firewall rule. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


1226
1227
1228
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1226

def priority
  @priority
end

#target_service_accountsArray<String>

The target service accounts specified by the firewall rule. Corresponds to the JSON property targetServiceAccounts

Returns:

  • (Array<String>)


1231
1232
1233
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1231

def target_service_accounts
  @target_service_accounts
end

#target_tagsArray<String>

The target tags defined by the VPC firewall rule. This field is not applicable to firewall policy rules. Corresponds to the JSON property targetTags

Returns:

  • (Array<String>)


1237
1238
1239
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1237

def target_tags
  @target_tags
end

#target_typeString

Target type of the firewall rule. Corresponds to the JSON property targetType

Returns:

  • (String)


1242
1243
1244
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1242

def target_type
  @target_type
end

#uriString

The URI of the firewall rule. This field is not applicable to implied VPC firewall rules. Corresponds to the JSON property uri

Returns:

  • (String)


1248
1249
1250
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1248

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1255

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @direction = args[:direction] if args.key?(:direction)
  @display_name = args[:display_name] if args.key?(:display_name)
  @firewall_rule_type = args[:firewall_rule_type] if args.key?(:firewall_rule_type)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @policy = args[:policy] if args.key?(:policy)
  @policy_priority = args[:policy_priority] if args.key?(:policy_priority)
  @policy_uri = args[:policy_uri] if args.key?(:policy_uri)
  @priority = args[:priority] if args.key?(:priority)
  @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts)
  @target_tags = args[:target_tags] if args.key?(:target_tags)
  @target_type = args[:target_type] if args.key?(:target_type)
  @uri = args[:uri] if args.key?(:uri)
end