Class: Google::Apis::NetworkmanagementV1::FirewallInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::FirewallInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a VPC firewall rule, an implied VPC firewall rule, or a firewall policy rule.
Instance Attribute Summary collapse
-
#action ⇒ String
Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP Corresponds to the JSON property
action. -
#direction ⇒ String
Possible values: INGRESS, EGRESS Corresponds to the JSON property
direction. -
#display_name ⇒ String
The display name of the firewall rule.
-
#firewall_rule_type ⇒ String
The firewall rule's type.
-
#network_uri ⇒ String
The URI of the VPC network that the firewall rule is associated with.
-
#policy ⇒ String
The name of the firewall policy that this rule is associated with.
-
#policy_priority ⇒ Fixnum
The priority of the firewall policy that this rule is associated with.
-
#policy_uri ⇒ String
The URI of the firewall policy that this rule is associated with.
-
#priority ⇒ Fixnum
The priority of the firewall rule.
-
#target_service_accounts ⇒ Array<String>
The target service accounts specified by the firewall rule.
-
#target_tags ⇒ Array<String>
The target tags defined by the VPC firewall rule.
-
#target_type ⇒ String
Target type of the firewall rule.
-
#uri ⇒ String
The URI of the firewall rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallInfo
constructor
A new instance of FirewallInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallInfo
Returns a new instance of FirewallInfo.
1219 1220 1221 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP
Corresponds to the JSON property action
1150 1151 1152 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1150 def action @action end |
#direction ⇒ String
Possible values: INGRESS, EGRESS
Corresponds to the JSON property direction
1155 1156 1157 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1155 def direction @direction end |
#display_name ⇒ String
The display name of the firewall rule. This field might be empty for firewall
policy rules.
Corresponds to the JSON property displayName
1161 1162 1163 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1161 def display_name @display_name end |
#firewall_rule_type ⇒ String
The firewall rule's type.
Corresponds to the JSON property firewallRuleType
1166 1167 1168 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1166 def firewall_rule_type @firewall_rule_type end |
#network_uri ⇒ String
The URI of the VPC network that the firewall rule is associated with. This
field is not applicable to hierarchical firewall policy rules.
Corresponds to the JSON property networkUri
1172 1173 1174 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1172 def network_uri @network_uri end |
#policy ⇒ String
The name of the firewall policy that this rule is associated with. This field
is not applicable to VPC firewall rules and implied VPC firewall rules.
Corresponds to the JSON property policy
1178 1179 1180 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1178 def policy @policy end |
#policy_priority ⇒ Fixnum
The priority of the firewall policy that this rule is associated with. This
field is not applicable to VPC firewall rules and implied VPC firewall rules.
Corresponds to the JSON property policyPriority
1184 1185 1186 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1184 def policy_priority @policy_priority end |
#policy_uri ⇒ String
The URI of the firewall policy that this rule is associated with. This field
is not applicable to VPC firewall rules and implied VPC firewall rules.
Corresponds to the JSON property policyUri
1190 1191 1192 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1190 def policy_uri @policy_uri end |
#priority ⇒ Fixnum
The priority of the firewall rule.
Corresponds to the JSON property priority
1195 1196 1197 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1195 def priority @priority end |
#target_service_accounts ⇒ Array<String>
The target service accounts specified by the firewall rule.
Corresponds to the JSON property targetServiceAccounts
1200 1201 1202 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1200 def target_service_accounts @target_service_accounts end |
#target_tags ⇒ Array<String>
The target tags defined by the VPC firewall rule. This field is not applicable
to firewall policy rules.
Corresponds to the JSON property targetTags
1206 1207 1208 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1206 def @target_tags end |
#target_type ⇒ String
Target type of the firewall rule.
Corresponds to the JSON property targetType
1211 1212 1213 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1211 def target_type @target_type end |
#uri ⇒ String
The URI of the firewall rule. This field is not applicable to implied VPC
firewall rules.
Corresponds to the JSON property uri
1217 1218 1219 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1217 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1224 def update!(**args) @action = args[:action] if args.key?(:action) @direction = args[:direction] if args.key?(:direction) @display_name = args[:display_name] if args.key?(:display_name) @firewall_rule_type = args[:firewall_rule_type] if args.key?(:firewall_rule_type) @network_uri = args[:network_uri] if args.key?(:network_uri) @policy = args[:policy] if args.key?(:policy) @policy_priority = args[:policy_priority] if args.key?(:policy_priority) @policy_uri = args[:policy_uri] if args.key?(:policy_uri) @priority = args[:priority] if args.key?(:priority) @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts) @target_tags = args[:target_tags] if args.key?(:target_tags) @target_type = args[:target_type] if args.key?(:target_type) @uri = args[:uri] if args.key?(:uri) end |