Class: Google::Apis::NetworkmanagementV1::ForwardingRuleInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ForwardingRuleInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine forwarding rule.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of the forwarding rule.
-
#load_balancer_name ⇒ String
Name of the load balancer the forwarding rule belongs to.
-
#matched_port_range ⇒ String
Port range defined in the forwarding rule that matches the packet.
-
#matched_protocol ⇒ String
Protocol defined in the forwarding rule that matches the packet.
-
#network_uri ⇒ String
URI of a VPC network where the forwarding rule is located in format "projects/
project/global/networks/network". -
#psc_google_api_target ⇒ String
PSC Google API target this forwarding rule targets (if applicable).
-
#psc_service_attachment_uri ⇒ String
URI of the PSC service attachment this forwarding rule targets (if applicable) in format "projects/
project/regions/region/serviceAttachments/service_attachment". -
#region ⇒ String
Region of the forwarding rule.
-
#target ⇒ String
Target type of the forwarding rule.
-
#uri ⇒ String
URI of the forwarding rule in format "projects/
project/global/ forwardingRules/forwarding_rule" (global) or "projects/project/regions/region/forwardingRules/forwarding_rule" (regional). -
#vip ⇒ String
VIP of the forwarding rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleInfo
constructor
A new instance of ForwardingRuleInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleInfo
Returns a new instance of ForwardingRuleInfo.
1407 1408 1409 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1407 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of the forwarding rule.
Corresponds to the JSON property displayName
1349 1350 1351 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1349 def display_name @display_name end |
#load_balancer_name ⇒ String
Name of the load balancer the forwarding rule belongs to. Empty for forwarding
rules not related to load balancers (like PSC forwarding rules).
Corresponds to the JSON property loadBalancerName
1355 1356 1357 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1355 def load_balancer_name @load_balancer_name end |
#matched_port_range ⇒ String
Port range defined in the forwarding rule that matches the packet.
Corresponds to the JSON property matchedPortRange
1360 1361 1362 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1360 def matched_port_range @matched_port_range end |
#matched_protocol ⇒ String
Protocol defined in the forwarding rule that matches the packet.
Corresponds to the JSON property matchedProtocol
1365 1366 1367 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1365 def matched_protocol @matched_protocol end |
#network_uri ⇒ String
URI of a VPC network where the forwarding rule is located in format "projects/
project/global/networks/network".
Corresponds to the JSON property networkUri
1371 1372 1373 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1371 def network_uri @network_uri end |
#psc_google_api_target ⇒ String
PSC Google API target this forwarding rule targets (if applicable).
Corresponds to the JSON property pscGoogleApiTarget
1376 1377 1378 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1376 def psc_google_api_target @psc_google_api_target end |
#psc_service_attachment_uri ⇒ String
URI of the PSC service attachment this forwarding rule targets (if applicable)
in format "projects/project/regions/region/serviceAttachments/
service_attachment".
Corresponds to the JSON property pscServiceAttachmentUri
1383 1384 1385 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1383 def @psc_service_attachment_uri end |
#region ⇒ String
Region of the forwarding rule. Set only for regional forwarding rules.
Corresponds to the JSON property region
1388 1389 1390 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1388 def region @region end |
#target ⇒ String
Target type of the forwarding rule.
Corresponds to the JSON property target
1393 1394 1395 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1393 def target @target end |
#uri ⇒ String
URI of the forwarding rule in format "projects/project/global/
forwardingRules/forwarding_rule" (global) or "projects/project/regions/
region/forwardingRules/forwarding_rule" (regional).
Corresponds to the JSON property uri
1400 1401 1402 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1400 def uri @uri end |
#vip ⇒ String
VIP of the forwarding rule.
Corresponds to the JSON property vip
1405 1406 1407 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1405 def vip @vip end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1412 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @load_balancer_name = args[:load_balancer_name] if args.key?(:load_balancer_name) @matched_port_range = args[:matched_port_range] if args.key?(:matched_port_range) @matched_protocol = args[:matched_protocol] if args.key?(:matched_protocol) @network_uri = args[:network_uri] if args.key?(:network_uri) @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target) @psc_service_attachment_uri = args[:psc_service_attachment_uri] if args.key?(:psc_service_attachment_uri) @region = args[:region] if args.key?(:region) @target = args[:target] if args.key?(:target) @uri = args[:uri] if args.key?(:uri) @vip = args[:vip] if args.key?(:vip) end |