Class: Google::Apis::NetworkmanagementV1::ForwardingRuleInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine forwarding rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleInfo

Returns a new instance of ForwardingRuleInfo.



1363
1364
1365
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of the forwarding rule. Corresponds to the JSON property displayName

Returns:

  • (String)


1310
1311
1312
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1310

def display_name
  @display_name
end

#load_balancer_nameString

Name of the load balancer the forwarding rule belongs to. Empty for forwarding rules not related to load balancers (like PSC forwarding rules). Corresponds to the JSON property loadBalancerName

Returns:

  • (String)


1316
1317
1318
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1316

def load_balancer_name
  @load_balancer_name
end

#matched_port_rangeString

Port range defined in the forwarding rule that matches the packet. Corresponds to the JSON property matchedPortRange

Returns:

  • (String)


1321
1322
1323
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1321

def matched_port_range
  @matched_port_range
end

#matched_protocolString

Protocol defined in the forwarding rule that matches the packet. Corresponds to the JSON property matchedProtocol

Returns:

  • (String)


1326
1327
1328
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1326

def matched_protocol
  @matched_protocol
end

#network_uriString

Network URI. Corresponds to the JSON property networkUri

Returns:

  • (String)


1331
1332
1333
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1331

def network_uri
  @network_uri
end

#psc_google_api_targetString

PSC Google API target this forwarding rule targets (if applicable). Corresponds to the JSON property pscGoogleApiTarget

Returns:

  • (String)


1336
1337
1338
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1336

def psc_google_api_target
  @psc_google_api_target
end

#psc_service_attachment_uriString

URI of the PSC service attachment this forwarding rule targets (if applicable). Corresponds to the JSON property pscServiceAttachmentUri

Returns:

  • (String)


1341
1342
1343
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1341

def psc_service_attachment_uri
  @psc_service_attachment_uri
end

#regionString

Region of the forwarding rule. Set only for regional forwarding rules. Corresponds to the JSON property region

Returns:

  • (String)


1346
1347
1348
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1346

def region
  @region
end

#targetString

Target type of the forwarding rule. Corresponds to the JSON property target

Returns:

  • (String)


1351
1352
1353
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1351

def target
  @target
end

#uriString

URI of the forwarding rule. Corresponds to the JSON property uri

Returns:

  • (String)


1356
1357
1358
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1356

def uri
  @uri
end

#vipString

VIP of the forwarding rule. Corresponds to the JSON property vip

Returns:

  • (String)


1361
1362
1363
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1361

def vip
  @vip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1368

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @load_balancer_name = args[:load_balancer_name] if args.key?(:load_balancer_name)
  @matched_port_range = args[:matched_port_range] if args.key?(:matched_port_range)
  @matched_protocol = args[:matched_protocol] if args.key?(:matched_protocol)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target)
  @psc_service_attachment_uri = args[:psc_service_attachment_uri] if args.key?(:psc_service_attachment_uri)
  @region = args[:region] if args.key?(:region)
  @target = args[:target] if args.key?(:target)
  @uri = args[:uri] if args.key?(:uri)
  @vip = args[:vip] if args.key?(:vip)
end