Class: Google::Apis::NetworkmanagementV1::GkeNetworkPolicyInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a GKE Network Policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GkeNetworkPolicyInfo

Returns a new instance of GkeNetworkPolicyInfo.



1528
1529
1530
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Possible values: ALLOW, DENY Corresponds to the JSON property action

Returns:

  • (String)


1508
1509
1510
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1508

def action
  @action
end

#directionString

Possible values: INGRESS, EGRESS Corresponds to the JSON property direction

Returns:

  • (String)


1513
1514
1515
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1513

def direction
  @direction
end

#display_nameString

The name of the Network Policy. Corresponds to the JSON property displayName

Returns:

  • (String)


1518
1519
1520
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1518

def display_name
  @display_name
end

#uriString

The URI of the Network Policy. Format for a Network Policy in a zonal cluster: projects//zones//clusters//k8s/namespaces//networking.k8s.io/networkpolicies/ Format for a Network Policy in a regional cluster: projects//locations// clusters//k8s/namespaces//networking.k8s.io/networkpolicies/ Corresponds to the JSON property uri

Returns:

  • (String)


1526
1527
1528
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1526

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1533
1534
1535
1536
1537
1538
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1533

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @direction = args[:direction] if args.key?(:direction)
  @display_name = args[:display_name] if args.key?(:display_name)
  @uri = args[:uri] if args.key?(:uri)
end