Class: Google::Apis::NetworkmanagementV1::GkeNetworkPolicyInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a GKE Network Policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GkeNetworkPolicyInfo

Returns a new instance of GkeNetworkPolicyInfo.



1488
1489
1490
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Possible values: ALLOW, DENY Corresponds to the JSON property action

Returns:

  • (String)


1468
1469
1470
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1468

def action
  @action
end

#directionString

Possible values: INGRESS, EGRESS Corresponds to the JSON property direction

Returns:

  • (String)


1473
1474
1475
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1473

def direction
  @direction
end

#display_nameString

The name of the Network Policy. Corresponds to the JSON property displayName

Returns:

  • (String)


1478
1479
1480
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1478

def display_name
  @display_name
end

#uriString

The URI of the Network Policy. Format for a Network Policy in a zonal cluster: projects//zones//clusters//k8s/namespaces//networking.k8s.io/networkpolicies/ Format for a Network Policy in a regional cluster: projects//locations// clusters//k8s/namespaces//networking.k8s.io/networkpolicies/ Corresponds to the JSON property uri

Returns:

  • (String)


1486
1487
1488
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1486

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1493
1494
1495
1496
1497
1498
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1493

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @direction = args[:direction] if args.key?(:direction)
  @display_name = args[:display_name] if args.key?(:display_name)
  @uri = args[:uri] if args.key?(:uri)
end