Class: Google::Apis::NetworkmanagementV1::HybridSubnetInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::HybridSubnetInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a hybrid subnet.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a hybrid subnet.
-
#region ⇒ String
Name of a Google Cloud region where the hybrid subnet is configured.
-
#uri ⇒ String
URI of a hybrid subnet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HybridSubnetInfo
constructor
A new instance of HybridSubnetInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HybridSubnetInfo
Returns a new instance of HybridSubnetInfo.
1480 1481 1482 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1480 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a hybrid subnet.
Corresponds to the JSON property displayName
1468 1469 1470 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1468 def display_name @display_name end |
#region ⇒ String
Name of a Google Cloud region where the hybrid subnet is configured.
Corresponds to the JSON property region
1473 1474 1475 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1473 def region @region end |
#uri ⇒ String
URI of a hybrid subnet.
Corresponds to the JSON property uri
1478 1479 1480 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1478 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1485 1486 1487 1488 1489 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1485 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |