Class: Google::Apis::NetworkmanagementV1::InstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::InstanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine instance.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Compute Engine instance.
-
#external_ip ⇒ String
External IP address of the network interface.
-
#interface ⇒ String
Name of the network interface of a Compute Engine instance.
-
#internal_ip ⇒ String
Internal IP address of the network interface.
-
#network_tags ⇒ Array<String>
Network tags configured on the instance.
-
#network_uri ⇒ String
URI of a Compute Engine network.
-
#psc_network_attachment_uri ⇒ String
URI of the PSC network attachment the NIC is attached to (if relevant).
-
#running ⇒ Boolean
(also: #running?)
Indicates whether the Compute Engine instance is running.
-
#service_account ⇒ String
Service account authorized for the instance.
-
#status ⇒ String
The status of the instance.
-
#uri ⇒ String
URI of a Compute Engine instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceInfo
constructor
A new instance of InstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceInfo
Returns a new instance of InstanceInfo.
1781 1782 1783 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Compute Engine instance.
Corresponds to the JSON property displayName
1727 1728 1729 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1727 def display_name @display_name end |
#external_ip ⇒ String
External IP address of the network interface.
Corresponds to the JSON property externalIp
1732 1733 1734 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1732 def external_ip @external_ip end |
#interface ⇒ String
Name of the network interface of a Compute Engine instance.
Corresponds to the JSON property interface
1737 1738 1739 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1737 def interface @interface end |
#internal_ip ⇒ String
Internal IP address of the network interface.
Corresponds to the JSON property internalIp
1742 1743 1744 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1742 def internal_ip @internal_ip end |
#network_tags ⇒ Array<String>
Network tags configured on the instance.
Corresponds to the JSON property networkTags
1747 1748 1749 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1747 def @network_tags end |
#network_uri ⇒ String
URI of a Compute Engine network.
Corresponds to the JSON property networkUri
1752 1753 1754 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1752 def network_uri @network_uri end |
#psc_network_attachment_uri ⇒ String
URI of the PSC network attachment the NIC is attached to (if relevant).
Corresponds to the JSON property pscNetworkAttachmentUri
1757 1758 1759 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1757 def @psc_network_attachment_uri end |
#running ⇒ Boolean Also known as: running?
Indicates whether the Compute Engine instance is running. Deprecated: use the
status field instead.
Corresponds to the JSON property running
1763 1764 1765 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1763 def running @running end |
#service_account ⇒ String
Service account authorized for the instance.
Corresponds to the JSON property serviceAccount
1769 1770 1771 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1769 def service_account @service_account end |
#status ⇒ String
The status of the instance.
Corresponds to the JSON property status
1774 1775 1776 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1774 def status @status end |
#uri ⇒ String
URI of a Compute Engine instance.
Corresponds to the JSON property uri
1779 1780 1781 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1779 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1786 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @external_ip = args[:external_ip] if args.key?(:external_ip) @interface = args[:interface] if args.key?(:interface) @internal_ip = args[:internal_ip] if args.key?(:internal_ip) @network_tags = args[:network_tags] if args.key?(:network_tags) @network_uri = args[:network_uri] if args.key?(:network_uri) @psc_network_attachment_uri = args[:psc_network_attachment_uri] if args.key?(:psc_network_attachment_uri) @running = args[:running] if args.key?(:running) @service_account = args[:service_account] if args.key?(:service_account) @status = args[:status] if args.key?(:status) @uri = args[:uri] if args.key?(:uri) end |