Class: Google::Apis::NetworkmanagementV1::InstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::InstanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine instance.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Compute Engine instance.
-
#external_ip ⇒ String
External IP address of the network interface.
-
#interface ⇒ String
Name of the network interface of a Compute Engine instance.
-
#internal_ip ⇒ String
Internal IP address of the network interface.
-
#network_tags ⇒ Array<String>
Network tags configured on the instance.
-
#network_uri ⇒ String
URI of a Compute Engine network.
-
#psc_network_attachment_uri ⇒ String
URI of the PSC network attachment the NIC is attached to (if relevant).
-
#running ⇒ Boolean
(also: #running?)
Indicates whether the Compute Engine instance is running.
-
#service_account ⇒ String
Service account authorized for the instance.
-
#status ⇒ String
The status of the instance.
-
#uri ⇒ String
URI of a Compute Engine instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceInfo
constructor
A new instance of InstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceInfo
Returns a new instance of InstanceInfo.
1613 1614 1615 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1613 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Compute Engine instance.
Corresponds to the JSON property displayName
1559 1560 1561 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1559 def display_name @display_name end |
#external_ip ⇒ String
External IP address of the network interface.
Corresponds to the JSON property externalIp
1564 1565 1566 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1564 def external_ip @external_ip end |
#interface ⇒ String
Name of the network interface of a Compute Engine instance.
Corresponds to the JSON property interface
1569 1570 1571 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1569 def interface @interface end |
#internal_ip ⇒ String
Internal IP address of the network interface.
Corresponds to the JSON property internalIp
1574 1575 1576 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1574 def internal_ip @internal_ip end |
#network_tags ⇒ Array<String>
Network tags configured on the instance.
Corresponds to the JSON property networkTags
1579 1580 1581 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1579 def @network_tags end |
#network_uri ⇒ String
URI of a Compute Engine network.
Corresponds to the JSON property networkUri
1584 1585 1586 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1584 def network_uri @network_uri end |
#psc_network_attachment_uri ⇒ String
URI of the PSC network attachment the NIC is attached to (if relevant).
Corresponds to the JSON property pscNetworkAttachmentUri
1589 1590 1591 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1589 def @psc_network_attachment_uri end |
#running ⇒ Boolean Also known as: running?
Indicates whether the Compute Engine instance is running. Deprecated: use the
status field instead.
Corresponds to the JSON property running
1595 1596 1597 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1595 def running @running end |
#service_account ⇒ String
Service account authorized for the instance.
Corresponds to the JSON property serviceAccount
1601 1602 1603 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1601 def service_account @service_account end |
#status ⇒ String
The status of the instance.
Corresponds to the JSON property status
1606 1607 1608 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1606 def status @status end |
#uri ⇒ String
URI of a Compute Engine instance.
Corresponds to the JSON property uri
1611 1612 1613 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1611 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1618 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @external_ip = args[:external_ip] if args.key?(:external_ip) @interface = args[:interface] if args.key?(:interface) @internal_ip = args[:internal_ip] if args.key?(:internal_ip) @network_tags = args[:network_tags] if args.key?(:network_tags) @network_uri = args[:network_uri] if args.key?(:network_uri) @psc_network_attachment_uri = args[:psc_network_attachment_uri] if args.key?(:psc_network_attachment_uri) @running = args[:running] if args.key?(:running) @service_account = args[:service_account] if args.key?(:service_account) @status = args[:status] if args.key?(:status) @uri = args[:uri] if args.key?(:uri) end |