Class: Google::Apis::NetworkmanagementV1::InterconnectAttachmentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with an Interconnect attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentInfo

Returns a new instance of InterconnectAttachmentInfo.



1927
1928
1929
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_router_uriString

URI of the Cloud Router to be used for dynamic routing. Format: projects/ project_id/regions/region/routers/router_id` Corresponds to the JSON propertycloudRouterUri`

Returns:

  • (String)


1893
1894
1895
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1893

def cloud_router_uri
  @cloud_router_uri
end

#display_nameString

Name of an Interconnect attachment. Corresponds to the JSON property displayName

Returns:

  • (String)


1898
1899
1900
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1898

def display_name
  @display_name
end

#interconnect_uriString

URI of the Interconnect. Format: projects/project_id/global/interconnects/ interconnect_id` Corresponds to the JSON propertyinterconnectUri`

Returns:

  • (String)


1904
1905
1906
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1904

def interconnect_uri
  @interconnect_uri
end

#l2_attachment_matched_ip_addressString

Appliance IP address that was matched for L2_DEDICATED attachments. Corresponds to the JSON property l2AttachmentMatchedIpAddress

Returns:

  • (String)


1909
1910
1911
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1909

def l2_attachment_matched_ip_address
  @l2_attachment_matched_ip_address
end

#regionString

Name of a Google Cloud region where the Interconnect attachment is configured. Corresponds to the JSON property region

Returns:

  • (String)


1914
1915
1916
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1914

def region
  @region
end

#typeString

The type of interconnect attachment this is. Corresponds to the JSON property type

Returns:

  • (String)


1919
1920
1921
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1919

def type
  @type
end

#uriString

URI of the Interconnect attachment. Format: projects/project_id/regions/ region/interconnectAttachments/attachment_id` Corresponds to the JSON propertyuri`

Returns:

  • (String)


1925
1926
1927
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1925

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1932
1933
1934
1935
1936
1937
1938
1939
1940
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1932

def update!(**args)
  @cloud_router_uri = args[:cloud_router_uri] if args.key?(:cloud_router_uri)
  @display_name = args[:display_name] if args.key?(:display_name)
  @interconnect_uri = args[:interconnect_uri] if args.key?(:interconnect_uri)
  @l2_attachment_matched_ip_address = args[:l2_attachment_matched_ip_address] if args.key?(:l2_attachment_matched_ip_address)
  @region = args[:region] if args.key?(:region)
  @type = args[:type] if args.key?(:type)
  @uri = args[:uri] if args.key?(:uri)
end