Class: Google::Apis::NetworkmanagementV1::InterconnectAttachmentInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with an Interconnect attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentInfo

Returns a new instance of InterconnectAttachmentInfo.



1871
1872
1873
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1871

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_router_uriString

URI of the Cloud Router to be used for dynamic routing. Corresponds to the JSON property cloudRouterUri

Returns:

  • (String)


1839
1840
1841
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1839

def cloud_router_uri
  @cloud_router_uri
end

#display_nameString

Name of an Interconnect attachment. Corresponds to the JSON property displayName

Returns:

  • (String)


1844
1845
1846
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1844

def display_name
  @display_name
end

#interconnect_uriString

URI of the Interconnect where the Interconnect attachment is configured. Corresponds to the JSON property interconnectUri

Returns:

  • (String)


1849
1850
1851
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1849

def interconnect_uri
  @interconnect_uri
end

#l2_attachment_matched_ip_addressString

Appliance IP address that was matched for L2_DEDICATED attachments. Corresponds to the JSON property l2AttachmentMatchedIpAddress

Returns:

  • (String)


1854
1855
1856
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1854

def l2_attachment_matched_ip_address
  @l2_attachment_matched_ip_address
end

#regionString

Name of a Google Cloud region where the Interconnect attachment is configured. Corresponds to the JSON property region

Returns:

  • (String)


1859
1860
1861
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1859

def region
  @region
end

#typeString

The type of interconnect attachment this is. Corresponds to the JSON property type

Returns:

  • (String)


1864
1865
1866
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1864

def type
  @type
end

#uriString

URI of an Interconnect attachment. Corresponds to the JSON property uri

Returns:

  • (String)


1869
1870
1871
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1869

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1876
1877
1878
1879
1880
1881
1882
1883
1884
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1876

def update!(**args)
  @cloud_router_uri = args[:cloud_router_uri] if args.key?(:cloud_router_uri)
  @display_name = args[:display_name] if args.key?(:display_name)
  @interconnect_uri = args[:interconnect_uri] if args.key?(:interconnect_uri)
  @l2_attachment_matched_ip_address = args[:l2_attachment_matched_ip_address] if args.key?(:l2_attachment_matched_ip_address)
  @region = args[:region] if args.key?(:region)
  @type = args[:type] if args.key?(:type)
  @uri = args[:uri] if args.key?(:uri)
end