Class: Google::Apis::NetworkmanagementV1::InterconnectAttachmentInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::InterconnectAttachmentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with an Interconnect attachment.
Instance Attribute Summary collapse
-
#cloud_router_uri ⇒ String
URI of the Cloud Router to be used for dynamic routing.
-
#display_name ⇒ String
Name of an Interconnect attachment.
-
#interconnect_uri ⇒ String
URI of the Interconnect where the Interconnect attachment is configured.
-
#l2_attachment_matched_ip_address ⇒ String
Appliance IP address that was matched for L2_DEDICATED attachments.
-
#region ⇒ String
Name of a Google Cloud region where the Interconnect attachment is configured.
-
#type ⇒ String
The type of interconnect attachment this is.
-
#uri ⇒ String
URI of an Interconnect attachment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentInfo
constructor
A new instance of InterconnectAttachmentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentInfo
Returns a new instance of InterconnectAttachmentInfo.
1840 1841 1842 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_router_uri ⇒ String
URI of the Cloud Router to be used for dynamic routing.
Corresponds to the JSON property cloudRouterUri
1808 1809 1810 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1808 def cloud_router_uri @cloud_router_uri end |
#display_name ⇒ String
Name of an Interconnect attachment.
Corresponds to the JSON property displayName
1813 1814 1815 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1813 def display_name @display_name end |
#interconnect_uri ⇒ String
URI of the Interconnect where the Interconnect attachment is configured.
Corresponds to the JSON property interconnectUri
1818 1819 1820 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1818 def interconnect_uri @interconnect_uri end |
#l2_attachment_matched_ip_address ⇒ String
Appliance IP address that was matched for L2_DEDICATED attachments.
Corresponds to the JSON property l2AttachmentMatchedIpAddress
1823 1824 1825 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1823 def @l2_attachment_matched_ip_address end |
#region ⇒ String
Name of a Google Cloud region where the Interconnect attachment is configured.
Corresponds to the JSON property region
1828 1829 1830 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1828 def region @region end |
#type ⇒ String
The type of interconnect attachment this is.
Corresponds to the JSON property type
1833 1834 1835 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1833 def type @type end |
#uri ⇒ String
URI of an Interconnect attachment.
Corresponds to the JSON property uri
1838 1839 1840 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1838 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1845 1846 1847 1848 1849 1850 1851 1852 1853 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1845 def update!(**args) @cloud_router_uri = args[:cloud_router_uri] if args.key?(:cloud_router_uri) @display_name = args[:display_name] if args.key?(:display_name) @interconnect_uri = args[:interconnect_uri] if args.key?(:interconnect_uri) @l2_attachment_matched_ip_address = args[:l2_attachment_matched_ip_address] if args.key?(:l2_attachment_matched_ip_address) @region = args[:region] if args.key?(:region) @type = args[:type] if args.key?(:type) @uri = args[:uri] if args.key?(:uri) end |