Class: Google::Apis::NetworkmanagementV1::InterconnectAttachmentInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::InterconnectAttachmentInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with an Interconnect attachment.
Instance Attribute Summary collapse
-
#cloud_router_uri ⇒ String
URI of the Cloud Router to be used for dynamic routing.
-
#display_name ⇒ String
Name of an Interconnect attachment.
-
#interconnect_uri ⇒ String
URI of the Interconnect where the Interconnect attachment is configured.
-
#l2_attachment_matched_ip_address ⇒ String
Appliance IP address that was matched for L2_DEDICATED attachments.
-
#region ⇒ String
Name of a Google Cloud region where the Interconnect attachment is configured.
-
#type ⇒ String
The type of interconnect attachment this is.
-
#uri ⇒ String
URI of an Interconnect attachment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentInfo
constructor
A new instance of InterconnectAttachmentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentInfo
Returns a new instance of InterconnectAttachmentInfo.
1672 1673 1674 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_router_uri ⇒ String
URI of the Cloud Router to be used for dynamic routing.
Corresponds to the JSON property cloudRouterUri
1640 1641 1642 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1640 def cloud_router_uri @cloud_router_uri end |
#display_name ⇒ String
Name of an Interconnect attachment.
Corresponds to the JSON property displayName
1645 1646 1647 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1645 def display_name @display_name end |
#interconnect_uri ⇒ String
URI of the Interconnect where the Interconnect attachment is configured.
Corresponds to the JSON property interconnectUri
1650 1651 1652 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1650 def interconnect_uri @interconnect_uri end |
#l2_attachment_matched_ip_address ⇒ String
Appliance IP address that was matched for L2_DEDICATED attachments.
Corresponds to the JSON property l2AttachmentMatchedIpAddress
1655 1656 1657 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1655 def @l2_attachment_matched_ip_address end |
#region ⇒ String
Name of a Google Cloud region where the Interconnect attachment is configured.
Corresponds to the JSON property region
1660 1661 1662 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1660 def region @region end |
#type ⇒ String
The type of interconnect attachment this is.
Corresponds to the JSON property type
1665 1666 1667 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1665 def type @type end |
#uri ⇒ String
URI of an Interconnect attachment.
Corresponds to the JSON property uri
1670 1671 1672 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1670 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1677 1678 1679 1680 1681 1682 1683 1684 1685 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1677 def update!(**args) @cloud_router_uri = args[:cloud_router_uri] if args.key?(:cloud_router_uri) @display_name = args[:display_name] if args.key?(:display_name) @interconnect_uri = args[:interconnect_uri] if args.key?(:interconnect_uri) @l2_attachment_matched_ip_address = args[:l2_attachment_matched_ip_address] if args.key?(:l2_attachment_matched_ip_address) @region = args[:region] if args.key?(:region) @type = args[:type] if args.key?(:type) @uri = args[:uri] if args.key?(:uri) end |