Class: Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Response for the ListConnectivityTests method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Page token to fetch the next set of Connectivity Tests.
-
#resources ⇒ Array<Google::Apis::NetworkmanagementV1::ConnectivityTest>
List of Connectivity Tests.
-
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with
-).
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListConnectivityTestsResponse
constructor
A new instance of ListConnectivityTestsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListConnectivityTestsResponse
Returns a new instance of ListConnectivityTestsResponse.
1780 1781 1782 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1780 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Page token to fetch the next set of Connectivity Tests.
Corresponds to the JSON property nextPageToken
1768 1769 1770 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1768 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::NetworkmanagementV1::ConnectivityTest>
List of Connectivity Tests.
Corresponds to the JSON property resources
1773 1774 1775 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1773 def resources @resources end |
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with -).
Corresponds to the JSON property unreachable
1778 1779 1780 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1778 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1785 1786 1787 1788 1789 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1785 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) @unreachable = args[:unreachable] if args.key?(:unreachable) end |