Class: Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Response for the ListVpcFlowLogsConfigs method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Page token to fetch the next set of configurations.
-
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with
-). -
#vpc_flow_logs_configs ⇒ Array<Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig>
List of VPC Flow Log configurations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVpcFlowLogsConfigsResponse
constructor
A new instance of ListVpcFlowLogsConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVpcFlowLogsConfigsResponse
Returns a new instance of ListVpcFlowLogsConfigsResponse.
1870 1871 1872 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1870 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Page token to fetch the next set of configurations.
Corresponds to the JSON property nextPageToken
1858 1859 1860 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1858 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached (when querying all locations with -).
Corresponds to the JSON property unreachable
1863 1864 1865 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1863 def unreachable @unreachable end |
#vpc_flow_logs_configs ⇒ Array<Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig>
List of VPC Flow Log configurations.
Corresponds to the JSON property vpcFlowLogsConfigs
1868 1869 1870 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1868 def vpc_flow_logs_configs @vpc_flow_logs_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1875 1876 1877 1878 1879 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1875 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @vpc_flow_logs_configs = args[:vpc_flow_logs_configs] if args.key?(:vpc_flow_logs_configs) end |