Class: Google::Apis::NetworkmanagementV1::ListWebPathsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ListWebPathsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Message for response to listing WebPaths
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#web_paths ⇒ Array<Google::Apis::NetworkmanagementV1::WebPath>
The list of WebPath.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListWebPathsResponse
constructor
A new instance of ListWebPathsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListWebPathsResponse
Returns a new instance of ListWebPathsResponse.
2170 2171 2172 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2163 2164 2165 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2163 def next_page_token @next_page_token end |
#web_paths ⇒ Array<Google::Apis::NetworkmanagementV1::WebPath>
The list of WebPath.
Corresponds to the JSON property webPaths
2168 2169 2170 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2168 def web_paths @web_paths end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2175 2176 2177 2178 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2175 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @web_paths = args[:web_paths] if args.key?(:web_paths) end |