Class: Google::Apis::NetworkmanagementV1::LoadBalancerBackend
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::LoadBalancerBackend
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a specific load balancer backend.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Compute Engine instance or network endpoint.
-
#health_check_allowing_firewall_rules ⇒ Array<String>
A list of firewall rule URIs allowing probes from health check IP ranges.
-
#health_check_blocking_firewall_rules ⇒ Array<String>
A list of firewall rule URIs blocking probes from health check IP ranges.
-
#health_check_firewall_state ⇒ String
State of the health check firewall configuration.
-
#uri ⇒ String
URI of a Compute Engine instance or network endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadBalancerBackend
constructor
A new instance of LoadBalancerBackend.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadBalancerBackend
Returns a new instance of LoadBalancerBackend.
2179 2180 2181 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2179 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Compute Engine instance or network endpoint.
Corresponds to the JSON property displayName
2157 2158 2159 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2157 def display_name @display_name end |
#health_check_allowing_firewall_rules ⇒ Array<String>
A list of firewall rule URIs allowing probes from health check IP ranges.
Corresponds to the JSON property healthCheckAllowingFirewallRules
2162 2163 2164 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2162 def health_check_allowing_firewall_rules @health_check_allowing_firewall_rules end |
#health_check_blocking_firewall_rules ⇒ Array<String>
A list of firewall rule URIs blocking probes from health check IP ranges.
Corresponds to the JSON property healthCheckBlockingFirewallRules
2167 2168 2169 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2167 def health_check_blocking_firewall_rules @health_check_blocking_firewall_rules end |
#health_check_firewall_state ⇒ String
State of the health check firewall configuration.
Corresponds to the JSON property healthCheckFirewallState
2172 2173 2174 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2172 def health_check_firewall_state @health_check_firewall_state end |
#uri ⇒ String
URI of a Compute Engine instance or network endpoint.
Corresponds to the JSON property uri
2177 2178 2179 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2177 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2184 2185 2186 2187 2188 2189 2190 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2184 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @health_check_allowing_firewall_rules = args[:health_check_allowing_firewall_rules] if args.key?(:health_check_allowing_firewall_rules) @health_check_blocking_firewall_rules = args[:health_check_blocking_firewall_rules] if args.key?(:health_check_blocking_firewall_rules) @health_check_firewall_state = args[:health_check_firewall_state] if args.key?(:health_check_firewall_state) @uri = args[:uri] if args.key?(:uri) end |