Class: Google::Apis::NetworkmanagementV1::LoadBalancerBackendInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::LoadBalancerBackendInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with the load balancer backend.
Instance Attribute Summary collapse
-
#backend_bucket_uri ⇒ String
URI of the backend bucket this backend targets (if applicable) in format " projects/
project/global/backendBuckets/backend_bucket". -
#backend_service_uri ⇒ String
URI of the backend service this backend belongs to (if applicable) in format " projects/
project/regions/region/backendServices/backend_service" ( regional) or "projects/project/global/backendServices/backend_service" ( global). -
#health_check_firewalls_config_state ⇒ String
Output only.
-
#health_check_uri ⇒ String
URI of the health check attached to this backend (if applicable).
-
#instance_group_uri ⇒ String
URI of the instance group this backend belongs to (if applicable) in format " projects/
project/zones/zone/instanceGroups/instance_group". -
#instance_uri ⇒ String
URI of the backend instance (if applicable) in format "projects/
project/ zones/zone/instances/instance". -
#name ⇒ String
Display name of the backend.
-
#network_endpoint_group_uri ⇒ String
URI of the network endpoint group this backend belongs to (if applicable) Format: *
projects/project_id/zones/zone/networkEndpointGroups/neg_id( zonal NEG) * `projects/`project_id`/regions/`region`/networkEndpointGroups/` neg_id(regional NEG) *projects/project_id/global/networkEndpointGroups/neg_id`(global NEG) Corresponds to the JSON propertynetworkEndpointGroupUri`. -
#psc_google_api_target ⇒ String
PSC Google API target this PSC NEG backend targets (if applicable).
-
#psc_service_attachment_uri ⇒ String
URI of the PSC service attachment this PSC NEG backend targets (if applicable) in format "projects/
project/regions/region/serviceAttachments/service_attachment".
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadBalancerBackendInfo
constructor
A new instance of LoadBalancerBackendInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadBalancerBackendInfo
Returns a new instance of LoadBalancerBackendInfo.
2362 2363 2364 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_bucket_uri ⇒ String
URI of the backend bucket this backend targets (if applicable) in format "
projects/project/global/backendBuckets/backend_bucket".
Corresponds to the JSON property backendBucketUri
2293 2294 2295 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2293 def backend_bucket_uri @backend_bucket_uri end |
#backend_service_uri ⇒ String
URI of the backend service this backend belongs to (if applicable) in format "
projects/project/regions/region/backendServices/backend_service" (
regional) or "projects/project/global/backendServices/backend_service" (
global).
Corresponds to the JSON property backendServiceUri
2301 2302 2303 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2301 def backend_service_uri @backend_service_uri end |
#health_check_firewalls_config_state ⇒ String
Output only. Health check firewalls configuration state for the backend. This
is a result of the static firewall analysis (verifying that health check
traffic from required IP ranges to the backend is allowed or not). The backend
might still be unhealthy even if these firewalls are configured. Please refer
to the documentation for more information: https://cloud.google.com/load-
balancing/docs/firewall-rules
Corresponds to the JSON property healthCheckFirewallsConfigState
2311 2312 2313 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2311 def health_check_firewalls_config_state @health_check_firewalls_config_state end |
#health_check_uri ⇒ String
URI of the health check attached to this backend (if applicable). Format: *
projects/project_id/global/healthChecks/health_check_id* `projects/`
project_id`/regions/`region`/healthChecks/`health_check_id * projects/
project_id/global/httpHealthChecks/health_check_id`(legacy)
Corresponds to the JSON propertyhealthCheckUri`
2319 2320 2321 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2319 def health_check_uri @health_check_uri end |
#instance_group_uri ⇒ String
URI of the instance group this backend belongs to (if applicable) in format "
projects/project/zones/zone/instanceGroups/instance_group".
Corresponds to the JSON property instanceGroupUri
2325 2326 2327 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2325 def instance_group_uri @instance_group_uri end |
#instance_uri ⇒ String
URI of the backend instance (if applicable) in format "projects/project/
zones/zone/instances/instance". Populated for instance group backends, and
zonal NEG backends.
Corresponds to the JSON property instanceUri
2332 2333 2334 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2332 def instance_uri @instance_uri end |
#name ⇒ String
Display name of the backend. For example, it might be an instance name for the
instance group backends, or an IP address and port for zonal network endpoint
group backends.
Corresponds to the JSON property name
2339 2340 2341 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2339 def name @name end |
#network_endpoint_group_uri ⇒ String
URI of the network endpoint group this backend belongs to (if applicable)
Format: * projects/project_id/zones/zone/networkEndpointGroups/neg_id(
zonal NEG) * `projects/`project_id`/regions/`region`/networkEndpointGroups/`
neg_id (regional NEG) * projects/project_id/global/networkEndpointGroups/
neg_id`(global NEG)
Corresponds to the JSON propertynetworkEndpointGroupUri`
2348 2349 2350 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2348 def network_endpoint_group_uri @network_endpoint_group_uri end |
#psc_google_api_target ⇒ String
PSC Google API target this PSC NEG backend targets (if applicable).
Corresponds to the JSON property pscGoogleApiTarget
2353 2354 2355 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2353 def psc_google_api_target @psc_google_api_target end |
#psc_service_attachment_uri ⇒ String
URI of the PSC service attachment this PSC NEG backend targets (if applicable)
in format "projects/project/regions/region/serviceAttachments/
service_attachment".
Corresponds to the JSON property pscServiceAttachmentUri
2360 2361 2362 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2360 def @psc_service_attachment_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2367 def update!(**args) @backend_bucket_uri = args[:backend_bucket_uri] if args.key?(:backend_bucket_uri) @backend_service_uri = args[:backend_service_uri] if args.key?(:backend_service_uri) @health_check_firewalls_config_state = args[:health_check_firewalls_config_state] if args.key?(:health_check_firewalls_config_state) @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri) @instance_group_uri = args[:instance_group_uri] if args.key?(:instance_group_uri) @instance_uri = args[:instance_uri] if args.key?(:instance_uri) @name = args[:name] if args.key?(:name) @network_endpoint_group_uri = args[:network_endpoint_group_uri] if args.key?(:network_endpoint_group_uri) @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target) @psc_service_attachment_uri = args[:psc_service_attachment_uri] if args.key?(:psc_service_attachment_uri) end |