Class: Google::Apis::NetworkmanagementV1::LoadBalancerBackendInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::LoadBalancerBackendInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with the load balancer backend.
Instance Attribute Summary collapse
-
#backend_bucket_uri ⇒ String
URI of the backend bucket this backend targets (if applicable).
-
#backend_service_uri ⇒ String
URI of the backend service this backend belongs to (if applicable).
-
#health_check_firewalls_config_state ⇒ String
Output only.
-
#health_check_uri ⇒ String
URI of the health check attached to this backend (if applicable).
-
#instance_group_uri ⇒ String
URI of the instance group this backend belongs to (if applicable).
-
#instance_uri ⇒ String
URI of the backend instance (if applicable).
-
#name ⇒ String
Display name of the backend.
-
#network_endpoint_group_uri ⇒ String
URI of the network endpoint group this backend belongs to (if applicable).
-
#psc_google_api_target ⇒ String
PSC Google API target this PSC NEG backend targets (if applicable).
-
#psc_service_attachment_uri ⇒ String
URI of the PSC service attachment this PSC NEG backend targets (if applicable).
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadBalancerBackendInfo
constructor
A new instance of LoadBalancerBackendInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadBalancerBackendInfo
Returns a new instance of LoadBalancerBackendInfo.
2286 2287 2288 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_bucket_uri ⇒ String
URI of the backend bucket this backend targets (if applicable).
Corresponds to the JSON property backendBucketUri
2231 2232 2233 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2231 def backend_bucket_uri @backend_bucket_uri end |
#backend_service_uri ⇒ String
URI of the backend service this backend belongs to (if applicable).
Corresponds to the JSON property backendServiceUri
2236 2237 2238 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2236 def backend_service_uri @backend_service_uri end |
#health_check_firewalls_config_state ⇒ String
Output only. Health check firewalls configuration state for the backend. This
is a result of the static firewall analysis (verifying that health check
traffic from required IP ranges to the backend is allowed or not). The backend
might still be unhealthy even if these firewalls are configured. Please refer
to the documentation for more information: https://cloud.google.com/load-
balancing/docs/firewall-rules
Corresponds to the JSON property healthCheckFirewallsConfigState
2246 2247 2248 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2246 def health_check_firewalls_config_state @health_check_firewalls_config_state end |
#health_check_uri ⇒ String
URI of the health check attached to this backend (if applicable).
Corresponds to the JSON property healthCheckUri
2251 2252 2253 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2251 def health_check_uri @health_check_uri end |
#instance_group_uri ⇒ String
URI of the instance group this backend belongs to (if applicable).
Corresponds to the JSON property instanceGroupUri
2256 2257 2258 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2256 def instance_group_uri @instance_group_uri end |
#instance_uri ⇒ String
URI of the backend instance (if applicable). Populated for instance group
backends, and zonal NEG backends.
Corresponds to the JSON property instanceUri
2262 2263 2264 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2262 def instance_uri @instance_uri end |
#name ⇒ String
Display name of the backend. For example, it might be an instance name for the
instance group backends, or an IP address and port for zonal network endpoint
group backends.
Corresponds to the JSON property name
2269 2270 2271 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2269 def name @name end |
#network_endpoint_group_uri ⇒ String
URI of the network endpoint group this backend belongs to (if applicable).
Corresponds to the JSON property networkEndpointGroupUri
2274 2275 2276 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2274 def network_endpoint_group_uri @network_endpoint_group_uri end |
#psc_google_api_target ⇒ String
PSC Google API target this PSC NEG backend targets (if applicable).
Corresponds to the JSON property pscGoogleApiTarget
2279 2280 2281 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2279 def psc_google_api_target @psc_google_api_target end |
#psc_service_attachment_uri ⇒ String
URI of the PSC service attachment this PSC NEG backend targets (if applicable).
Corresponds to the JSON property pscServiceAttachmentUri
2284 2285 2286 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2284 def @psc_service_attachment_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2291 def update!(**args) @backend_bucket_uri = args[:backend_bucket_uri] if args.key?(:backend_bucket_uri) @backend_service_uri = args[:backend_service_uri] if args.key?(:backend_service_uri) @health_check_firewalls_config_state = args[:health_check_firewalls_config_state] if args.key?(:health_check_firewalls_config_state) @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri) @instance_group_uri = args[:instance_group_uri] if args.key?(:instance_group_uri) @instance_uri = args[:instance_uri] if args.key?(:instance_uri) @name = args[:name] if args.key?(:name) @network_endpoint_group_uri = args[:network_endpoint_group_uri] if args.key?(:network_endpoint_group_uri) @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target) @psc_service_attachment_uri = args[:psc_service_attachment_uri] if args.key?(:psc_service_attachment_uri) end |