Class: Google::Apis::NetworkmanagementV1::LoadBalancerBackendInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with the load balancer backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerBackendInfo

Returns a new instance of LoadBalancerBackendInfo.



1927
1928
1929
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_bucket_uriString

URI of the backend bucket this backend targets (if applicable). Corresponds to the JSON property backendBucketUri

Returns:

  • (String)


1872
1873
1874
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1872

def backend_bucket_uri
  @backend_bucket_uri
end

#backend_service_uriString

URI of the backend service this backend belongs to (if applicable). Corresponds to the JSON property backendServiceUri

Returns:

  • (String)


1877
1878
1879
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1877

def backend_service_uri
  @backend_service_uri
end

#health_check_firewalls_config_stateString

Output only. Health check firewalls configuration state for the backend. This is a result of the static firewall analysis (verifying that health check traffic from required IP ranges to the backend is allowed or not). The backend might still be unhealthy even if these firewalls are configured. Please refer to the documentation for more information: https://cloud.google.com/load- balancing/docs/firewall-rules Corresponds to the JSON property healthCheckFirewallsConfigState

Returns:

  • (String)


1887
1888
1889
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1887

def health_check_firewalls_config_state
  @health_check_firewalls_config_state
end

#health_check_uriString

URI of the health check attached to this backend (if applicable). Corresponds to the JSON property healthCheckUri

Returns:

  • (String)


1892
1893
1894
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1892

def health_check_uri
  @health_check_uri
end

#instance_group_uriString

URI of the instance group this backend belongs to (if applicable). Corresponds to the JSON property instanceGroupUri

Returns:

  • (String)


1897
1898
1899
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1897

def instance_group_uri
  @instance_group_uri
end

#instance_uriString

URI of the backend instance (if applicable). Populated for instance group backends, and zonal NEG backends. Corresponds to the JSON property instanceUri

Returns:

  • (String)


1903
1904
1905
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1903

def instance_uri
  @instance_uri
end

#nameString

Display name of the backend. For example, it might be an instance name for the instance group backends, or an IP address and port for zonal network endpoint group backends. Corresponds to the JSON property name

Returns:

  • (String)


1910
1911
1912
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1910

def name
  @name
end

#network_endpoint_group_uriString

URI of the network endpoint group this backend belongs to (if applicable). Corresponds to the JSON property networkEndpointGroupUri

Returns:

  • (String)


1915
1916
1917
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1915

def network_endpoint_group_uri
  @network_endpoint_group_uri
end

#psc_google_api_targetString

PSC Google API target this PSC NEG backend targets (if applicable). Corresponds to the JSON property pscGoogleApiTarget

Returns:

  • (String)


1920
1921
1922
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1920

def psc_google_api_target
  @psc_google_api_target
end

#psc_service_attachment_uriString

URI of the PSC service attachment this PSC NEG backend targets (if applicable). Corresponds to the JSON property pscServiceAttachmentUri

Returns:

  • (String)


1925
1926
1927
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1925

def psc_service_attachment_uri
  @psc_service_attachment_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1932
1933
1934
1935
1936
1937
1938
1939
1940
1941
1942
1943
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1932

def update!(**args)
  @backend_bucket_uri = args[:backend_bucket_uri] if args.key?(:backend_bucket_uri)
  @backend_service_uri = args[:backend_service_uri] if args.key?(:backend_service_uri)
  @health_check_firewalls_config_state = args[:health_check_firewalls_config_state] if args.key?(:health_check_firewalls_config_state)
  @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri)
  @instance_group_uri = args[:instance_group_uri] if args.key?(:instance_group_uri)
  @instance_uri = args[:instance_uri] if args.key?(:instance_uri)
  @name = args[:name] if args.key?(:name)
  @network_endpoint_group_uri = args[:network_endpoint_group_uri] if args.key?(:network_endpoint_group_uri)
  @psc_google_api_target = args[:psc_google_api_target] if args.key?(:psc_google_api_target)
  @psc_service_attachment_uri = args[:psc_service_attachment_uri] if args.key?(:psc_service_attachment_uri)
end