Class: Google::Apis::NetworkmanagementV1::LoadBalancerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a load balancer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerInfo

Returns a new instance of LoadBalancerInfo.



2416
2417
2418
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_typeString

Type of load balancer's backend configuration. Corresponds to the JSON property backendType

Returns:

  • (String)


2388
2389
2390
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2388

def backend_type
  @backend_type
end

#backend_uriString

URI of the backend associated with the load balancer. Format: * projects/ project_id/regions/region/backendServices/backend_service_id* `projects/ `project_id`/global/backendServices/`backend_service_id * projects/ project_id/regions/region/targetPools/target_pool_id* `projects/` project_id`/zones/`zone`/targetInstances/`target_instance_id Corresponds to the JSON property backendUri

Returns:

  • (String)


2397
2398
2399
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2397

def backend_uri
  @backend_uri
end

#backendsArray<Google::Apis::NetworkmanagementV1::LoadBalancerBackend>

Information for the loadbalancer backends. Corresponds to the JSON property backends



2402
2403
2404
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2402

def backends
  @backends
end

#health_check_uriString

URI of the health check for the load balancer. Deprecated and no longer populated as different load balancer backends might have different health checks. Corresponds to the JSON property healthCheckUri

Returns:

  • (String)


2409
2410
2411
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2409

def health_check_uri
  @health_check_uri
end

#load_balancer_typeString

Type of the load balancer. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


2414
2415
2416
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2414

def load_balancer_type
  @load_balancer_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2421
2422
2423
2424
2425
2426
2427
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2421

def update!(**args)
  @backend_type = args[:backend_type] if args.key?(:backend_type)
  @backend_uri = args[:backend_uri] if args.key?(:backend_uri)
  @backends = args[:backends] if args.key?(:backends)
  @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
end