Class: Google::Apis::NetworkmanagementV1::LoadBalancerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a load balancer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerInfo

Returns a new instance of LoadBalancerInfo.



2345
2346
2347
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_typeString

Type of load balancer's backend configuration. Corresponds to the JSON property backendType

Returns:

  • (String)


2321
2322
2323
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2321

def backend_type
  @backend_type
end

#backend_uriString

Backend configuration URI. Corresponds to the JSON property backendUri

Returns:

  • (String)


2326
2327
2328
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2326

def backend_uri
  @backend_uri
end

#backendsArray<Google::Apis::NetworkmanagementV1::LoadBalancerBackend>

Information for the loadbalancer backends. Corresponds to the JSON property backends



2331
2332
2333
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2331

def backends
  @backends
end

#health_check_uriString

URI of the health check for the load balancer. Deprecated and no longer populated as different load balancer backends might have different health checks. Corresponds to the JSON property healthCheckUri

Returns:

  • (String)


2338
2339
2340
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2338

def health_check_uri
  @health_check_uri
end

#load_balancer_typeString

Type of the load balancer. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


2343
2344
2345
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2343

def load_balancer_type
  @load_balancer_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2350
2351
2352
2353
2354
2355
2356
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2350

def update!(**args)
  @backend_type = args[:backend_type] if args.key?(:backend_type)
  @backend_uri = args[:backend_uri] if args.key?(:backend_uri)
  @backends = args[:backends] if args.key?(:backends)
  @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
end