Class: Google::Apis::NetworkmanagementV1::LoadBalancerInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::LoadBalancerInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a load balancer.
Instance Attribute Summary collapse
-
#backend_type ⇒ String
Type of load balancer's backend configuration.
-
#backend_uri ⇒ String
Backend configuration URI.
-
#backends ⇒ Array<Google::Apis::NetworkmanagementV1::LoadBalancerBackend>
Information for the loadbalancer backends.
-
#health_check_uri ⇒ String
URI of the health check for the load balancer.
-
#load_balancer_type ⇒ String
Type of the load balancer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadBalancerInfo
constructor
A new instance of LoadBalancerInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadBalancerInfo
Returns a new instance of LoadBalancerInfo.
2336 2337 2338 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_type ⇒ String
Type of load balancer's backend configuration.
Corresponds to the JSON property backendType
2312 2313 2314 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2312 def backend_type @backend_type end |
#backend_uri ⇒ String
Backend configuration URI.
Corresponds to the JSON property backendUri
2317 2318 2319 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2317 def backend_uri @backend_uri end |
#backends ⇒ Array<Google::Apis::NetworkmanagementV1::LoadBalancerBackend>
Information for the loadbalancer backends.
Corresponds to the JSON property backends
2322 2323 2324 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2322 def backends @backends end |
#health_check_uri ⇒ String
URI of the health check for the load balancer. Deprecated and no longer
populated as different load balancer backends might have different health
checks.
Corresponds to the JSON property healthCheckUri
2329 2330 2331 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2329 def health_check_uri @health_check_uri end |
#load_balancer_type ⇒ String
Type of the load balancer.
Corresponds to the JSON property loadBalancerType
2334 2335 2336 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2334 def load_balancer_type @load_balancer_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2341 2342 2343 2344 2345 2346 2347 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2341 def update!(**args) @backend_type = args[:backend_type] if args.key?(:backend_type) @backend_uri = args[:backend_uri] if args.key?(:backend_uri) @backends = args[:backends] if args.key?(:backends) @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri) @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type) end |