Class: Google::Apis::NetworkmanagementV1::LoadBalancerInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::LoadBalancerInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a load balancer.
Instance Attribute Summary collapse
-
#backend_type ⇒ String
Type of load balancer's backend configuration.
-
#backend_uri ⇒ String
Backend configuration URI.
-
#backends ⇒ Array<Google::Apis::NetworkmanagementV1::LoadBalancerBackend>
Information for the loadbalancer backends.
-
#health_check_uri ⇒ String
URI of the health check for the load balancer.
-
#load_balancer_type ⇒ String
Type of the load balancer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadBalancerInfo
constructor
A new instance of LoadBalancerInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadBalancerInfo
Returns a new instance of LoadBalancerInfo.
2305 2306 2307 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_type ⇒ String
Type of load balancer's backend configuration.
Corresponds to the JSON property backendType
2281 2282 2283 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2281 def backend_type @backend_type end |
#backend_uri ⇒ String
Backend configuration URI.
Corresponds to the JSON property backendUri
2286 2287 2288 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2286 def backend_uri @backend_uri end |
#backends ⇒ Array<Google::Apis::NetworkmanagementV1::LoadBalancerBackend>
Information for the loadbalancer backends.
Corresponds to the JSON property backends
2291 2292 2293 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2291 def backends @backends end |
#health_check_uri ⇒ String
URI of the health check for the load balancer. Deprecated and no longer
populated as different load balancer backends might have different health
checks.
Corresponds to the JSON property healthCheckUri
2298 2299 2300 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2298 def health_check_uri @health_check_uri end |
#load_balancer_type ⇒ String
Type of the load balancer.
Corresponds to the JSON property loadBalancerType
2303 2304 2305 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2303 def load_balancer_type @load_balancer_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2310 2311 2312 2313 2314 2315 2316 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2310 def update!(**args) @backend_type = args[:backend_type] if args.key?(:backend_type) @backend_uri = args[:backend_uri] if args.key?(:backend_uri) @backends = args[:backends] if args.key?(:backends) @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri) @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type) end |