Class: Google::Apis::NetworkmanagementV1::LoadBalancerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a load balancer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerInfo

Returns a new instance of LoadBalancerInfo.



2037
2038
2039
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_typeString

Type of load balancer's backend configuration. Corresponds to the JSON property backendType

Returns:

  • (String)


2013
2014
2015
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2013

def backend_type
  @backend_type
end

#backend_uriString

Backend configuration URI. Corresponds to the JSON property backendUri

Returns:

  • (String)


2018
2019
2020
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2018

def backend_uri
  @backend_uri
end

#backendsArray<Google::Apis::NetworkmanagementV1::LoadBalancerBackend>

Information for the loadbalancer backends. Corresponds to the JSON property backends



2023
2024
2025
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2023

def backends
  @backends
end

#health_check_uriString

URI of the health check for the load balancer. Deprecated and no longer populated as different load balancer backends might have different health checks. Corresponds to the JSON property healthCheckUri

Returns:

  • (String)


2030
2031
2032
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2030

def health_check_uri
  @health_check_uri
end

#load_balancer_typeString

Type of the load balancer. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


2035
2036
2037
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2035

def load_balancer_type
  @load_balancer_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2042
2043
2044
2045
2046
2047
2048
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2042

def update!(**args)
  @backend_type = args[:backend_type] if args.key?(:backend_type)
  @backend_uri = args[:backend_uri] if args.key?(:backend_uri)
  @backends = args[:backends] if args.key?(:backends)
  @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
end