Class: Google::Apis::NetworkmanagementV1::LoadBalancerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a load balancer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadBalancerInfo

Returns a new instance of LoadBalancerInfo.



1977
1978
1979
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1977

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_typeString

Type of load balancer's backend configuration. Corresponds to the JSON property backendType

Returns:

  • (String)


1953
1954
1955
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1953

def backend_type
  @backend_type
end

#backend_uriString

Backend configuration URI. Corresponds to the JSON property backendUri

Returns:

  • (String)


1958
1959
1960
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1958

def backend_uri
  @backend_uri
end

#backendsArray<Google::Apis::NetworkmanagementV1::LoadBalancerBackend>

Information for the loadbalancer backends. Corresponds to the JSON property backends



1963
1964
1965
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1963

def backends
  @backends
end

#health_check_uriString

URI of the health check for the load balancer. Deprecated and no longer populated as different load balancer backends might have different health checks. Corresponds to the JSON property healthCheckUri

Returns:

  • (String)


1970
1971
1972
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1970

def health_check_uri
  @health_check_uri
end

#load_balancer_typeString

Type of the load balancer. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


1975
1976
1977
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1975

def load_balancer_type
  @load_balancer_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1982
1983
1984
1985
1986
1987
1988
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 1982

def update!(**args)
  @backend_type = args[:backend_type] if args.key?(:backend_type)
  @backend_uri = args[:backend_uri] if args.key?(:backend_uri)
  @backends = args[:backends] if args.key?(:backends)
  @health_check_uri = args[:health_check_uri] if args.key?(:health_check_uri)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
end