Class: Google::Apis::NetworkmanagementV1::MonitoringPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

Message describing MonitoringPoint resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MonitoringPoint

Returns a new instance of MonitoringPoint.



2501
2502
2503
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_geo_location_enabledBoolean Also known as: auto_geo_location_enabled?

Output only. Indicates if automaitic geographic location is enabled for the MonitoringPoint. Corresponds to the JSON property autoGeoLocationEnabled

Returns:

  • (Boolean)


2405
2406
2407
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2405

def auto_geo_location_enabled
  @auto_geo_location_enabled
end

#connection_statusString

Output only. Connection status of the MonitoringPoint. Corresponds to the JSON property connectionStatus

Returns:

  • (String)


2411
2412
2413
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2411

def connection_status
  @connection_status
end

#create_timeString

Output only. The time the MonitoringPoint was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2416
2417
2418
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2416

def create_time
  @create_time
end

#deployment_typeString

Output only. The deployment type of the MonitoringPoint. Corresponds to the JSON property deploymentType

Returns:

  • (String)


2421
2422
2423
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2421

def deployment_type
  @deployment_type
end

#display_nameString

Output only. Display name of the MonitoringPoint. Corresponds to the JSON property displayName

Returns:

  • (String)


2426
2427
2428
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2426

def display_name
  @display_name
end

#errorsArray<String>

Output only. The codes of errors detected in the MonitoringPoint. Corresponds to the JSON property errors

Returns:

  • (Array<String>)


2431
2432
2433
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2431

def errors
  @errors
end

#geo_locationGoogle::Apis::NetworkmanagementV1::GeoLocation

The geographical location of the MonitoringPoint. Corresponds to the JSON property geoLocation



2436
2437
2438
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2436

def geo_location
  @geo_location
end

#guidString

Output only. The GUID of the MonitoringPoint. Corresponds to the JSON property guid

Returns:

  • (String)


2441
2442
2443
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2441

def guid
  @guid
end

#hostGoogle::Apis::NetworkmanagementV1::Host

Message describing information about the host. Corresponds to the JSON property host



2446
2447
2448
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2446

def host
  @host
end

#hostnameString

Output only. The hostname of the MonitoringPoint. Corresponds to the JSON property hostname

Returns:

  • (String)


2451
2452
2453
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2451

def hostname
  @hostname
end

#nameString

Identifier. Name of the resource. Format: projects/project/locations/ location/networkMonitoringProviders/network_monitoring_provider/ monitoringPoints/monitoring_point` Corresponds to the JSON propertyname`

Returns:

  • (String)


2458
2459
2460
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2458

def name
  @name
end

#network_interfacesArray<Google::Apis::NetworkmanagementV1::NetworkInterface>

Output only. The network interfaces of the MonitoringPoint. Corresponds to the JSON property networkInterfaces



2463
2464
2465
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2463

def network_interfaces
  @network_interfaces
end

#originating_ipString

Output only. IP address visible when MonitoringPoint connects to the provider. Corresponds to the JSON property originatingIp

Returns:

  • (String)


2468
2469
2470
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2468

def originating_ip
  @originating_ip
end

#provider_tagsArray<Google::Apis::NetworkmanagementV1::ProviderTag>

Output only. The provider tags of the MonitoringPoint. Corresponds to the JSON property providerTags



2473
2474
2475
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2473

def provider_tags
  @provider_tags
end

#typeString

Output only. Deployment type of the MonitoringPoint. Corresponds to the JSON property type

Returns:

  • (String)


2478
2479
2480
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2478

def type
  @type
end

#update_timeString

Output only. The time the MonitoringPoint was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2483
2484
2485
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2483

def update_time
  @update_time
end

#upgrade_availableBoolean Also known as: upgrade_available?

Output only. Indicates if an upgrade is available for the MonitoringPoint. Corresponds to the JSON property upgradeAvailable

Returns:

  • (Boolean)


2488
2489
2490
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2488

def upgrade_available
  @upgrade_available
end

#upgrade_typeString

Output only. The type of upgrade available for the MonitoringPoint. Corresponds to the JSON property upgradeType

Returns:

  • (String)


2494
2495
2496
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2494

def upgrade_type
  @upgrade_type
end

#versionString

Output only. Version of the software running on the MonitoringPoint. Corresponds to the JSON property version

Returns:

  • (String)


2499
2500
2501
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2499

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2506
2507
2508
2509
2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2506

def update!(**args)
  @auto_geo_location_enabled = args[:auto_geo_location_enabled] if args.key?(:auto_geo_location_enabled)
  @connection_status = args[:connection_status] if args.key?(:connection_status)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @geo_location = args[:geo_location] if args.key?(:geo_location)
  @guid = args[:guid] if args.key?(:guid)
  @host = args[:host] if args.key?(:host)
  @hostname = args[:hostname] if args.key?(:hostname)
  @name = args[:name] if args.key?(:name)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @originating_ip = args[:originating_ip] if args.key?(:originating_ip)
  @provider_tags = args[:provider_tags] if args.key?(:provider_tags)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @upgrade_available = args[:upgrade_available] if args.key?(:upgrade_available)
  @upgrade_type = args[:upgrade_type] if args.key?(:upgrade_type)
  @version = args[:version] if args.key?(:version)
end