Class: Google::Apis::NetworkmanagementV1::NetworkInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkInfo

Returns a new instance of NetworkInfo.



2625
2626
2627
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a Compute Engine network. Corresponds to the JSON property displayName

Returns:

  • (String)


2603
2604
2605
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2603

def display_name
  @display_name
end

#matched_ip_rangeString

The IP range of the subnet matching the source IP address of the test. Corresponds to the JSON property matchedIpRange

Returns:

  • (String)


2608
2609
2610
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2608

def matched_ip_range
  @matched_ip_range
end

#matched_subnet_uriString

URI of the subnet matching the source IP address of the test. Corresponds to the JSON property matchedSubnetUri

Returns:

  • (String)


2613
2614
2615
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2613

def matched_subnet_uri
  @matched_subnet_uri
end

#regionString

The region of the subnet matching the source IP address of the test. Corresponds to the JSON property region

Returns:

  • (String)


2618
2619
2620
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2618

def region
  @region
end

#uriString

URI of a Compute Engine network. Corresponds to the JSON property uri

Returns:

  • (String)


2623
2624
2625
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2623

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2630
2631
2632
2633
2634
2635
2636
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2630

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @matched_ip_range = args[:matched_ip_range] if args.key?(:matched_ip_range)
  @matched_subnet_uri = args[:matched_subnet_uri] if args.key?(:matched_subnet_uri)
  @region = args[:region] if args.key?(:region)
  @uri = args[:uri] if args.key?(:uri)
end