Class: Google::Apis::NetworkmanagementV1::NetworkInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::NetworkInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine network.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Compute Engine network.
-
#matched_ip_range ⇒ String
The IP range of the subnet matching the source IP address of the test.
-
#matched_subnet_uri ⇒ String
URI of the subnet matching the source IP address of the test.
-
#region ⇒ String
The region of the subnet matching the source IP address of the test.
-
#uri ⇒ String
URI of a Compute Engine network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInfo
constructor
A new instance of NetworkInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkInfo
Returns a new instance of NetworkInfo.
2225 2226 2227 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2225 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Compute Engine network.
Corresponds to the JSON property displayName
2203 2204 2205 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2203 def display_name @display_name end |
#matched_ip_range ⇒ String
The IP range of the subnet matching the source IP address of the test.
Corresponds to the JSON property matchedIpRange
2208 2209 2210 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2208 def matched_ip_range @matched_ip_range end |
#matched_subnet_uri ⇒ String
URI of the subnet matching the source IP address of the test.
Corresponds to the JSON property matchedSubnetUri
2213 2214 2215 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2213 def matched_subnet_uri @matched_subnet_uri end |
#region ⇒ String
The region of the subnet matching the source IP address of the test.
Corresponds to the JSON property region
2218 2219 2220 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2218 def region @region end |
#uri ⇒ String
URI of a Compute Engine network.
Corresponds to the JSON property uri
2223 2224 2225 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2223 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2230 2231 2232 2233 2234 2235 2236 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2230 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @matched_ip_range = args[:matched_ip_range] if args.key?(:matched_ip_range) @matched_subnet_uri = args[:matched_subnet_uri] if args.key?(:matched_subnet_uri) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |