Class: Google::Apis::NetworkmanagementV1::NetworkInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkInfo

Returns a new instance of NetworkInfo.



2165
2166
2167
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a Compute Engine network. Corresponds to the JSON property displayName

Returns:

  • (String)


2143
2144
2145
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2143

def display_name
  @display_name
end

#matched_ip_rangeString

The IP range of the subnet matching the source IP address of the test. Corresponds to the JSON property matchedIpRange

Returns:

  • (String)


2148
2149
2150
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2148

def matched_ip_range
  @matched_ip_range
end

#matched_subnet_uriString

URI of the subnet matching the source IP address of the test. Corresponds to the JSON property matchedSubnetUri

Returns:

  • (String)


2153
2154
2155
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2153

def matched_subnet_uri
  @matched_subnet_uri
end

#regionString

The region of the subnet matching the source IP address of the test. Corresponds to the JSON property region

Returns:

  • (String)


2158
2159
2160
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2158

def region
  @region
end

#uriString

URI of a Compute Engine network. Corresponds to the JSON property uri

Returns:

  • (String)


2163
2164
2165
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2163

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2170
2171
2172
2173
2174
2175
2176
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2170

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @matched_ip_range = args[:matched_ip_range] if args.key?(:matched_ip_range)
  @matched_subnet_uri = args[:matched_subnet_uri] if args.key?(:matched_subnet_uri)
  @region = args[:region] if args.key?(:region)
  @uri = args[:uri] if args.key?(:uri)
end