Class: Google::Apis::NetworkmanagementV1::NetworkInterface
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::NetworkInterface
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Message describing network interfaces.
Instance Attribute Summary collapse
-
#adapter_description ⇒ String
Output only.
-
#cidr ⇒ String
Output only.
-
#interface_name ⇒ String
Output only.
-
#ip_address ⇒ String
Output only.
-
#mac_address ⇒ String
Output only.
-
#speed ⇒ Fixnum
Output only.
-
#vlan_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInterface
constructor
A new instance of NetworkInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkInterface
Returns a new instance of NetworkInterface.
2794 2795 2796 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adapter_description ⇒ String
Output only. The description of the interface.
Corresponds to the JSON property adapterDescription
2761 2762 2763 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2761 def adapter_description @adapter_description end |
#cidr ⇒ String
Output only. The IP address of the interface and subnet mask in CIDR format.
Examples: 192.168.1.0/24, 2001:db8::/32
Corresponds to the JSON property cidr
2767 2768 2769 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2767 def cidr @cidr end |
#interface_name ⇒ String
Output only. The name of the network interface. Examples: eth0, eno1
Corresponds to the JSON property interfaceName
2772 2773 2774 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2772 def interface_name @interface_name end |
#ip_address ⇒ String
Output only. The IP address of the interface.
Corresponds to the JSON property ipAddress
2777 2778 2779 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2777 def ip_address @ip_address end |
#mac_address ⇒ String
Output only. The MAC address of the interface.
Corresponds to the JSON property macAddress
2782 2783 2784 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2782 def mac_address @mac_address end |
#speed ⇒ Fixnum
Output only. Speed of the interface in millions of bits per second.
Corresponds to the JSON property speed
2787 2788 2789 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2787 def speed @speed end |
#vlan_id ⇒ Fixnum
Output only. The id of the VLAN.
Corresponds to the JSON property vlanId
2792 2793 2794 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2792 def vlan_id @vlan_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2799 2800 2801 2802 2803 2804 2805 2806 2807 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2799 def update!(**args) @adapter_description = args[:adapter_description] if args.key?(:adapter_description) @cidr = args[:cidr] if args.key?(:cidr) @interface_name = args[:interface_name] if args.key?(:interface_name) @ip_address = args[:ip_address] if args.key?(:ip_address) @mac_address = args[:mac_address] if args.key?(:mac_address) @speed = args[:speed] if args.key?(:speed) @vlan_id = args[:vlan_id] if args.key?(:vlan_id) end |