Class: Google::Apis::NetworkmanagementV1::NetworkInterface
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::NetworkInterface
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Message describing network interfaces.
Instance Attribute Summary collapse
-
#adapter_description ⇒ String
Output only.
-
#cidr ⇒ String
Output only.
-
#interface_name ⇒ String
Output only.
-
#ip_address ⇒ String
Output only.
-
#mac_address ⇒ String
Output only.
-
#speed ⇒ Fixnum
Output only.
-
#vlan_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInterface
constructor
A new instance of NetworkInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkInterface
Returns a new instance of NetworkInterface.
2679 2680 2681 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adapter_description ⇒ String
Output only. The description of the interface.
Corresponds to the JSON property adapterDescription
2646 2647 2648 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2646 def adapter_description @adapter_description end |
#cidr ⇒ String
Output only. The IP address of the interface and subnet mask in CIDR format.
Examples: 192.168.1.0/24, 2001:db8::/32
Corresponds to the JSON property cidr
2652 2653 2654 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2652 def cidr @cidr end |
#interface_name ⇒ String
Output only. The name of the network interface. Examples: eth0, eno1
Corresponds to the JSON property interfaceName
2657 2658 2659 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2657 def interface_name @interface_name end |
#ip_address ⇒ String
Output only. The IP address of the interface.
Corresponds to the JSON property ipAddress
2662 2663 2664 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2662 def ip_address @ip_address end |
#mac_address ⇒ String
Output only. The MAC address of the interface.
Corresponds to the JSON property macAddress
2667 2668 2669 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2667 def mac_address @mac_address end |
#speed ⇒ Fixnum
Output only. Speed of the interface in millions of bits per second.
Corresponds to the JSON property speed
2672 2673 2674 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2672 def speed @speed end |
#vlan_id ⇒ Fixnum
Output only. The id of the VLAN.
Corresponds to the JSON property vlanId
2677 2678 2679 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2677 def vlan_id @vlan_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2684 2685 2686 2687 2688 2689 2690 2691 2692 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2684 def update!(**args) @adapter_description = args[:adapter_description] if args.key?(:adapter_description) @cidr = args[:cidr] if args.key?(:cidr) @interface_name = args[:interface_name] if args.key?(:interface_name) @ip_address = args[:ip_address] if args.key?(:ip_address) @mac_address = args[:mac_address] if args.key?(:mac_address) @speed = args[:speed] if args.key?(:speed) @vlan_id = args[:vlan_id] if args.key?(:vlan_id) end |