Class: Google::Apis::NetworkmanagementV1::NetworkManagementService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::NetworkmanagementV1::NetworkManagementService
- Defined in:
- lib/google/apis/networkmanagement_v1/service.rb
Overview
Network Management API
The Network Management API provides a collection of network performance monitoring and diagnostic capabilities.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://networkmanagement.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#cancel_organization_location_global_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_organization_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new
VpcFlowLogsConfig. -
#create_project_location_global_connectivity_test(parent, connectivity_test_object = nil, test_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new Connectivity Test.
-
#create_project_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new
VpcFlowLogsConfig. -
#delete_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Deletes a long-running operation.
-
#delete_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific
VpcFlowLogsConfig. -
#delete_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific
ConnectivityTest. -
#delete_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Deletes a long-running operation.
-
#delete_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific
VpcFlowLogsConfig. -
#get_organization_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Location
Gets information about a location.
-
#get_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Gets the latest state of a long-running operation.
-
#get_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig
Gets the details of a specific
VpcFlowLogsConfig. -
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Location
Gets information about a location.
-
#get_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ConnectivityTest
Gets the details of a specific Connectivity Test.
-
#get_project_location_global_connectivity_test_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Policy
Gets the access control policy for a resource.
-
#get_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig
Gets the details of a specific
VpcFlowLogsConfig. -
#initialize ⇒ NetworkManagementService
constructor
A new instance of NetworkManagementService.
-
#list_organization_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_organization_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
Lists all
VpcFlowLogsConfigsin a given organization. -
#list_organization_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#list_project_location_global_connectivity_tests(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse
Lists all Connectivity Tests owned by a project.
-
#list_project_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
Lists all
VpcFlowLogsConfigsin a given project. -
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_organization_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates an existing
VpcFlowLogsConfig. -
#patch_project_location_global_connectivity_test(name, connectivity_test_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates the configuration of an existing
ConnectivityTest. -
#patch_project_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates an existing
VpcFlowLogsConfig. -
#query_project_location_vpc_flow_logs_config_org_vpc_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::QueryOrgVpcFlowLogsConfigsResponse
QueryOrgVpcFlowLogsConfigs returns a list of all organization-level VPC Flow Logs configurations applicable to the specified project.
-
#rerun_connectivity_test(name, rerun_connectivity_test_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Rerun an existing
ConnectivityTest. -
#set_connectivity_test_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Policy
Sets the access control policy on the specified resource.
-
#show_project_location_vpc_flow_logs_config_effective_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, resource: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ShowEffectiveFlowLogsConfigsResponse
ShowEffectiveFlowLogsConfigs returns a list of all VPC Flow Logs configurations applicable to a specified resource.
-
#test_connectivity_test_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ NetworkManagementService
Returns a new instance of NetworkManagementService.
48 49 50 51 52 53 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-networkmanagement_v1', client_version: Google::Apis::NetworkmanagementV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
978 979 980 981 982 983 984 985 986 987 988 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 978 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::NetworkmanagementV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::NetworkmanagementV1::Empty::Representation command.response_class = Google::Apis::NetworkmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_organization_location_global_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 164 def cancel_organization_location_global_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::NetworkmanagementV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::NetworkmanagementV1::Empty::Representation command.response_class = Google::Apis::NetworkmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_organization_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new VpcFlowLogsConfig. If a configuration with the exact same
settings already exists (even if the ID is different), the creation fails.
Notes: 1. Creating a configuration with state=DISABLED will fail 2. The
following fields are not considered as settings for the purpose of the check
mentioned above, therefore - creating another configuration with the same
fields but different values for the following fields will fail as well: * name
- create_time * update_time * labels * description
321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 321 def create_organization_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/vpcFlowLogsConfigs', ) command.request_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.request_object = vpc_flow_logs_config_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['parent'] = parent unless parent.nil? command.query['vpcFlowLogsConfigId'] = vpc_flow_logs_config_id unless vpc_flow_logs_config_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_global_connectivity_test(parent, connectivity_test_object = nil, test_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new Connectivity Test. After you create a test, the reachability
analysis is performed as part of the long running operation, which completes
when the analysis completes. If the endpoint specifications in
ConnectivityTest are invalid (for example, containing non-existent resources
in the network, or you don't have read permissions to the network
configurations of listed projects), then the reachability result returns a
value of UNKNOWN. If the endpoint specifications in ConnectivityTest are
incomplete, the reachability result returns a value of AMBIGUOUS. For more
information, see the Connectivity Test documentation.
615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 615 def create_project_location_global_connectivity_test(parent, connectivity_test_object = nil, test_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/connectivityTests', ) command.request_representation = Google::Apis::NetworkmanagementV1::ConnectivityTest::Representation command.request_object = connectivity_test_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['parent'] = parent unless parent.nil? command.query['testId'] = test_id unless test_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Creates a new VpcFlowLogsConfig. If a configuration with the exact same
settings already exists (even if the ID is different), the creation fails.
Notes: 1. Creating a configuration with state=DISABLED will fail 2. The
following fields are not considered as settings for the purpose of the check
mentioned above, therefore - creating another configuration with the same
fields but different values for the following fields will fail as well: * name
- create_time * update_time * labels * description
1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1135 def create_project_location_vpc_flow_logs_config(parent, vpc_flow_logs_config_object = nil, vpc_flow_logs_config_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/vpcFlowLogsConfigs', ) command.request_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.request_object = vpc_flow_logs_config_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['parent'] = parent unless parent.nil? command.query['vpcFlowLogsConfigId'] = vpc_flow_logs_config_id unless vpc_flow_logs_config_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
199 200 201 202 203 204 205 206 207 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 199 def delete_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Empty::Representation command.response_class = Google::Apis::NetworkmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific VpcFlowLogsConfig.
358 359 360 361 362 363 364 365 366 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 358 def delete_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific ConnectivityTest.
649 650 651 652 653 654 655 656 657 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 649 def delete_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1013 1014 1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1013 def delete_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Empty::Representation command.response_class = Google::Apis::NetworkmanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Deletes a specific VpcFlowLogsConfig.
1172 1173 1174 1175 1176 1177 1178 1179 1180 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1172 def delete_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 75 def get_organization_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Location::Representation command.response_class = Google::Apis::NetworkmanagementV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
230 231 232 233 234 235 236 237 238 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 230 def get_organization_location_global_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig
Gets the details of a specific VpcFlowLogsConfig.
392 393 394 395 396 397 398 399 400 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 392 def get_organization_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.response_class = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Location
Gets information about a location.
519 520 521 522 523 524 525 526 527 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 519 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Location::Representation command.response_class = Google::Apis::NetworkmanagementV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ConnectivityTest
Gets the details of a specific Connectivity Test.
680 681 682 683 684 685 686 687 688 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 680 def get_project_location_global_connectivity_test(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::ConnectivityTest::Representation command.response_class = Google::Apis::NetworkmanagementV1::ConnectivityTest command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_connectivity_test_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
724 725 726 727 728 729 730 731 732 733 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 724 def get_project_location_global_connectivity_test_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::NetworkmanagementV1::Policy::Representation command.response_class = Google::Apis::NetworkmanagementV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1044 1045 1046 1047 1048 1049 1050 1051 1052 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1044 def get_project_location_global_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig
Gets the details of a specific VpcFlowLogsConfig.
1206 1207 1208 1209 1210 1211 1212 1213 1214 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1206 def get_project_location_vpc_flow_logs_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.response_class = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 275 def list_organization_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListOperationsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
Lists all VpcFlowLogsConfigs in a given organization.
435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 435 def list_organization_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/vpcFlowLogsConfigs', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 122 def list_organization_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListLocationsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_global_connectivity_tests(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse
Lists all Connectivity Tests owned by a project.
772 773 774 775 776 777 778 779 780 781 782 783 784 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 772 def list_project_location_global_connectivity_tests(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/connectivityTests', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListConnectivityTestsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1089 def list_project_location_global_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListOperationsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse
Lists all VpcFlowLogsConfigs in a given project.
1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1249 def list_project_location_vpc_flow_logs_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/vpcFlowLogsConfigs', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListVpcFlowLogsConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
566 567 568 569 570 571 572 573 574 575 576 577 578 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 566 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::NetworkmanagementV1::ListLocationsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates an existing VpcFlowLogsConfig. If a configuration with the exact
same settings already exists (even if the ID is different), the creation fails.
Notes: 1. Updating a configuration with state=DISABLED will fail 2. The
following fields are not considered as settings for the purpose of the check
mentioned above, therefore - updating another configuration with the same
fields but different values for the following fields will fail as well: * name
- create_time * update_time * labels * description
486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 486 def patch_organization_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.request_object = vpc_flow_logs_config_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_global_connectivity_test(name, connectivity_test_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates the configuration of an existing ConnectivityTest. After you update
a test, the reachability analysis is performed as part of the long running
operation, which completes when the analysis completes. The Reachability state
in the test resource is updated with the new result. If the endpoint
specifications in ConnectivityTest are invalid (for example, they contain
non-existent resources in the network, or the user does not have read
permissions to the network configurations of listed projects), then the
reachability result returns a value of UNKNOWN. If the endpoint specifications
in ConnectivityTest are incomplete, the reachability result returns a value
of AMBIGUOUS. See the documentation in ConnectivityTest for more details.
820 821 822 823 824 825 826 827 828 829 830 831 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 820 def patch_project_location_global_connectivity_test(name, connectivity_test_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::NetworkmanagementV1::ConnectivityTest::Representation command.request_object = connectivity_test_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Updates an existing VpcFlowLogsConfig. If a configuration with the exact
same settings already exists (even if the ID is different), the creation fails.
Notes: 1. Updating a configuration with state=DISABLED will fail. 2. The
following fields are not considered as settings for the purpose of the check
mentioned above, therefore - updating another configuration with the same
fields but different values for the following fields will fail as well: * name
- create_time * update_time * labels * description
1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1300 def patch_project_location_vpc_flow_logs_config(name, vpc_flow_logs_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::NetworkmanagementV1::VpcFlowLogsConfig::Representation command.request_object = vpc_flow_logs_config_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#query_project_location_vpc_flow_logs_config_org_vpc_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::QueryOrgVpcFlowLogsConfigsResponse
QueryOrgVpcFlowLogsConfigs returns a list of all organization-level VPC Flow Logs configurations applicable to the specified project.
1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1343 def query_project_location_vpc_flow_logs_config_org_vpc_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/vpcFlowLogsConfigs:queryOrgVpcFlowLogsConfigs', ) command.response_representation = Google::Apis::NetworkmanagementV1::QueryOrgVpcFlowLogsConfigsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::QueryOrgVpcFlowLogsConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#rerun_connectivity_test(name, rerun_connectivity_test_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Operation
Rerun an existing ConnectivityTest. After the user triggers the rerun, the
reachability analysis is performed as part of the long running operation,
which completes when the analysis completes. Even though the test
configuration remains the same, the reachability result may change due to
underlying network configuration changes. If the endpoint specifications in
ConnectivityTest become invalid (for example, specified resources are deleted
in the network, or you lost read permissions to the network configurations of
listed projects), then the reachability result returns a value of UNKNOWN.
862 863 864 865 866 867 868 869 870 871 872 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 862 def rerun_connectivity_test(name, rerun_connectivity_test_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:rerun', ) command.request_representation = Google::Apis::NetworkmanagementV1::RerunConnectivityTestRequest::Representation command.request_object = rerun_connectivity_test_request_object command.response_representation = Google::Apis::NetworkmanagementV1::Operation::Representation command.response_class = Google::Apis::NetworkmanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_connectivity_test_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
899 900 901 902 903 904 905 906 907 908 909 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 899 def set_connectivity_test_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::NetworkmanagementV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::NetworkmanagementV1::Policy::Representation command.response_class = Google::Apis::NetworkmanagementV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#show_project_location_vpc_flow_logs_config_effective_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, resource: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::ShowEffectiveFlowLogsConfigsResponse
ShowEffectiveFlowLogsConfigs returns a list of all VPC Flow Logs configurations applicable to a specified resource.
1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 1391 def show_project_location_vpc_flow_logs_config_effective_flow_logs_configs(parent, filter: nil, page_size: nil, page_token: nil, resource: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/vpcFlowLogsConfigs:showEffectiveFlowLogsConfigs', ) command.response_representation = Google::Apis::NetworkmanagementV1::ShowEffectiveFlowLogsConfigsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::ShowEffectiveFlowLogsConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_connectivity_test_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkmanagementV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
938 939 940 941 942 943 944 945 946 947 948 |
# File 'lib/google/apis/networkmanagement_v1/service.rb', line 938 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::NetworkmanagementV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::NetworkmanagementV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::NetworkmanagementV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |