Class: Google::Apis::NetworkmanagementV1::NetworkPath

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

Message describing NetworkPath resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPath

Returns a new instance of NetworkPath.



2885
2886
2887
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the NetworkPath was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2799
2800
2801
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2799

def create_time
  @create_time
end

#destinationString

Output only. IP address or hostname of the network path destination. Corresponds to the JSON property destination

Returns:

  • (String)


2804
2805
2806
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2804

def destination
  @destination
end

#destination_geo_locationGoogle::Apis::NetworkmanagementV1::GeoLocation

The geographical location of the MonitoringPoint. Corresponds to the JSON property destinationGeoLocation



2809
2810
2811
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2809

def destination_geo_location
  @destination_geo_location
end

#destination_monitoring_point_idString

Output only. Provider's UUID of the destination MonitoringPoint. This id may not point to a resource in the Google Cloud. Corresponds to the JSON property destinationMonitoringPointId

Returns:

  • (String)


2815
2816
2817
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2815

def destination_monitoring_point_id
  @destination_monitoring_point_id
end

#display_nameString

Output only. The display name of the network path. Corresponds to the JSON property displayName

Returns:

  • (String)


2820
2821
2822
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2820

def display_name
  @display_name
end

#dual_endedBoolean Also known as: dual_ended?

Output only. Indicates if the network path is dual ended. When true, the network path is measured both: from both source to destination, and from destination to source. When false, the network path is measured from the source through the destination back to the source (round trip measurement). Corresponds to the JSON property dualEnded

Returns:

  • (Boolean)


2828
2829
2830
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2828

def dual_ended
  @dual_ended
end

#monitoring_enabledBoolean Also known as: monitoring_enabled?

Output only. Is monitoring enabled for the network path. Corresponds to the JSON property monitoringEnabled

Returns:

  • (Boolean)


2834
2835
2836
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2834

def monitoring_enabled
  @monitoring_enabled
end

#monitoring_policy_display_nameString

Output only. Display name of the monitoring policy. Corresponds to the JSON property monitoringPolicyDisplayName

Returns:

  • (String)


2840
2841
2842
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2840

def monitoring_policy_display_name
  @monitoring_policy_display_name
end

#monitoring_policy_idString

Output only. ID of monitoring policy. Corresponds to the JSON property monitoringPolicyId

Returns:

  • (String)


2845
2846
2847
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2845

def monitoring_policy_id
  @monitoring_policy_id
end

#monitoring_statusString

Output only. The monitoring status of the network path. Corresponds to the JSON property monitoringStatus

Returns:

  • (String)


2850
2851
2852
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2850

def monitoring_status
  @monitoring_status
end

#nameString

Identifier. Name of the resource. Format: projects/project/locations/ location/networkMonitoringProviders/network_monitoring_provider/ networkPaths/network_path` Corresponds to the JSON propertyname`

Returns:

  • (String)


2857
2858
2859
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2857

def name
  @name
end

#network_protocolString

Output only. The network protocol of the network path. Corresponds to the JSON property networkProtocol

Returns:

  • (String)


2862
2863
2864
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2862

def network_protocol
  @network_protocol
end

#provider_tagsArray<Google::Apis::NetworkmanagementV1::ProviderTag>

Output only. The provider tags of the network path. Corresponds to the JSON property providerTags



2867
2868
2869
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2867

def provider_tags
  @provider_tags
end

#provider_ui_uriString

Output only. Link to provider's UI; link shows the NetworkPath. Corresponds to the JSON property providerUiUri

Returns:

  • (String)


2872
2873
2874
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2872

def provider_ui_uri
  @provider_ui_uri
end

#source_monitoring_point_idString

Output only. Provider's UUID of the source MonitoringPoint. This id may not point to a resource in the Google Cloud. Corresponds to the JSON property sourceMonitoringPointId

Returns:

  • (String)


2878
2879
2880
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2878

def source_monitoring_point_id
  @source_monitoring_point_id
end

#update_timeString

Output only. The time the NetworkPath was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2883
2884
2885
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2883

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2890

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destination = args[:destination] if args.key?(:destination)
  @destination_geo_location = args[:destination_geo_location] if args.key?(:destination_geo_location)
  @destination_monitoring_point_id = args[:destination_monitoring_point_id] if args.key?(:destination_monitoring_point_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @dual_ended = args[:dual_ended] if args.key?(:dual_ended)
  @monitoring_enabled = args[:monitoring_enabled] if args.key?(:monitoring_enabled)
  @monitoring_policy_display_name = args[:monitoring_policy_display_name] if args.key?(:monitoring_policy_display_name)
  @monitoring_policy_id = args[:monitoring_policy_id] if args.key?(:monitoring_policy_id)
  @monitoring_status = args[:monitoring_status] if args.key?(:monitoring_status)
  @name = args[:name] if args.key?(:name)
  @network_protocol = args[:network_protocol] if args.key?(:network_protocol)
  @provider_tags = args[:provider_tags] if args.key?(:provider_tags)
  @provider_ui_uri = args[:provider_ui_uri] if args.key?(:provider_ui_uri)
  @source_monitoring_point_id = args[:source_monitoring_point_id] if args.key?(:source_monitoring_point_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end