Class: Google::Apis::NetworkmanagementV1::NetworkPath
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::NetworkPath
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Message describing NetworkPath resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#destination ⇒ String
Output only.
-
#destination_geo_location ⇒ Google::Apis::NetworkmanagementV1::GeoLocation
The geographical location of the MonitoringPoint.
-
#destination_monitoring_point_id ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#dual_ended ⇒ Boolean
(also: #dual_ended?)
Output only.
-
#monitoring_enabled ⇒ Boolean
(also: #monitoring_enabled?)
Output only.
-
#monitoring_policy_display_name ⇒ String
Output only.
-
#monitoring_policy_id ⇒ String
Output only.
-
#monitoring_status ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#network_protocol ⇒ String
Output only.
-
#provider_tags ⇒ Array<Google::Apis::NetworkmanagementV1::ProviderTag>
Output only.
-
#provider_ui_uri ⇒ String
Output only.
-
#source_monitoring_point_id ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPath
constructor
A new instance of NetworkPath.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPath
Returns a new instance of NetworkPath.
2845 2846 2847 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the NetworkPath was created.
Corresponds to the JSON property createTime
2759 2760 2761 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2759 def create_time @create_time end |
#destination ⇒ String
Output only. IP address or hostname of the network path destination.
Corresponds to the JSON property destination
2764 2765 2766 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2764 def destination @destination end |
#destination_geo_location ⇒ Google::Apis::NetworkmanagementV1::GeoLocation
The geographical location of the MonitoringPoint.
Corresponds to the JSON property destinationGeoLocation
2769 2770 2771 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2769 def destination_geo_location @destination_geo_location end |
#destination_monitoring_point_id ⇒ String
Output only. Provider's UUID of the destination MonitoringPoint. This id may
not point to a resource in the Google Cloud.
Corresponds to the JSON property destinationMonitoringPointId
2775 2776 2777 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2775 def destination_monitoring_point_id @destination_monitoring_point_id end |
#display_name ⇒ String
Output only. The display name of the network path.
Corresponds to the JSON property displayName
2780 2781 2782 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2780 def display_name @display_name end |
#dual_ended ⇒ Boolean Also known as: dual_ended?
Output only. Indicates if the network path is dual ended. When true, the
network path is measured both: from both source to destination, and from
destination to source. When false, the network path is measured from the
source through the destination back to the source (round trip measurement).
Corresponds to the JSON property dualEnded
2788 2789 2790 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2788 def dual_ended @dual_ended end |
#monitoring_enabled ⇒ Boolean Also known as: monitoring_enabled?
Output only. Is monitoring enabled for the network path.
Corresponds to the JSON property monitoringEnabled
2794 2795 2796 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2794 def monitoring_enabled @monitoring_enabled end |
#monitoring_policy_display_name ⇒ String
Output only. Display name of the monitoring policy.
Corresponds to the JSON property monitoringPolicyDisplayName
2800 2801 2802 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2800 def monitoring_policy_display_name @monitoring_policy_display_name end |
#monitoring_policy_id ⇒ String
Output only. ID of monitoring policy.
Corresponds to the JSON property monitoringPolicyId
2805 2806 2807 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2805 def monitoring_policy_id @monitoring_policy_id end |
#monitoring_status ⇒ String
Output only. The monitoring status of the network path.
Corresponds to the JSON property monitoringStatus
2810 2811 2812 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2810 def monitoring_status @monitoring_status end |
#name ⇒ String
Identifier. Name of the resource. Format: projects/project/locations/
location/networkMonitoringProviders/network_monitoring_provider/
networkPaths/network_path`
Corresponds to the JSON propertyname`
2817 2818 2819 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2817 def name @name end |
#network_protocol ⇒ String
Output only. The network protocol of the network path.
Corresponds to the JSON property networkProtocol
2822 2823 2824 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2822 def network_protocol @network_protocol end |
#provider_tags ⇒ Array<Google::Apis::NetworkmanagementV1::ProviderTag>
Output only. The provider tags of the network path.
Corresponds to the JSON property providerTags
2827 2828 2829 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2827 def @provider_tags end |
#provider_ui_uri ⇒ String
Output only. Link to provider's UI; link shows the NetworkPath.
Corresponds to the JSON property providerUiUri
2832 2833 2834 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2832 def provider_ui_uri @provider_ui_uri end |
#source_monitoring_point_id ⇒ String
Output only. Provider's UUID of the source MonitoringPoint. This id may not
point to a resource in the Google Cloud.
Corresponds to the JSON property sourceMonitoringPointId
2838 2839 2840 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2838 def source_monitoring_point_id @source_monitoring_point_id end |
#update_time ⇒ String
Output only. The time the NetworkPath was updated.
Corresponds to the JSON property updateTime
2843 2844 2845 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2843 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2850 2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2850 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @destination = args[:destination] if args.key?(:destination) @destination_geo_location = args[:destination_geo_location] if args.key?(:destination_geo_location) @destination_monitoring_point_id = args[:destination_monitoring_point_id] if args.key?(:destination_monitoring_point_id) @display_name = args[:display_name] if args.key?(:display_name) @dual_ended = args[:dual_ended] if args.key?(:dual_ended) @monitoring_enabled = args[:monitoring_enabled] if args.key?(:monitoring_enabled) @monitoring_policy_display_name = args[:monitoring_policy_display_name] if args.key?(:monitoring_policy_display_name) @monitoring_policy_id = args[:monitoring_policy_id] if args.key?(:monitoring_policy_id) @monitoring_status = args[:monitoring_status] if args.key?(:monitoring_status) @name = args[:name] if args.key?(:name) @network_protocol = args[:network_protocol] if args.key?(:network_protocol) @provider_tags = args[:provider_tags] if args.key?(:provider_tags) @provider_ui_uri = args[:provider_ui_uri] if args.key?(:provider_ui_uri) @source_monitoring_point_id = args[:source_monitoring_point_id] if args.key?(:source_monitoring_point_id) @update_time = args[:update_time] if args.key?(:update_time) end |