Class: Google::Apis::NetworkmanagementV1::NgfwPacketInspectionInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::NgfwPacketInspectionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a layer 7 packet inspection by the firewall.
Instance Attribute Summary collapse
-
#security_profile_group_uri ⇒ String
URI of the security profile group associated with this firewall packet inspection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NgfwPacketInspectionInfo
constructor
A new instance of NgfwPacketInspectionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NgfwPacketInspectionInfo
Returns a new instance of NgfwPacketInspectionInfo.
2190 2191 2192 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2190 def initialize(**args) update!(**args) end |
Instance Attribute Details
#security_profile_group_uri ⇒ String
URI of the security profile group associated with this firewall packet
inspection.
Corresponds to the JSON property securityProfileGroupUri
2188 2189 2190 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2188 def security_profile_group_uri @security_profile_group_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2195 2196 2197 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2195 def update!(**args) @security_profile_group_uri = args[:security_profile_group_uri] if args.key?(:security_profile_group_uri) end |