Class: Google::Apis::NetworkmanagementV1::ProbingDetails
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ProbingDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Results of active probing from the last run of the test.
Instance Attribute Summary collapse
-
#abort_cause ⇒ String
The reason probing was aborted.
-
#destination_egress_location ⇒ Google::Apis::NetworkmanagementV1::EdgeLocation
Representation of a network edge location as per https://cloud.google.com/vpc/ docs/edge-locations.
-
#edge_responses ⇒ Array<Google::Apis::NetworkmanagementV1::SingleEdgeResponse>
Probing results for all edge devices.
-
#endpoint_info ⇒ Google::Apis::NetworkmanagementV1::EndpointInfo
For display only.
-
#error ⇒ Google::Apis::NetworkmanagementV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#probed_all_devices ⇒ Boolean
(also: #probed_all_devices?)
Whether all relevant edge devices were probed.
-
#probing_latency ⇒ Google::Apis::NetworkmanagementV1::LatencyDistribution
Describes measured latency distribution.
-
#result ⇒ String
The overall result of active probing.
-
#sent_probe_count ⇒ Fixnum
Number of probes sent.
-
#successful_probe_count ⇒ Fixnum
Number of probes that reached the destination.
-
#verify_time ⇒ String
The time that reachability was assessed through active probing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProbingDetails
constructor
A new instance of ProbingDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProbingDetails
Returns a new instance of ProbingDetails.
3309 3310 3311 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3309 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abort_cause ⇒ String
The reason probing was aborted.
Corresponds to the JSON property abortCause
3248 3249 3250 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3248 def abort_cause @abort_cause end |
#destination_egress_location ⇒ Google::Apis::NetworkmanagementV1::EdgeLocation
Representation of a network edge location as per https://cloud.google.com/vpc/
docs/edge-locations.
Corresponds to the JSON property destinationEgressLocation
3254 3255 3256 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3254 def destination_egress_location @destination_egress_location end |
#edge_responses ⇒ Array<Google::Apis::NetworkmanagementV1::SingleEdgeResponse>
Probing results for all edge devices.
Corresponds to the JSON property edgeResponses
3259 3260 3261 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3259 def edge_responses @edge_responses end |
#endpoint_info ⇒ Google::Apis::NetworkmanagementV1::EndpointInfo
For display only. The specification of the endpoints for the test.
EndpointInfo is derived from source and destination Endpoint and validated by
the backend data plane model.
Corresponds to the JSON property endpointInfo
3266 3267 3268 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3266 def endpoint_info @endpoint_info end |
#error ⇒ Google::Apis::NetworkmanagementV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
3276 3277 3278 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3276 def error @error end |
#probed_all_devices ⇒ Boolean Also known as: probed_all_devices?
Whether all relevant edge devices were probed.
Corresponds to the JSON property probedAllDevices
3281 3282 3283 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3281 def probed_all_devices @probed_all_devices end |
#probing_latency ⇒ Google::Apis::NetworkmanagementV1::LatencyDistribution
Describes measured latency distribution.
Corresponds to the JSON property probingLatency
3287 3288 3289 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3287 def probing_latency @probing_latency end |
#result ⇒ String
The overall result of active probing.
Corresponds to the JSON property result
3292 3293 3294 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3292 def result @result end |
#sent_probe_count ⇒ Fixnum
Number of probes sent.
Corresponds to the JSON property sentProbeCount
3297 3298 3299 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3297 def sent_probe_count @sent_probe_count end |
#successful_probe_count ⇒ Fixnum
Number of probes that reached the destination.
Corresponds to the JSON property successfulProbeCount
3302 3303 3304 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3302 def successful_probe_count @successful_probe_count end |
#verify_time ⇒ String
The time that reachability was assessed through active probing.
Corresponds to the JSON property verifyTime
3307 3308 3309 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3307 def verify_time @verify_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3314 def update!(**args) @abort_cause = args[:abort_cause] if args.key?(:abort_cause) @destination_egress_location = args[:destination_egress_location] if args.key?(:destination_egress_location) @edge_responses = args[:edge_responses] if args.key?(:edge_responses) @endpoint_info = args[:endpoint_info] if args.key?(:endpoint_info) @error = args[:error] if args.key?(:error) @probed_all_devices = args[:probed_all_devices] if args.key?(:probed_all_devices) @probing_latency = args[:probing_latency] if args.key?(:probing_latency) @result = args[:result] if args.key?(:result) @sent_probe_count = args[:sent_probe_count] if args.key?(:sent_probe_count) @successful_probe_count = args[:successful_probe_count] if args.key?(:successful_probe_count) @verify_time = args[:verify_time] if args.key?(:verify_time) end |