Class: Google::Apis::NetworkmanagementV1::ProbingDetails
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ProbingDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Results of active probing from the last run of the test.
Instance Attribute Summary collapse
-
#abort_cause ⇒ String
The reason probing was aborted.
-
#destination_egress_location ⇒ Google::Apis::NetworkmanagementV1::EdgeLocation
Representation of a network edge location as per https://cloud.google.com/vpc/ docs/edge-locations.
-
#edge_responses ⇒ Array<Google::Apis::NetworkmanagementV1::SingleEdgeResponse>
Probing results for all edge devices.
-
#endpoint_info ⇒ Google::Apis::NetworkmanagementV1::EndpointInfo
For display only.
-
#error ⇒ Google::Apis::NetworkmanagementV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#probed_all_devices ⇒ Boolean
(also: #probed_all_devices?)
Whether all relevant edge devices were probed.
-
#probing_latency ⇒ Google::Apis::NetworkmanagementV1::LatencyDistribution
Describes measured latency distribution.
-
#result ⇒ String
The overall result of active probing.
-
#sent_probe_count ⇒ Fixnum
Number of probes sent.
-
#successful_probe_count ⇒ Fixnum
Number of probes that reached the destination.
-
#verify_time ⇒ String
The time that reachability was assessed through active probing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProbingDetails
constructor
A new instance of ProbingDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProbingDetails
Returns a new instance of ProbingDetails.
3233 3234 3235 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abort_cause ⇒ String
The reason probing was aborted.
Corresponds to the JSON property abortCause
3172 3173 3174 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3172 def abort_cause @abort_cause end |
#destination_egress_location ⇒ Google::Apis::NetworkmanagementV1::EdgeLocation
Representation of a network edge location as per https://cloud.google.com/vpc/
docs/edge-locations.
Corresponds to the JSON property destinationEgressLocation
3178 3179 3180 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3178 def destination_egress_location @destination_egress_location end |
#edge_responses ⇒ Array<Google::Apis::NetworkmanagementV1::SingleEdgeResponse>
Probing results for all edge devices.
Corresponds to the JSON property edgeResponses
3183 3184 3185 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3183 def edge_responses @edge_responses end |
#endpoint_info ⇒ Google::Apis::NetworkmanagementV1::EndpointInfo
For display only. The specification of the endpoints for the test.
EndpointInfo is derived from source and destination Endpoint and validated by
the backend data plane model.
Corresponds to the JSON property endpointInfo
3190 3191 3192 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3190 def endpoint_info @endpoint_info end |
#error ⇒ Google::Apis::NetworkmanagementV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
3200 3201 3202 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3200 def error @error end |
#probed_all_devices ⇒ Boolean Also known as: probed_all_devices?
Whether all relevant edge devices were probed.
Corresponds to the JSON property probedAllDevices
3205 3206 3207 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3205 def probed_all_devices @probed_all_devices end |
#probing_latency ⇒ Google::Apis::NetworkmanagementV1::LatencyDistribution
Describes measured latency distribution.
Corresponds to the JSON property probingLatency
3211 3212 3213 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3211 def probing_latency @probing_latency end |
#result ⇒ String
The overall result of active probing.
Corresponds to the JSON property result
3216 3217 3218 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3216 def result @result end |
#sent_probe_count ⇒ Fixnum
Number of probes sent.
Corresponds to the JSON property sentProbeCount
3221 3222 3223 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3221 def sent_probe_count @sent_probe_count end |
#successful_probe_count ⇒ Fixnum
Number of probes that reached the destination.
Corresponds to the JSON property successfulProbeCount
3226 3227 3228 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3226 def successful_probe_count @successful_probe_count end |
#verify_time ⇒ String
The time that reachability was assessed through active probing.
Corresponds to the JSON property verifyTime
3231 3232 3233 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3231 def verify_time @verify_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3238 def update!(**args) @abort_cause = args[:abort_cause] if args.key?(:abort_cause) @destination_egress_location = args[:destination_egress_location] if args.key?(:destination_egress_location) @edge_responses = args[:edge_responses] if args.key?(:edge_responses) @endpoint_info = args[:endpoint_info] if args.key?(:endpoint_info) @error = args[:error] if args.key?(:error) @probed_all_devices = args[:probed_all_devices] if args.key?(:probed_all_devices) @probing_latency = args[:probing_latency] if args.key?(:probing_latency) @result = args[:result] if args.key?(:result) @sent_probe_count = args[:sent_probe_count] if args.key?(:sent_probe_count) @successful_probe_count = args[:successful_probe_count] if args.key?(:successful_probe_count) @verify_time = args[:verify_time] if args.key?(:verify_time) end |