Class: Google::Apis::NetworkmanagementV1::ProbingDetails
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ProbingDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Results of active probing from the last run of the test.
Instance Attribute Summary collapse
-
#abort_cause ⇒ String
The reason probing was aborted.
-
#destination_egress_location ⇒ Google::Apis::NetworkmanagementV1::EdgeLocation
Representation of a network edge location as per https://cloud.google.com/vpc/ docs/edge-locations.
-
#edge_responses ⇒ Array<Google::Apis::NetworkmanagementV1::SingleEdgeResponse>
Probing results for all edge devices.
-
#endpoint_info ⇒ Google::Apis::NetworkmanagementV1::EndpointInfo
For display only.
-
#error ⇒ Google::Apis::NetworkmanagementV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#probed_all_devices ⇒ Boolean
(also: #probed_all_devices?)
Whether all relevant edge devices were probed.
-
#probing_latency ⇒ Google::Apis::NetworkmanagementV1::LatencyDistribution
Describes measured latency distribution.
-
#result ⇒ String
The overall result of active probing.
-
#sent_probe_count ⇒ Fixnum
Number of probes sent.
-
#successful_probe_count ⇒ Fixnum
Number of probes that reached the destination.
-
#verify_time ⇒ String
The time that reachability was assessed through active probing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProbingDetails
constructor
A new instance of ProbingDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProbingDetails
Returns a new instance of ProbingDetails.
2542 2543 2544 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abort_cause ⇒ String
The reason probing was aborted.
Corresponds to the JSON property abortCause
2481 2482 2483 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2481 def abort_cause @abort_cause end |
#destination_egress_location ⇒ Google::Apis::NetworkmanagementV1::EdgeLocation
Representation of a network edge location as per https://cloud.google.com/vpc/
docs/edge-locations.
Corresponds to the JSON property destinationEgressLocation
2487 2488 2489 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2487 def destination_egress_location @destination_egress_location end |
#edge_responses ⇒ Array<Google::Apis::NetworkmanagementV1::SingleEdgeResponse>
Probing results for all edge devices.
Corresponds to the JSON property edgeResponses
2492 2493 2494 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2492 def edge_responses @edge_responses end |
#endpoint_info ⇒ Google::Apis::NetworkmanagementV1::EndpointInfo
For display only. The specification of the endpoints for the test.
EndpointInfo is derived from source and destination Endpoint and validated by
the backend data plane model.
Corresponds to the JSON property endpointInfo
2499 2500 2501 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2499 def endpoint_info @endpoint_info end |
#error ⇒ Google::Apis::NetworkmanagementV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
2509 2510 2511 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2509 def error @error end |
#probed_all_devices ⇒ Boolean Also known as: probed_all_devices?
Whether all relevant edge devices were probed.
Corresponds to the JSON property probedAllDevices
2514 2515 2516 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2514 def probed_all_devices @probed_all_devices end |
#probing_latency ⇒ Google::Apis::NetworkmanagementV1::LatencyDistribution
Describes measured latency distribution.
Corresponds to the JSON property probingLatency
2520 2521 2522 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2520 def probing_latency @probing_latency end |
#result ⇒ String
The overall result of active probing.
Corresponds to the JSON property result
2525 2526 2527 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2525 def result @result end |
#sent_probe_count ⇒ Fixnum
Number of probes sent.
Corresponds to the JSON property sentProbeCount
2530 2531 2532 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2530 def sent_probe_count @sent_probe_count end |
#successful_probe_count ⇒ Fixnum
Number of probes that reached the destination.
Corresponds to the JSON property successfulProbeCount
2535 2536 2537 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2535 def successful_probe_count @successful_probe_count end |
#verify_time ⇒ String
The time that reachability was assessed through active probing.
Corresponds to the JSON property verifyTime
2540 2541 2542 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2540 def verify_time @verify_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2547 def update!(**args) @abort_cause = args[:abort_cause] if args.key?(:abort_cause) @destination_egress_location = args[:destination_egress_location] if args.key?(:destination_egress_location) @edge_responses = args[:edge_responses] if args.key?(:edge_responses) @endpoint_info = args[:endpoint_info] if args.key?(:endpoint_info) @error = args[:error] if args.key?(:error) @probed_all_devices = args[:probed_all_devices] if args.key?(:probed_all_devices) @probing_latency = args[:probing_latency] if args.key?(:probing_latency) @result = args[:result] if args.key?(:result) @sent_probe_count = args[:sent_probe_count] if args.key?(:sent_probe_count) @successful_probe_count = args[:successful_probe_count] if args.key?(:successful_probe_count) @verify_time = args[:verify_time] if args.key?(:verify_time) end |