Class: Google::Apis::NetworkmanagementV1::ProbingDetails
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ProbingDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Results of active probing from the last run of the test.
Instance Attribute Summary collapse
-
#abort_cause ⇒ String
The reason probing was aborted.
-
#destination_egress_location ⇒ Google::Apis::NetworkmanagementV1::EdgeLocation
Representation of a network edge location as per https://cloud.google.com/vpc/ docs/edge-locations.
-
#edge_responses ⇒ Array<Google::Apis::NetworkmanagementV1::SingleEdgeResponse>
Probing results for all edge devices.
-
#endpoint_info ⇒ Google::Apis::NetworkmanagementV1::EndpointInfo
For display only.
-
#error ⇒ Google::Apis::NetworkmanagementV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#probed_all_devices ⇒ Boolean
(also: #probed_all_devices?)
Whether all relevant edge devices were probed.
-
#probing_latency ⇒ Google::Apis::NetworkmanagementV1::LatencyDistribution
Describes measured latency distribution.
-
#result ⇒ String
The overall result of active probing.
-
#sent_probe_count ⇒ Fixnum
Number of probes sent.
-
#successful_probe_count ⇒ Fixnum
Number of probes that reached the destination.
-
#verify_time ⇒ String
The time that reachability was assessed through active probing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProbingDetails
constructor
A new instance of ProbingDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProbingDetails
Returns a new instance of ProbingDetails.
2482 2483 2484 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abort_cause ⇒ String
The reason probing was aborted.
Corresponds to the JSON property abortCause
2421 2422 2423 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2421 def abort_cause @abort_cause end |
#destination_egress_location ⇒ Google::Apis::NetworkmanagementV1::EdgeLocation
Representation of a network edge location as per https://cloud.google.com/vpc/
docs/edge-locations.
Corresponds to the JSON property destinationEgressLocation
2427 2428 2429 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2427 def destination_egress_location @destination_egress_location end |
#edge_responses ⇒ Array<Google::Apis::NetworkmanagementV1::SingleEdgeResponse>
Probing results for all edge devices.
Corresponds to the JSON property edgeResponses
2432 2433 2434 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2432 def edge_responses @edge_responses end |
#endpoint_info ⇒ Google::Apis::NetworkmanagementV1::EndpointInfo
For display only. The specification of the endpoints for the test.
EndpointInfo is derived from source and destination Endpoint and validated by
the backend data plane model.
Corresponds to the JSON property endpointInfo
2439 2440 2441 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2439 def endpoint_info @endpoint_info end |
#error ⇒ Google::Apis::NetworkmanagementV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
2449 2450 2451 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2449 def error @error end |
#probed_all_devices ⇒ Boolean Also known as: probed_all_devices?
Whether all relevant edge devices were probed.
Corresponds to the JSON property probedAllDevices
2454 2455 2456 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2454 def probed_all_devices @probed_all_devices end |
#probing_latency ⇒ Google::Apis::NetworkmanagementV1::LatencyDistribution
Describes measured latency distribution.
Corresponds to the JSON property probingLatency
2460 2461 2462 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2460 def probing_latency @probing_latency end |
#result ⇒ String
The overall result of active probing.
Corresponds to the JSON property result
2465 2466 2467 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2465 def result @result end |
#sent_probe_count ⇒ Fixnum
Number of probes sent.
Corresponds to the JSON property sentProbeCount
2470 2471 2472 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2470 def sent_probe_count @sent_probe_count end |
#successful_probe_count ⇒ Fixnum
Number of probes that reached the destination.
Corresponds to the JSON property successfulProbeCount
2475 2476 2477 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2475 def successful_probe_count @successful_probe_count end |
#verify_time ⇒ String
The time that reachability was assessed through active probing.
Corresponds to the JSON property verifyTime
2480 2481 2482 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2480 def verify_time @verify_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2487 def update!(**args) @abort_cause = args[:abort_cause] if args.key?(:abort_cause) @destination_egress_location = args[:destination_egress_location] if args.key?(:destination_egress_location) @edge_responses = args[:edge_responses] if args.key?(:edge_responses) @endpoint_info = args[:endpoint_info] if args.key?(:endpoint_info) @error = args[:error] if args.key?(:error) @probed_all_devices = args[:probed_all_devices] if args.key?(:probed_all_devices) @probing_latency = args[:probing_latency] if args.key?(:probing_latency) @result = args[:result] if args.key?(:result) @sent_probe_count = args[:sent_probe_count] if args.key?(:sent_probe_count) @successful_probe_count = args[:successful_probe_count] if args.key?(:successful_probe_count) @verify_time = args[:verify_time] if args.key?(:verify_time) end |