Class: Google::Apis::NetworkmanagementV1::ReachabilityDetails
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::ReachabilityDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
Results of the configuration analysis from the last run of the test.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::NetworkmanagementV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#result ⇒ String
The overall result of the test's configuration analysis.
-
#traces ⇒ Array<Google::Apis::NetworkmanagementV1::Trace>
Result may contain a list of traces if a test has multiple possible paths in the network, such as when destination endpoint is a load balancer with multiple backends.
-
#verify_time ⇒ String
The time of the configuration analysis.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReachabilityDetails
constructor
A new instance of ReachabilityDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReachabilityDetails
Returns a new instance of ReachabilityDetails.
2644 2645 2646 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2644 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::NetworkmanagementV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
2625 2626 2627 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2625 def error @error end |
#result ⇒ String
The overall result of the test's configuration analysis.
Corresponds to the JSON property result
2630 2631 2632 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2630 def result @result end |
#traces ⇒ Array<Google::Apis::NetworkmanagementV1::Trace>
Result may contain a list of traces if a test has multiple possible paths in
the network, such as when destination endpoint is a load balancer with
multiple backends.
Corresponds to the JSON property traces
2637 2638 2639 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2637 def traces @traces end |
#verify_time ⇒ String
The time of the configuration analysis.
Corresponds to the JSON property verifyTime
2642 2643 2644 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2642 def verify_time @verify_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2649 2650 2651 2652 2653 2654 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2649 def update!(**args) @error = args[:error] if args.key?(:error) @result = args[:result] if args.key?(:result) @traces = args[:traces] if args.key?(:traces) @verify_time = args[:verify_time] if args.key?(:verify_time) end |