Class: Google::Apis::NetworkmanagementV1::RedisClusterInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::RedisClusterInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Redis Cluster.
Instance Attribute Summary collapse
-
#discovery_endpoint_ip_address ⇒ String
Discovery endpoint IP address of a Redis Cluster.
-
#display_name ⇒ String
Name of a Redis Cluster.
-
#location ⇒ String
Name of the region in which the Redis Cluster is defined.
-
#network_uri ⇒ String
URI of the network containing the Redis Cluster endpoints in format "projects/
project_id/global/networks/network_id". -
#secondary_endpoint_ip_address ⇒ String
Secondary endpoint IP address of a Redis Cluster.
-
#uri ⇒ String
URI of a Redis Cluster in format "projects/
project_id/locations/location/ clusters/cluster_id" Corresponds to the JSON propertyuri.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RedisClusterInfo
constructor
A new instance of RedisClusterInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RedisClusterInfo
Returns a new instance of RedisClusterInfo.
3554 3555 3556 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3554 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discovery_endpoint_ip_address ⇒ String
Discovery endpoint IP address of a Redis Cluster.
Corresponds to the JSON property discoveryEndpointIpAddress
3524 3525 3526 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3524 def discovery_endpoint_ip_address @discovery_endpoint_ip_address end |
#display_name ⇒ String
Name of a Redis Cluster.
Corresponds to the JSON property displayName
3529 3530 3531 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3529 def display_name @display_name end |
#location ⇒ String
Name of the region in which the Redis Cluster is defined. For example, "us-
central1".
Corresponds to the JSON property location
3535 3536 3537 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3535 def location @location end |
#network_uri ⇒ String
URI of the network containing the Redis Cluster endpoints in format "projects/
project_id/global/networks/network_id".
Corresponds to the JSON property networkUri
3541 3542 3543 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3541 def network_uri @network_uri end |
#secondary_endpoint_ip_address ⇒ String
Secondary endpoint IP address of a Redis Cluster.
Corresponds to the JSON property secondaryEndpointIpAddress
3546 3547 3548 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3546 def secondary_endpoint_ip_address @secondary_endpoint_ip_address end |
#uri ⇒ String
URI of a Redis Cluster in format "projects/project_id/locations/location/
clusters/cluster_id"
Corresponds to the JSON property uri
3552 3553 3554 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3552 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3559 3560 3561 3562 3563 3564 3565 3566 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3559 def update!(**args) @discovery_endpoint_ip_address = args[:discovery_endpoint_ip_address] if args.key?(:discovery_endpoint_ip_address) @display_name = args[:display_name] if args.key?(:display_name) @location = args[:location] if args.key?(:location) @network_uri = args[:network_uri] if args.key?(:network_uri) @secondary_endpoint_ip_address = args[:secondary_endpoint_ip_address] if args.key?(:secondary_endpoint_ip_address) @uri = args[:uri] if args.key?(:uri) end |