Class: Google::Apis::NetworkmanagementV1::RedisClusterInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Redis Cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RedisClusterInfo

Returns a new instance of RedisClusterInfo.



3436
3437
3438
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discovery_endpoint_ip_addressString

Discovery endpoint IP address of a Redis Cluster. Corresponds to the JSON property discoveryEndpointIpAddress

Returns:

  • (String)


3406
3407
3408
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3406

def discovery_endpoint_ip_address
  @discovery_endpoint_ip_address
end

#display_nameString

Name of a Redis Cluster. Corresponds to the JSON property displayName

Returns:

  • (String)


3411
3412
3413
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3411

def display_name
  @display_name
end

#locationString

Name of the region in which the Redis Cluster is defined. For example, "us- central1". Corresponds to the JSON property location

Returns:

  • (String)


3417
3418
3419
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3417

def location
  @location
end

#network_uriString

URI of the network containing the Redis Cluster endpoints in format "projects/ project_id/global/networks/network_id". Corresponds to the JSON property networkUri

Returns:

  • (String)


3423
3424
3425
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3423

def network_uri
  @network_uri
end

#secondary_endpoint_ip_addressString

Secondary endpoint IP address of a Redis Cluster. Corresponds to the JSON property secondaryEndpointIpAddress

Returns:

  • (String)


3428
3429
3430
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3428

def secondary_endpoint_ip_address
  @secondary_endpoint_ip_address
end

#uriString

URI of a Redis Cluster in format "projects/project_id/locations/location/ clusters/cluster_id" Corresponds to the JSON property uri

Returns:

  • (String)


3434
3435
3436
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3434

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3441
3442
3443
3444
3445
3446
3447
3448
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3441

def update!(**args)
  @discovery_endpoint_ip_address = args[:discovery_endpoint_ip_address] if args.key?(:discovery_endpoint_ip_address)
  @display_name = args[:display_name] if args.key?(:display_name)
  @location = args[:location] if args.key?(:location)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @secondary_endpoint_ip_address = args[:secondary_endpoint_ip_address] if args.key?(:secondary_endpoint_ip_address)
  @uri = args[:uri] if args.key?(:uri)
end