Class: Google::Apis::NetworkmanagementV1::RedisInstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::RedisInstanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Cloud Redis Instance.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Cloud Redis Instance.
-
#network_uri ⇒ String
URI of a Cloud Redis Instance network in format "projects/
project/global/ networks/network". -
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
-
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
-
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
-
#uri ⇒ String
URI of a Cloud Redis Instance in format "projects/
project/locations/location/instances/instance" Corresponds to the JSON propertyuri.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RedisInstanceInfo
constructor
A new instance of RedisInstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RedisInstanceInfo
Returns a new instance of RedisInstanceInfo.
3605 3606 3607 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Cloud Redis Instance.
Corresponds to the JSON property displayName
3576 3577 3578 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3576 def display_name @display_name end |
#network_uri ⇒ String
URI of a Cloud Redis Instance network in format "projects/project/global/
networks/network".
Corresponds to the JSON property networkUri
3582 3583 3584 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3582 def network_uri @network_uri end |
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
Corresponds to the JSON property primaryEndpointIp
3587 3588 3589 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3587 def primary_endpoint_ip @primary_endpoint_ip end |
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
Corresponds to the JSON property readEndpointIp
3592 3593 3594 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3592 def read_endpoint_ip @read_endpoint_ip end |
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
Corresponds to the JSON property region
3597 3598 3599 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3597 def region @region end |
#uri ⇒ String
URI of a Cloud Redis Instance in format "projects/project/locations/
location/instances/instance"
Corresponds to the JSON property uri
3603 3604 3605 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3603 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3610 3611 3612 3613 3614 3615 3616 3617 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3610 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @network_uri = args[:network_uri] if args.key?(:network_uri) @primary_endpoint_ip = args[:primary_endpoint_ip] if args.key?(:primary_endpoint_ip) @read_endpoint_ip = args[:read_endpoint_ip] if args.key?(:read_endpoint_ip) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |