Class: Google::Apis::NetworkmanagementV1::RedisInstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::RedisInstanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Cloud Redis Instance.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Cloud Redis Instance.
-
#network_uri ⇒ String
URI of a Cloud Redis Instance network.
-
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
-
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
-
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
-
#uri ⇒ String
URI of a Cloud Redis Instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RedisInstanceInfo
constructor
A new instance of RedisInstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RedisInstanceInfo
Returns a new instance of RedisInstanceInfo.
3485 3486 3487 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Cloud Redis Instance.
Corresponds to the JSON property displayName
3458 3459 3460 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3458 def display_name @display_name end |
#network_uri ⇒ String
URI of a Cloud Redis Instance network.
Corresponds to the JSON property networkUri
3463 3464 3465 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3463 def network_uri @network_uri end |
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
Corresponds to the JSON property primaryEndpointIp
3468 3469 3470 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3468 def primary_endpoint_ip @primary_endpoint_ip end |
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
Corresponds to the JSON property readEndpointIp
3473 3474 3475 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3473 def read_endpoint_ip @read_endpoint_ip end |
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
Corresponds to the JSON property region
3478 3479 3480 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3478 def region @region end |
#uri ⇒ String
URI of a Cloud Redis Instance.
Corresponds to the JSON property uri
3483 3484 3485 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3483 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3490 3491 3492 3493 3494 3495 3496 3497 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3490 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @network_uri = args[:network_uri] if args.key?(:network_uri) @primary_endpoint_ip = args[:primary_endpoint_ip] if args.key?(:primary_endpoint_ip) @read_endpoint_ip = args[:read_endpoint_ip] if args.key?(:read_endpoint_ip) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |