Class: Google::Apis::NetworkmanagementV1::RedisInstanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::RedisInstanceInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Cloud Redis Instance.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a Cloud Redis Instance.
-
#network_uri ⇒ String
URI of a Cloud Redis Instance network.
-
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
-
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
-
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
-
#uri ⇒ String
URI of a Cloud Redis Instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RedisInstanceInfo
constructor
A new instance of RedisInstanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RedisInstanceInfo
Returns a new instance of RedisInstanceInfo.
2803 2804 2805 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a Cloud Redis Instance.
Corresponds to the JSON property displayName
2776 2777 2778 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2776 def display_name @display_name end |
#network_uri ⇒ String
URI of a Cloud Redis Instance network.
Corresponds to the JSON property networkUri
2781 2782 2783 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2781 def network_uri @network_uri end |
#primary_endpoint_ip ⇒ String
Primary endpoint IP address of a Cloud Redis Instance.
Corresponds to the JSON property primaryEndpointIp
2786 2787 2788 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2786 def primary_endpoint_ip @primary_endpoint_ip end |
#read_endpoint_ip ⇒ String
Read endpoint IP address of a Cloud Redis Instance (if applicable).
Corresponds to the JSON property readEndpointIp
2791 2792 2793 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2791 def read_endpoint_ip @read_endpoint_ip end |
#region ⇒ String
Region in which the Cloud Redis Instance is defined.
Corresponds to the JSON property region
2796 2797 2798 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2796 def region @region end |
#uri ⇒ String
URI of a Cloud Redis Instance.
Corresponds to the JSON property uri
2801 2802 2803 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2801 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2808 2809 2810 2811 2812 2813 2814 2815 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2808 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @network_uri = args[:network_uri] if args.key?(:network_uri) @primary_endpoint_ip = args[:primary_endpoint_ip] if args.key?(:primary_endpoint_ip) @read_endpoint_ip = args[:read_endpoint_ip] if args.key?(:read_endpoint_ip) @region = args[:region] if args.key?(:region) @uri = args[:uri] if args.key?(:uri) end |