Class: Google::Apis::NetworkmanagementV1::RouteInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::RouteInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine route.
Instance Attribute Summary collapse
-
#advertised_route_next_hop_uri ⇒ String
For ADVERTISED routes, the URI of their next hop, i.e.
-
#advertised_route_source_router_uri ⇒ String
For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the corresponding IP prefix in format "projects/
project/regions/region/routers/router". -
#dest_ip_range ⇒ String
Destination IP range of the route.
-
#dest_port_ranges ⇒ Array<String>
Destination port ranges of the route.
-
#display_name ⇒ String
Name of a route.
-
#instance_tags ⇒ Array<String>
Instance tags of the route.
-
#ncc_hub_route_uri ⇒ String
For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub, the URI of the corresponding route in NCC Hub's routing table.
-
#ncc_hub_uri ⇒ String
URI of the NCC Hub the route is advertised by in format "projects/
project/ locations/global/hubs/hub". -
#ncc_spoke_uri ⇒ String
URI of the destination NCC Spoke in format "projects/
project/locations/location/spokes/spoke" (regional) or "projects/project/locations/global/ spokes/spoke" (global). -
#network_uri ⇒ String
URI of a VPC network where route is located in format "projects/
project/ global/networks/network". -
#next_hop ⇒ String
String type of the next hop of the route (for example, "VPN tunnel").
-
#next_hop_network_uri ⇒ String
URI of a VPC network where the next hop resource is located in format " projects/
project/global/networks/network". -
#next_hop_type ⇒ String
Type of next hop.
-
#next_hop_uri ⇒ String
URI of the next hop resource.
-
#originating_route_display_name ⇒ String
For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the originating SUBNET/STATIC/DYNAMIC route.
-
#originating_route_uri ⇒ String
For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating SUBNET/STATIC route.
-
#priority ⇒ Fixnum
Priority of the route.
-
#protocols ⇒ Array<String>
Protocols of the route.
-
#region ⇒ String
Region of the route.
-
#route_scope ⇒ String
Indicates where route is applicable.
-
#route_type ⇒ String
Type of route.
-
#src_ip_range ⇒ String
Source IP address range of the route.
-
#src_port_ranges ⇒ Array<String>
Source port ranges of the route.
-
#uri ⇒ String
URI of a route in format "projects/
project/global/routes/route".
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteInfo
constructor
A new instance of RouteInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteInfo
Returns a new instance of RouteInfo.
3782 3783 3784 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3782 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertised_route_next_hop_uri ⇒ String
For ADVERTISED routes, the URI of their next hop, i.e. the URI of the hybrid
endpoint (VPN tunnel, Interconnect attachment, NCC router appliance) the
advertised prefix is advertised through, or URI of the source peered network.
Deprecated in favor of the next_hop_uri field, not used in new tests.
Corresponds to the JSON property advertisedRouteNextHopUri
3643 3644 3645 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3643 def advertised_route_next_hop_uri @advertised_route_next_hop_uri end |
#advertised_route_source_router_uri ⇒ String
For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the
corresponding IP prefix in format "projects/project/regions/region/routers/
router".
Corresponds to the JSON property advertisedRouteSourceRouterUri
3650 3651 3652 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3650 def advertised_route_source_router_uri @advertised_route_source_router_uri end |
#dest_ip_range ⇒ String
Destination IP range of the route.
Corresponds to the JSON property destIpRange
3655 3656 3657 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3655 def dest_ip_range @dest_ip_range end |
#dest_port_ranges ⇒ Array<String>
Destination port ranges of the route. POLICY_BASED routes only.
Corresponds to the JSON property destPortRanges
3660 3661 3662 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3660 def dest_port_ranges @dest_port_ranges end |
#display_name ⇒ String
Name of a route.
Corresponds to the JSON property displayName
3665 3666 3667 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3665 def display_name @display_name end |
#instance_tags ⇒ Array<String>
Instance tags of the route.
Corresponds to the JSON property instanceTags
3670 3671 3672 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3670 def @instance_tags end |
#ncc_hub_route_uri ⇒ String
For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub,
the URI of the corresponding route in NCC Hub's routing table. Format:
projects/project_id/locations/global/hubs/hub_id/routeTables/
route_table_id/routes/route_id`
Corresponds to the JSON propertynccHubRouteUri`
3678 3679 3680 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3678 def ncc_hub_route_uri @ncc_hub_route_uri end |
#ncc_hub_uri ⇒ String
URI of the NCC Hub the route is advertised by in format "projects/project/
locations/global/hubs/hub". PEERING_SUBNET and PEERING_DYNAMIC routes that
are advertised by NCC Hub only.
Corresponds to the JSON property nccHubUri
3685 3686 3687 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3685 def ncc_hub_uri @ncc_hub_uri end |
#ncc_spoke_uri ⇒ String
URI of the destination NCC Spoke in format "projects/project/locations/
location/spokes/spoke" (regional) or "projects/project/locations/global/
spokes/spoke" (global). PEERING_SUBNET and PEERING_DYNAMIC routes that are
advertised by NCC Hub only.
Corresponds to the JSON property nccSpokeUri
3693 3694 3695 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3693 def ncc_spoke_uri @ncc_spoke_uri end |
#network_uri ⇒ String
URI of a VPC network where route is located in format "projects/project/
global/networks/network".
Corresponds to the JSON property networkUri
3699 3700 3701 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3699 def network_uri @network_uri end |
#next_hop ⇒ String
String type of the next hop of the route (for example, "VPN tunnel").
Deprecated in favor of the next_hop_type and next_hop_uri fields, not used in
new tests.
Corresponds to the JSON property nextHop
3706 3707 3708 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3706 def next_hop @next_hop end |
#next_hop_network_uri ⇒ String
URI of a VPC network where the next hop resource is located in format "
projects/project/global/networks/network".
Corresponds to the JSON property nextHopNetworkUri
3712 3713 3714 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3712 def next_hop_network_uri @next_hop_network_uri end |
#next_hop_type ⇒ String
Type of next hop.
Corresponds to the JSON property nextHopType
3717 3718 3719 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3717 def next_hop_type @next_hop_type end |
#next_hop_uri ⇒ String
URI of the next hop resource.
Corresponds to the JSON property nextHopUri
3722 3723 3724 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3722 def next_hop_uri @next_hop_uri end |
#originating_route_display_name ⇒ String
For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the
originating SUBNET/STATIC/DYNAMIC route.
Corresponds to the JSON property originatingRouteDisplayName
3728 3729 3730 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3728 def originating_route_display_name @originating_route_display_name end |
#originating_route_uri ⇒ String
For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating
SUBNET/STATIC route. Format: projects/project_id/global/routes/route_id`
Corresponds to the JSON propertyoriginatingRouteUri`
3734 3735 3736 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3734 def originating_route_uri @originating_route_uri end |
#priority ⇒ Fixnum
Priority of the route.
Corresponds to the JSON property priority
3739 3740 3741 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3739 def priority @priority end |
#protocols ⇒ Array<String>
Protocols of the route. POLICY_BASED routes only.
Corresponds to the JSON property protocols
3744 3745 3746 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3744 def protocols @protocols end |
#region ⇒ String
Region of the route. DYNAMIC, PEERING_DYNAMIC, POLICY_BASED and ADVERTISED
routes only. If set for POLICY_BASED route, this is a region of VLAN
attachments for Cloud Interconnect the route applies to. If set to "all" for
POLICY_BASED route, the route applies to VLAN attachments of Cloud
Interconnect in all regions.
Corresponds to the JSON property region
3753 3754 3755 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3753 def region @region end |
#route_scope ⇒ String
Indicates where route is applicable. Deprecated, routes with NCC_HUB scope are
not included in the trace in new tests.
Corresponds to the JSON property routeScope
3759 3760 3761 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3759 def route_scope @route_scope end |
#route_type ⇒ String
Type of route.
Corresponds to the JSON property routeType
3764 3765 3766 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3764 def route_type @route_type end |
#src_ip_range ⇒ String
Source IP address range of the route. POLICY_BASED routes only.
Corresponds to the JSON property srcIpRange
3769 3770 3771 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3769 def src_ip_range @src_ip_range end |
#src_port_ranges ⇒ Array<String>
Source port ranges of the route. POLICY_BASED routes only.
Corresponds to the JSON property srcPortRanges
3774 3775 3776 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3774 def src_port_ranges @src_port_ranges end |
#uri ⇒ String
URI of a route in format "projects/project/global/routes/route". SUBNET,
STATIC, PEERING_SUBNET (only for peering network) and POLICY_BASED routes only.
Corresponds to the JSON property uri
3780 3781 3782 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3780 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3787 def update!(**args) @advertised_route_next_hop_uri = args[:advertised_route_next_hop_uri] if args.key?(:advertised_route_next_hop_uri) @advertised_route_source_router_uri = args[:advertised_route_source_router_uri] if args.key?(:advertised_route_source_router_uri) @dest_ip_range = args[:dest_ip_range] if args.key?(:dest_ip_range) @dest_port_ranges = args[:dest_port_ranges] if args.key?(:dest_port_ranges) @display_name = args[:display_name] if args.key?(:display_name) @instance_tags = args[:instance_tags] if args.key?(:instance_tags) @ncc_hub_route_uri = args[:ncc_hub_route_uri] if args.key?(:ncc_hub_route_uri) @ncc_hub_uri = args[:ncc_hub_uri] if args.key?(:ncc_hub_uri) @ncc_spoke_uri = args[:ncc_spoke_uri] if args.key?(:ncc_spoke_uri) @network_uri = args[:network_uri] if args.key?(:network_uri) @next_hop = args[:next_hop] if args.key?(:next_hop) @next_hop_network_uri = args[:next_hop_network_uri] if args.key?(:next_hop_network_uri) @next_hop_type = args[:next_hop_type] if args.key?(:next_hop_type) @next_hop_uri = args[:next_hop_uri] if args.key?(:next_hop_uri) @originating_route_display_name = args[:originating_route_display_name] if args.key?(:originating_route_display_name) @originating_route_uri = args[:originating_route_uri] if args.key?(:originating_route_uri) @priority = args[:priority] if args.key?(:priority) @protocols = args[:protocols] if args.key?(:protocols) @region = args[:region] if args.key?(:region) @route_scope = args[:route_scope] if args.key?(:route_scope) @route_type = args[:route_type] if args.key?(:route_type) @src_ip_range = args[:src_ip_range] if args.key?(:src_ip_range) @src_port_ranges = args[:src_port_ranges] if args.key?(:src_port_ranges) @uri = args[:uri] if args.key?(:uri) end |