Class: Google::Apis::NetworkmanagementV1::RouteInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::RouteInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine route.
Instance Attribute Summary collapse
-
#advertised_route_next_hop_uri ⇒ String
For ADVERTISED routes, the URI of their next hop, i.e.
-
#advertised_route_source_router_uri ⇒ String
For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the corresponding IP prefix.
-
#dest_ip_range ⇒ String
Destination IP range of the route.
-
#dest_port_ranges ⇒ Array<String>
Destination port ranges of the route.
-
#display_name ⇒ String
Name of a route.
-
#instance_tags ⇒ Array<String>
Instance tags of the route.
-
#ncc_hub_route_uri ⇒ String
For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub, the URI of the corresponding route in NCC Hub's routing table.
-
#ncc_hub_uri ⇒ String
URI of the NCC Hub the route is advertised by.
-
#ncc_spoke_uri ⇒ String
URI of the destination NCC Spoke.
-
#network_uri ⇒ String
URI of a VPC network where route is located.
-
#next_hop ⇒ String
String type of the next hop of the route (for example, "VPN tunnel").
-
#next_hop_network_uri ⇒ String
URI of a VPC network where the next hop resource is located.
-
#next_hop_type ⇒ String
Type of next hop.
-
#next_hop_uri ⇒ String
URI of the next hop resource.
-
#originating_route_display_name ⇒ String
For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the originating SUBNET/STATIC/DYNAMIC route.
-
#originating_route_uri ⇒ String
For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating SUBNET/STATIC route.
-
#priority ⇒ Fixnum
Priority of the route.
-
#protocols ⇒ Array<String>
Protocols of the route.
-
#region ⇒ String
Region of the route.
-
#route_scope ⇒ String
Indicates where route is applicable.
-
#route_type ⇒ String
Type of route.
-
#src_ip_range ⇒ String
Source IP address range of the route.
-
#src_port_ranges ⇒ Array<String>
Source port ranges of the route.
-
#uri ⇒ String
URI of a route.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteInfo
constructor
A new instance of RouteInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteInfo
Returns a new instance of RouteInfo.
3654 3655 3656 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3654 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertised_route_next_hop_uri ⇒ String
For ADVERTISED routes, the URI of their next hop, i.e. the URI of the hybrid
endpoint (VPN tunnel, Interconnect attachment, NCC router appliance) the
advertised prefix is advertised through, or URI of the source peered network.
Deprecated in favor of the next_hop_uri field, not used in new tests.
Corresponds to the JSON property advertisedRouteNextHopUri
3523 3524 3525 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3523 def advertised_route_next_hop_uri @advertised_route_next_hop_uri end |
#advertised_route_source_router_uri ⇒ String
For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the
corresponding IP prefix.
Corresponds to the JSON property advertisedRouteSourceRouterUri
3529 3530 3531 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3529 def advertised_route_source_router_uri @advertised_route_source_router_uri end |
#dest_ip_range ⇒ String
Destination IP range of the route.
Corresponds to the JSON property destIpRange
3534 3535 3536 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3534 def dest_ip_range @dest_ip_range end |
#dest_port_ranges ⇒ Array<String>
Destination port ranges of the route. POLICY_BASED routes only.
Corresponds to the JSON property destPortRanges
3539 3540 3541 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3539 def dest_port_ranges @dest_port_ranges end |
#display_name ⇒ String
Name of a route.
Corresponds to the JSON property displayName
3544 3545 3546 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3544 def display_name @display_name end |
#instance_tags ⇒ Array<String>
Instance tags of the route.
Corresponds to the JSON property instanceTags
3549 3550 3551 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3549 def @instance_tags end |
#ncc_hub_route_uri ⇒ String
For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub,
the URI of the corresponding route in NCC Hub's routing table.
Corresponds to the JSON property nccHubRouteUri
3555 3556 3557 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3555 def ncc_hub_route_uri @ncc_hub_route_uri end |
#ncc_hub_uri ⇒ String
URI of the NCC Hub the route is advertised by. PEERING_SUBNET and
PEERING_DYNAMIC routes that are advertised by NCC Hub only.
Corresponds to the JSON property nccHubUri
3561 3562 3563 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3561 def ncc_hub_uri @ncc_hub_uri end |
#ncc_spoke_uri ⇒ String
URI of the destination NCC Spoke. PEERING_SUBNET and PEERING_DYNAMIC routes
that are advertised by NCC Hub only.
Corresponds to the JSON property nccSpokeUri
3567 3568 3569 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3567 def ncc_spoke_uri @ncc_spoke_uri end |
#network_uri ⇒ String
URI of a VPC network where route is located.
Corresponds to the JSON property networkUri
3572 3573 3574 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3572 def network_uri @network_uri end |
#next_hop ⇒ String
String type of the next hop of the route (for example, "VPN tunnel").
Deprecated in favor of the next_hop_type and next_hop_uri fields, not used in
new tests.
Corresponds to the JSON property nextHop
3579 3580 3581 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3579 def next_hop @next_hop end |
#next_hop_network_uri ⇒ String
URI of a VPC network where the next hop resource is located.
Corresponds to the JSON property nextHopNetworkUri
3584 3585 3586 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3584 def next_hop_network_uri @next_hop_network_uri end |
#next_hop_type ⇒ String
Type of next hop.
Corresponds to the JSON property nextHopType
3589 3590 3591 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3589 def next_hop_type @next_hop_type end |
#next_hop_uri ⇒ String
URI of the next hop resource.
Corresponds to the JSON property nextHopUri
3594 3595 3596 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3594 def next_hop_uri @next_hop_uri end |
#originating_route_display_name ⇒ String
For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the
originating SUBNET/STATIC/DYNAMIC route.
Corresponds to the JSON property originatingRouteDisplayName
3600 3601 3602 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3600 def originating_route_display_name @originating_route_display_name end |
#originating_route_uri ⇒ String
For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating
SUBNET/STATIC route.
Corresponds to the JSON property originatingRouteUri
3606 3607 3608 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3606 def originating_route_uri @originating_route_uri end |
#priority ⇒ Fixnum
Priority of the route.
Corresponds to the JSON property priority
3611 3612 3613 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3611 def priority @priority end |
#protocols ⇒ Array<String>
Protocols of the route. POLICY_BASED routes only.
Corresponds to the JSON property protocols
3616 3617 3618 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3616 def protocols @protocols end |
#region ⇒ String
Region of the route. DYNAMIC, PEERING_DYNAMIC, POLICY_BASED and ADVERTISED
routes only. If set for POLICY_BASED route, this is a region of VLAN
attachments for Cloud Interconnect the route applies to. If set to "all" for
POLICY_BASED route, the route applies to VLAN attachments of Cloud
Interconnect in all regions.
Corresponds to the JSON property region
3625 3626 3627 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3625 def region @region end |
#route_scope ⇒ String
Indicates where route is applicable. Deprecated, routes with NCC_HUB scope are
not included in the trace in new tests.
Corresponds to the JSON property routeScope
3631 3632 3633 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3631 def route_scope @route_scope end |
#route_type ⇒ String
Type of route.
Corresponds to the JSON property routeType
3636 3637 3638 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3636 def route_type @route_type end |
#src_ip_range ⇒ String
Source IP address range of the route. POLICY_BASED routes only.
Corresponds to the JSON property srcIpRange
3641 3642 3643 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3641 def src_ip_range @src_ip_range end |
#src_port_ranges ⇒ Array<String>
Source port ranges of the route. POLICY_BASED routes only.
Corresponds to the JSON property srcPortRanges
3646 3647 3648 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3646 def src_port_ranges @src_port_ranges end |
#uri ⇒ String
URI of a route. SUBNET, STATIC, PEERING_SUBNET (only for peering network) and
POLICY_BASED routes only.
Corresponds to the JSON property uri
3652 3653 3654 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3652 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3659 3660 3661 3662 3663 3664 3665 3666 3667 3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 3680 3681 3682 3683 3684 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3659 def update!(**args) @advertised_route_next_hop_uri = args[:advertised_route_next_hop_uri] if args.key?(:advertised_route_next_hop_uri) @advertised_route_source_router_uri = args[:advertised_route_source_router_uri] if args.key?(:advertised_route_source_router_uri) @dest_ip_range = args[:dest_ip_range] if args.key?(:dest_ip_range) @dest_port_ranges = args[:dest_port_ranges] if args.key?(:dest_port_ranges) @display_name = args[:display_name] if args.key?(:display_name) @instance_tags = args[:instance_tags] if args.key?(:instance_tags) @ncc_hub_route_uri = args[:ncc_hub_route_uri] if args.key?(:ncc_hub_route_uri) @ncc_hub_uri = args[:ncc_hub_uri] if args.key?(:ncc_hub_uri) @ncc_spoke_uri = args[:ncc_spoke_uri] if args.key?(:ncc_spoke_uri) @network_uri = args[:network_uri] if args.key?(:network_uri) @next_hop = args[:next_hop] if args.key?(:next_hop) @next_hop_network_uri = args[:next_hop_network_uri] if args.key?(:next_hop_network_uri) @next_hop_type = args[:next_hop_type] if args.key?(:next_hop_type) @next_hop_uri = args[:next_hop_uri] if args.key?(:next_hop_uri) @originating_route_display_name = args[:originating_route_display_name] if args.key?(:originating_route_display_name) @originating_route_uri = args[:originating_route_uri] if args.key?(:originating_route_uri) @priority = args[:priority] if args.key?(:priority) @protocols = args[:protocols] if args.key?(:protocols) @region = args[:region] if args.key?(:region) @route_scope = args[:route_scope] if args.key?(:route_scope) @route_type = args[:route_type] if args.key?(:route_type) @src_ip_range = args[:src_ip_range] if args.key?(:src_ip_range) @src_port_ranges = args[:src_port_ranges] if args.key?(:src_port_ranges) @uri = args[:uri] if args.key?(:uri) end |