Class: Google::Apis::NetworkmanagementV1::RouteInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::RouteInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine route.
Instance Attribute Summary collapse
-
#advertised_route_next_hop_uri ⇒ String
For ADVERTISED routes, the URI of their next hop, i.e.
-
#advertised_route_source_router_uri ⇒ String
For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the corresponding IP prefix.
-
#dest_ip_range ⇒ String
Destination IP range of the route.
-
#dest_port_ranges ⇒ Array<String>
Destination port ranges of the route.
-
#display_name ⇒ String
Name of a route.
-
#instance_tags ⇒ Array<String>
Instance tags of the route.
-
#ncc_hub_route_uri ⇒ String
For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub, the URI of the corresponding route in NCC Hub's routing table.
-
#ncc_hub_uri ⇒ String
URI of the NCC Hub the route is advertised by.
-
#ncc_spoke_uri ⇒ String
URI of the destination NCC Spoke.
-
#network_uri ⇒ String
URI of a VPC network where route is located.
-
#next_hop ⇒ String
String type of the next hop of the route (for example, "VPN tunnel").
-
#next_hop_network_uri ⇒ String
URI of a VPC network where the next hop resource is located.
-
#next_hop_type ⇒ String
Type of next hop.
-
#next_hop_uri ⇒ String
URI of the next hop resource.
-
#originating_route_display_name ⇒ String
For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the originating SUBNET/STATIC/DYNAMIC route.
-
#originating_route_uri ⇒ String
For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating SUBNET/STATIC route.
-
#priority ⇒ Fixnum
Priority of the route.
-
#protocols ⇒ Array<String>
Protocols of the route.
-
#region ⇒ String
Region of the route.
-
#route_scope ⇒ String
Indicates where route is applicable.
-
#route_type ⇒ String
Type of route.
-
#src_ip_range ⇒ String
Source IP address range of the route.
-
#src_port_ranges ⇒ Array<String>
Source port ranges of the route.
-
#uri ⇒ String
URI of a route.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteInfo
constructor
A new instance of RouteInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteInfo
Returns a new instance of RouteInfo.
2910 2911 2912 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertised_route_next_hop_uri ⇒ String
For ADVERTISED routes, the URI of their next hop, i.e. the URI of the hybrid
endpoint (VPN tunnel, Interconnect attachment, NCC router appliance) the
advertised prefix is advertised through, or URI of the source peered network.
Deprecated in favor of the next_hop_uri field, not used in new tests.
Corresponds to the JSON property advertisedRouteNextHopUri
2781 2782 2783 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2781 def advertised_route_next_hop_uri @advertised_route_next_hop_uri end |
#advertised_route_source_router_uri ⇒ String
For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the
corresponding IP prefix.
Corresponds to the JSON property advertisedRouteSourceRouterUri
2787 2788 2789 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2787 def advertised_route_source_router_uri @advertised_route_source_router_uri end |
#dest_ip_range ⇒ String
Destination IP range of the route.
Corresponds to the JSON property destIpRange
2792 2793 2794 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2792 def dest_ip_range @dest_ip_range end |
#dest_port_ranges ⇒ Array<String>
Destination port ranges of the route. POLICY_BASED routes only.
Corresponds to the JSON property destPortRanges
2797 2798 2799 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2797 def dest_port_ranges @dest_port_ranges end |
#display_name ⇒ String
Name of a route.
Corresponds to the JSON property displayName
2802 2803 2804 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2802 def display_name @display_name end |
#instance_tags ⇒ Array<String>
Instance tags of the route.
Corresponds to the JSON property instanceTags
2807 2808 2809 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2807 def @instance_tags end |
#ncc_hub_route_uri ⇒ String
For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub,
the URI of the corresponding route in NCC Hub's routing table.
Corresponds to the JSON property nccHubRouteUri
2813 2814 2815 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2813 def ncc_hub_route_uri @ncc_hub_route_uri end |
#ncc_hub_uri ⇒ String
URI of the NCC Hub the route is advertised by. PEERING_SUBNET and
PEERING_DYNAMIC routes that are advertised by NCC Hub only.
Corresponds to the JSON property nccHubUri
2819 2820 2821 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2819 def ncc_hub_uri @ncc_hub_uri end |
#ncc_spoke_uri ⇒ String
URI of the destination NCC Spoke. PEERING_SUBNET and PEERING_DYNAMIC routes
that are advertised by NCC Hub only.
Corresponds to the JSON property nccSpokeUri
2825 2826 2827 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2825 def ncc_spoke_uri @ncc_spoke_uri end |
#network_uri ⇒ String
URI of a VPC network where route is located.
Corresponds to the JSON property networkUri
2830 2831 2832 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2830 def network_uri @network_uri end |
#next_hop ⇒ String
String type of the next hop of the route (for example, "VPN tunnel").
Deprecated in favor of the next_hop_type and next_hop_uri fields, not used in
new tests.
Corresponds to the JSON property nextHop
2837 2838 2839 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2837 def next_hop @next_hop end |
#next_hop_network_uri ⇒ String
URI of a VPC network where the next hop resource is located.
Corresponds to the JSON property nextHopNetworkUri
2842 2843 2844 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2842 def next_hop_network_uri @next_hop_network_uri end |
#next_hop_type ⇒ String
Type of next hop.
Corresponds to the JSON property nextHopType
2847 2848 2849 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2847 def next_hop_type @next_hop_type end |
#next_hop_uri ⇒ String
URI of the next hop resource.
Corresponds to the JSON property nextHopUri
2852 2853 2854 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2852 def next_hop_uri @next_hop_uri end |
#originating_route_display_name ⇒ String
For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the
originating SUBNET/STATIC/DYNAMIC route.
Corresponds to the JSON property originatingRouteDisplayName
2858 2859 2860 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2858 def originating_route_display_name @originating_route_display_name end |
#originating_route_uri ⇒ String
For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating
SUBNET/STATIC route.
Corresponds to the JSON property originatingRouteUri
2864 2865 2866 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2864 def originating_route_uri @originating_route_uri end |
#priority ⇒ Fixnum
Priority of the route.
Corresponds to the JSON property priority
2869 2870 2871 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2869 def priority @priority end |
#protocols ⇒ Array<String>
Protocols of the route. POLICY_BASED routes only.
Corresponds to the JSON property protocols
2874 2875 2876 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2874 def protocols @protocols end |
#region ⇒ String
Region of the route. DYNAMIC, PEERING_DYNAMIC, POLICY_BASED and ADVERTISED
routes only. If set for POLICY_BASED route, this is a region of VLAN
attachments for Cloud Interconnect the route applies to.
Corresponds to the JSON property region
2881 2882 2883 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2881 def region @region end |
#route_scope ⇒ String
Indicates where route is applicable. Deprecated, routes with NCC_HUB scope are
not included in the trace in new tests.
Corresponds to the JSON property routeScope
2887 2888 2889 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2887 def route_scope @route_scope end |
#route_type ⇒ String
Type of route.
Corresponds to the JSON property routeType
2892 2893 2894 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2892 def route_type @route_type end |
#src_ip_range ⇒ String
Source IP address range of the route. POLICY_BASED routes only.
Corresponds to the JSON property srcIpRange
2897 2898 2899 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2897 def src_ip_range @src_ip_range end |
#src_port_ranges ⇒ Array<String>
Source port ranges of the route. POLICY_BASED routes only.
Corresponds to the JSON property srcPortRanges
2902 2903 2904 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2902 def src_port_ranges @src_port_ranges end |
#uri ⇒ String
URI of a route. SUBNET, STATIC, PEERING_SUBNET (only for peering network) and
POLICY_BASED routes only.
Corresponds to the JSON property uri
2908 2909 2910 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2908 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 2915 def update!(**args) @advertised_route_next_hop_uri = args[:advertised_route_next_hop_uri] if args.key?(:advertised_route_next_hop_uri) @advertised_route_source_router_uri = args[:advertised_route_source_router_uri] if args.key?(:advertised_route_source_router_uri) @dest_ip_range = args[:dest_ip_range] if args.key?(:dest_ip_range) @dest_port_ranges = args[:dest_port_ranges] if args.key?(:dest_port_ranges) @display_name = args[:display_name] if args.key?(:display_name) @instance_tags = args[:instance_tags] if args.key?(:instance_tags) @ncc_hub_route_uri = args[:ncc_hub_route_uri] if args.key?(:ncc_hub_route_uri) @ncc_hub_uri = args[:ncc_hub_uri] if args.key?(:ncc_hub_uri) @ncc_spoke_uri = args[:ncc_spoke_uri] if args.key?(:ncc_spoke_uri) @network_uri = args[:network_uri] if args.key?(:network_uri) @next_hop = args[:next_hop] if args.key?(:next_hop) @next_hop_network_uri = args[:next_hop_network_uri] if args.key?(:next_hop_network_uri) @next_hop_type = args[:next_hop_type] if args.key?(:next_hop_type) @next_hop_uri = args[:next_hop_uri] if args.key?(:next_hop_uri) @originating_route_display_name = args[:originating_route_display_name] if args.key?(:originating_route_display_name) @originating_route_uri = args[:originating_route_uri] if args.key?(:originating_route_uri) @priority = args[:priority] if args.key?(:priority) @protocols = args[:protocols] if args.key?(:protocols) @region = args[:region] if args.key?(:region) @route_scope = args[:route_scope] if args.key?(:route_scope) @route_type = args[:route_type] if args.key?(:route_type) @src_ip_range = args[:src_ip_range] if args.key?(:src_ip_range) @src_port_ranges = args[:src_port_ranges] if args.key?(:src_port_ranges) @uri = args[:uri] if args.key?(:uri) end |