Class: Google::Apis::NetworkmanagementV1::SingleEdgeResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

Probing results for a single edge device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SingleEdgeResponse

Returns a new instance of SingleEdgeResponse.



3164
3165
3166
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3164

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_egress_locationGoogle::Apis::NetworkmanagementV1::EdgeLocation

Representation of a network edge location as per https://cloud.google.com/vpc/ docs/edge-locations. Corresponds to the JSON property destinationEgressLocation



3136
3137
3138
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3136

def destination_egress_location
  @destination_egress_location
end

#destination_routerString

Router name in the format 'router.metroshard'. For example: pf01.aaa01, pr02.aaa01. Corresponds to the JSON property destinationRouter

Returns:

  • (String)


3142
3143
3144
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3142

def destination_router
  @destination_router
end

#probing_latencyGoogle::Apis::NetworkmanagementV1::LatencyDistribution

Describes measured latency distribution. Corresponds to the JSON property probingLatency



3147
3148
3149
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3147

def probing_latency
  @probing_latency
end

#resultString

The overall result of active probing for this egress device. Corresponds to the JSON property result

Returns:

  • (String)


3152
3153
3154
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3152

def result
  @result
end

#sent_probe_countFixnum

Number of probes sent. Corresponds to the JSON property sentProbeCount

Returns:

  • (Fixnum)


3157
3158
3159
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3157

def sent_probe_count
  @sent_probe_count
end

#successful_probe_countFixnum

Number of probes that reached the destination. Corresponds to the JSON property successfulProbeCount

Returns:

  • (Fixnum)


3162
3163
3164
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3162

def successful_probe_count
  @successful_probe_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3169
3170
3171
3172
3173
3174
3175
3176
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3169

def update!(**args)
  @destination_egress_location = args[:destination_egress_location] if args.key?(:destination_egress_location)
  @destination_router = args[:destination_router] if args.key?(:destination_router)
  @probing_latency = args[:probing_latency] if args.key?(:probing_latency)
  @result = args[:result] if args.key?(:result)
  @sent_probe_count = args[:sent_probe_count] if args.key?(:sent_probe_count)
  @successful_probe_count = args[:successful_probe_count] if args.key?(:successful_probe_count)
end