Class: Google::Apis::NetworkmanagementV1::VpnGatewayInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine VPN gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayInfo

Returns a new instance of VpnGatewayInfo.



4532
4533
4534
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a VPN gateway. Corresponds to the JSON property displayName

Returns:

  • (String)


4503
4504
4505
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4503

def display_name
  @display_name
end

#ip_addressString

IP address of the VPN gateway. Corresponds to the JSON property ipAddress

Returns:

  • (String)


4508
4509
4510
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4508

def ip_address
  @ip_address
end

#network_uriString

URI of a Compute Engine network where the VPN gateway is configured. Corresponds to the JSON property networkUri

Returns:

  • (String)


4513
4514
4515
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4513

def network_uri
  @network_uri
end

#regionString

Name of a Google Cloud region where this VPN gateway is configured. Corresponds to the JSON property region

Returns:

  • (String)


4518
4519
4520
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4518

def region
  @region
end

#uriString

URI of a VPN gateway. Corresponds to the JSON property uri

Returns:

  • (String)


4523
4524
4525
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4523

def uri
  @uri
end

#vpn_tunnel_uriString

A VPN tunnel that is associated with this VPN gateway. There may be multiple VPN tunnels configured on a VPN gateway, and only the one relevant to the test is displayed. Corresponds to the JSON property vpnTunnelUri

Returns:

  • (String)


4530
4531
4532
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4530

def vpn_tunnel_uri
  @vpn_tunnel_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4537
4538
4539
4540
4541
4542
4543
4544
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4537

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @region = args[:region] if args.key?(:region)
  @uri = args[:uri] if args.key?(:uri)
  @vpn_tunnel_uri = args[:vpn_tunnel_uri] if args.key?(:vpn_tunnel_uri)
end