Class: Google::Apis::NetworkmanagementV1::VpnGatewayInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine VPN gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayInfo

Returns a new instance of VpnGatewayInfo.



4486
4487
4488
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a VPN gateway. Corresponds to the JSON property displayName

Returns:

  • (String)


4457
4458
4459
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4457

def display_name
  @display_name
end

#ip_addressString

IP address of the VPN gateway. Corresponds to the JSON property ipAddress

Returns:

  • (String)


4462
4463
4464
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4462

def ip_address
  @ip_address
end

#network_uriString

URI of a Compute Engine network where the VPN gateway is configured. Corresponds to the JSON property networkUri

Returns:

  • (String)


4467
4468
4469
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4467

def network_uri
  @network_uri
end

#regionString

Name of a Google Cloud region where this VPN gateway is configured. Corresponds to the JSON property region

Returns:

  • (String)


4472
4473
4474
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4472

def region
  @region
end

#uriString

URI of a VPN gateway. Corresponds to the JSON property uri

Returns:

  • (String)


4477
4478
4479
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4477

def uri
  @uri
end

#vpn_tunnel_uriString

A VPN tunnel that is associated with this VPN gateway. There may be multiple VPN tunnels configured on a VPN gateway, and only the one relevant to the test is displayed. Corresponds to the JSON property vpnTunnelUri

Returns:

  • (String)


4484
4485
4486
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4484

def vpn_tunnel_uri
  @vpn_tunnel_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4491
4492
4493
4494
4495
4496
4497
4498
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4491

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @region = args[:region] if args.key?(:region)
  @uri = args[:uri] if args.key?(:uri)
  @vpn_tunnel_uri = args[:vpn_tunnel_uri] if args.key?(:vpn_tunnel_uri)
end