Class: Google::Apis::NetworkmanagementV1::VpnTunnelInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkmanagementV1::VpnTunnelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb
Overview
For display only. Metadata associated with a Compute Engine VPN tunnel.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of a VPN tunnel.
-
#network_uri ⇒ String
URI of a Compute Engine network where the VPN tunnel is configured.
-
#region ⇒ String
Name of a Google Cloud region where this VPN tunnel is configured.
-
#remote_gateway ⇒ String
URI of a VPN gateway at remote end of the tunnel.
-
#remote_gateway_ip ⇒ String
Remote VPN gateway's IP address.
-
#routing_type ⇒ String
Type of the routing policy.
-
#source_gateway ⇒ String
URI of the VPN gateway at local end of the tunnel.
-
#source_gateway_ip ⇒ String
Local VPN gateway's IP address.
-
#uri ⇒ String
URI of a VPN tunnel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnelInfo
constructor
A new instance of VpnTunnelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnelInfo
Returns a new instance of VpnTunnelInfo.
4550 4551 4552 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4550 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of a VPN tunnel.
Corresponds to the JSON property displayName
4508 4509 4510 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4508 def display_name @display_name end |
#network_uri ⇒ String
URI of a Compute Engine network where the VPN tunnel is configured.
Corresponds to the JSON property networkUri
4513 4514 4515 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4513 def network_uri @network_uri end |
#region ⇒ String
Name of a Google Cloud region where this VPN tunnel is configured.
Corresponds to the JSON property region
4518 4519 4520 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4518 def region @region end |
#remote_gateway ⇒ String
URI of a VPN gateway at remote end of the tunnel.
Corresponds to the JSON property remoteGateway
4523 4524 4525 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4523 def remote_gateway @remote_gateway end |
#remote_gateway_ip ⇒ String
Remote VPN gateway's IP address.
Corresponds to the JSON property remoteGatewayIp
4528 4529 4530 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4528 def remote_gateway_ip @remote_gateway_ip end |
#routing_type ⇒ String
Type of the routing policy.
Corresponds to the JSON property routingType
4533 4534 4535 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4533 def routing_type @routing_type end |
#source_gateway ⇒ String
URI of the VPN gateway at local end of the tunnel.
Corresponds to the JSON property sourceGateway
4538 4539 4540 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4538 def source_gateway @source_gateway end |
#source_gateway_ip ⇒ String
Local VPN gateway's IP address.
Corresponds to the JSON property sourceGatewayIp
4543 4544 4545 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4543 def source_gateway_ip @source_gateway_ip end |
#uri ⇒ String
URI of a VPN tunnel.
Corresponds to the JSON property uri
4548 4549 4550 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4548 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 |
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 4555 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @network_uri = args[:network_uri] if args.key?(:network_uri) @region = args[:region] if args.key?(:region) @remote_gateway = args[:remote_gateway] if args.key?(:remote_gateway) @remote_gateway_ip = args[:remote_gateway_ip] if args.key?(:remote_gateway_ip) @routing_type = args[:routing_type] if args.key?(:routing_type) @source_gateway = args[:source_gateway] if args.key?(:source_gateway) @source_gateway_ip = args[:source_gateway_ip] if args.key?(:source_gateway_ip) @uri = args[:uri] if args.key?(:uri) end |