Class: Google::Apis::NetworkmanagementV1::VpnTunnelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine VPN tunnel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelInfo

Returns a new instance of VpnTunnelInfo.



3888
3889
3890
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a VPN tunnel. Corresponds to the JSON property displayName

Returns:

  • (String)


3846
3847
3848
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3846

def display_name
  @display_name
end

#network_uriString

URI of a Compute Engine network where the VPN tunnel is configured. Corresponds to the JSON property networkUri

Returns:

  • (String)


3851
3852
3853
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3851

def network_uri
  @network_uri
end

#regionString

Name of a Google Cloud region where this VPN tunnel is configured. Corresponds to the JSON property region

Returns:

  • (String)


3856
3857
3858
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3856

def region
  @region
end

#remote_gatewayString

URI of a VPN gateway at remote end of the tunnel. Corresponds to the JSON property remoteGateway

Returns:

  • (String)


3861
3862
3863
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3861

def remote_gateway
  @remote_gateway
end

#remote_gateway_ipString

Remote VPN gateway's IP address. Corresponds to the JSON property remoteGatewayIp

Returns:

  • (String)


3866
3867
3868
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3866

def remote_gateway_ip
  @remote_gateway_ip
end

#routing_typeString

Type of the routing policy. Corresponds to the JSON property routingType

Returns:

  • (String)


3871
3872
3873
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3871

def routing_type
  @routing_type
end

#source_gatewayString

URI of the VPN gateway at local end of the tunnel. Corresponds to the JSON property sourceGateway

Returns:

  • (String)


3876
3877
3878
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3876

def source_gateway
  @source_gateway
end

#source_gateway_ipString

Local VPN gateway's IP address. Corresponds to the JSON property sourceGatewayIp

Returns:

  • (String)


3881
3882
3883
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3881

def source_gateway_ip
  @source_gateway_ip
end

#uriString

URI of a VPN tunnel. Corresponds to the JSON property uri

Returns:

  • (String)


3886
3887
3888
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3886

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3893
3894
3895
3896
3897
3898
3899
3900
3901
3902
3903
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3893

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @region = args[:region] if args.key?(:region)
  @remote_gateway = args[:remote_gateway] if args.key?(:remote_gateway)
  @remote_gateway_ip = args[:remote_gateway_ip] if args.key?(:remote_gateway_ip)
  @routing_type = args[:routing_type] if args.key?(:routing_type)
  @source_gateway = args[:source_gateway] if args.key?(:source_gateway)
  @source_gateway_ip = args[:source_gateway_ip] if args.key?(:source_gateway_ip)
  @uri = args[:uri] if args.key?(:uri)
end