Class: Google::Apis::NetworkmanagementV1::VpnTunnelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine VPN tunnel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelInfo

Returns a new instance of VpnTunnelInfo.



3856
3857
3858
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3856

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a VPN tunnel. Corresponds to the JSON property displayName

Returns:

  • (String)


3814
3815
3816
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3814

def display_name
  @display_name
end

#network_uriString

URI of a Compute Engine network where the VPN tunnel is configured. Corresponds to the JSON property networkUri

Returns:

  • (String)


3819
3820
3821
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3819

def network_uri
  @network_uri
end

#regionString

Name of a Google Cloud region where this VPN tunnel is configured. Corresponds to the JSON property region

Returns:

  • (String)


3824
3825
3826
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3824

def region
  @region
end

#remote_gatewayString

URI of a VPN gateway at remote end of the tunnel. Corresponds to the JSON property remoteGateway

Returns:

  • (String)


3829
3830
3831
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3829

def remote_gateway
  @remote_gateway
end

#remote_gateway_ipString

Remote VPN gateway's IP address. Corresponds to the JSON property remoteGatewayIp

Returns:

  • (String)


3834
3835
3836
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3834

def remote_gateway_ip
  @remote_gateway_ip
end

#routing_typeString

Type of the routing policy. Corresponds to the JSON property routingType

Returns:

  • (String)


3839
3840
3841
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3839

def routing_type
  @routing_type
end

#source_gatewayString

URI of the VPN gateway at local end of the tunnel. Corresponds to the JSON property sourceGateway

Returns:

  • (String)


3844
3845
3846
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3844

def source_gateway
  @source_gateway
end

#source_gateway_ipString

Local VPN gateway's IP address. Corresponds to the JSON property sourceGatewayIp

Returns:

  • (String)


3849
3850
3851
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3849

def source_gateway_ip
  @source_gateway_ip
end

#uriString

URI of a VPN tunnel. Corresponds to the JSON property uri

Returns:

  • (String)


3854
3855
3856
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3854

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3861

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @region = args[:region] if args.key?(:region)
  @remote_gateway = args[:remote_gateway] if args.key?(:remote_gateway)
  @remote_gateway_ip = args[:remote_gateway_ip] if args.key?(:remote_gateway_ip)
  @routing_type = args[:routing_type] if args.key?(:routing_type)
  @source_gateway = args[:source_gateway] if args.key?(:source_gateway)
  @source_gateway_ip = args[:source_gateway_ip] if args.key?(:source_gateway_ip)
  @uri = args[:uri] if args.key?(:uri)
end