Class: Google::Apis::NetworkmanagementV1::VpnTunnelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkmanagement_v1/classes.rb,
lib/google/apis/networkmanagement_v1/representations.rb,
lib/google/apis/networkmanagement_v1/representations.rb

Overview

For display only. Metadata associated with a Compute Engine VPN tunnel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelInfo

Returns a new instance of VpnTunnelInfo.



3781
3782
3783
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3781

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of a VPN tunnel. Corresponds to the JSON property displayName

Returns:

  • (String)


3739
3740
3741
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3739

def display_name
  @display_name
end

#network_uriString

URI of a Compute Engine network where the VPN tunnel is configured. Corresponds to the JSON property networkUri

Returns:

  • (String)


3744
3745
3746
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3744

def network_uri
  @network_uri
end

#regionString

Name of a Google Cloud region where this VPN tunnel is configured. Corresponds to the JSON property region

Returns:

  • (String)


3749
3750
3751
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3749

def region
  @region
end

#remote_gatewayString

URI of a VPN gateway at remote end of the tunnel. Corresponds to the JSON property remoteGateway

Returns:

  • (String)


3754
3755
3756
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3754

def remote_gateway
  @remote_gateway
end

#remote_gateway_ipString

Remote VPN gateway's IP address. Corresponds to the JSON property remoteGatewayIp

Returns:

  • (String)


3759
3760
3761
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3759

def remote_gateway_ip
  @remote_gateway_ip
end

#routing_typeString

Type of the routing policy. Corresponds to the JSON property routingType

Returns:

  • (String)


3764
3765
3766
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3764

def routing_type
  @routing_type
end

#source_gatewayString

URI of the VPN gateway at local end of the tunnel. Corresponds to the JSON property sourceGateway

Returns:

  • (String)


3769
3770
3771
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3769

def source_gateway
  @source_gateway
end

#source_gateway_ipString

Local VPN gateway's IP address. Corresponds to the JSON property sourceGatewayIp

Returns:

  • (String)


3774
3775
3776
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3774

def source_gateway_ip
  @source_gateway_ip
end

#uriString

URI of a VPN tunnel. Corresponds to the JSON property uri

Returns:

  • (String)


3779
3780
3781
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3779

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
# File 'lib/google/apis/networkmanagement_v1/classes.rb', line 3786

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @region = args[:region] if args.key?(:region)
  @remote_gateway = args[:remote_gateway] if args.key?(:remote_gateway)
  @remote_gateway_ip = args[:remote_gateway_ip] if args.key?(:remote_gateway_ip)
  @routing_type = args[:routing_type] if args.key?(:routing_type)
  @source_gateway = args[:source_gateway] if args.key?(:source_gateway)
  @source_gateway_ip = args[:source_gateway_ip] if args.key?(:source_gateway_ip)
  @uri = args[:uri] if args.key?(:uri)
end